/**
 * @fileoverview
 * <pre>
 * Cet cran permet d'diter un utilisateur.
 *
 * <b><u>Contraintes:</u></b>
 * --------------------------------------------------------------------------
 * Champs concern | Description de la contrainte
 * ---------------------------------|----------------------------------------
 *
 *
 * <b><u>Contrles de surfaces:</u></b>
 * ---------------------------------------------------------------------------
 * Donne concerne | Obligatoire | Description
 * ----------------------------------|-------------|--------------------------
 * Le login est obligatoire
 * Le password et sa confirmation doivent tre identique
 * L'adresse email doit tre bien formatte
 *
 * <b><u>Flux Statiques:</u></b>
 * Aucun
 *
 * <b><u>Flux dynamiques:</u></b>
 * - /flux/protected/admin/gestionUtilisateurs/editerUtilisateur.xml
 * - /flux/protected/admin/gestionUtilisateurs/enregistrerUtilisateur.xml
 *
 * <b><u>Navigation  partir de cet cran:</u></b>
 * - /html/admin/gestionUtilisateurs.html
 * </pre>
 * Projet Gestion de contacts
 * @author EDS
 */
 
// initialisation de l'objet XML contenant les donnes de la page
var XMLDynamiquePage = null;
// l'URL du flux XML contenant les donnes de la page
var URL_XMLDynamiquePage = "/proto/xml/forms/form.xml";

// L'URL d'enregistrement d'un utilisateur
var URL_XMLDynamiqueContactEnregistrerUtilisateur = "/proto/flux/protected/forms/form.xml";

// Login de l'utilisateur en train d'tre dit
var login = null;

// Mode de la page (edition,ajout)
var mode = "edition";

// Formulaire des informations personnelles
var formUtilisateur = null;

/**
 * La mthode "editerUtilisateur_preparePage" est appele au chargement de la page.
 * Elle importe le flux dynamique comprenant les donnes.
 */
function form_preparePage() {

    // Importation du flux dynamique
    if (XMLDynamiquePage == null) {
    
        // importation du flux XML
        XMLDynamiquePage = new parent.XMLObject(null, null, "window.frames['CONTENU_WIN'].form_construirePage", URL_XMLDynamiquePage, false);
        XMLDynamiquePage.importXML();
    } else {
        form_construirePage();
    }
}

/**
 * La mthode "form_construirePage" est appele aprs le chargement du flux dynamique.
 * Elle initialise les donnes de l'utilisateur.
 */
function form_construirePage() {
    
    // On vrifie que le flux a t bien intgr
    if (XMLDynamiquePage.parseErrorXML() == 0) {
            
        // Cration du formulaire
        formUtilisateur = new ComposantForm("formUtilisateur");
        
        // Cration des lements
        var login = new ElementFormText("login", null, null, 20, 20, null, true, STATUT_ENABLED);
        formUtilisateur.addElement(login);
        
        var password = new ElementFormPass("password", null, null, 20, 20, null, true);
        formUtilisateur.addElement(password);
        
        var confPassword = new ElementFormPass("confPassword", null, null, 20, 20, null, true);
        formUtilisateur.addElement(confPassword);
        
        var nom = new ElementFormText("nom", null, null, 20, 20);
        formUtilisateur.addElement(nom);
        
        var prenom = new ElementFormText("prenom", null, null, 20, 20);
        formUtilisateur.addElement(prenom);
        
        var email = new ElementFormText("email", null, null, 40, 50);
        formUtilisateur.addElement(email);
        
        // Liste drouante des rles
        var XMLRole = new parent.XMLObjectSauvegarde();
        XMLRole.sauvegardeDOM(parent.getElements(XMLDynamiquePage.xmlDoc,"ROLE")[0]);
        var role = new ElementFormSelect("role", XMLRole);
        formUtilisateur.addElement(role);
    
        // Mthode de contrle de surface du formulaire
        //formUtilisateur.controlerSurface = form_controlerSurface;
        
        // Mthode de soumission du formulaire
        formUtilisateur.addElement(new ElementFormButtonValider("boutonValider"));
        formUtilisateur.soumettre = form_valider;
        
        formUtilisateur.ecrireBind();
    }
}

/**
 * La mthode "form_valider" est appele lors d'un clique sur le bouton valider
 */
function form_valider() {

    var params = [];
    
    // On remplis les paramtres avec les composants du formulaire
    var element = null; 
    for (i = 0; i < formUtilisateur.tabElement.length; i++){
        
        element = formUtilisateur.tabElement[i];

        params[element.id] = element.getValue();
        
    }
    
    // On appel l'action
    xmlAction = new parent.XMLObject(null, null, "window.frames['CONTENU_WIN'].gererRetourAction", URL_XMLDynamiqueContactEnregistrerUtilisateur, false);
    // On appelle l'action en mode synchrone
    xmlAction.initAsynchrone(false);
    //Initialisation de la requte avec les paramtres
    xmlAction.initRequestParams("POST",params);
    // Appel de l'action
    xmlAction.importXML();
}

/**
 * Fonction prive appele au retour du flux xml de l'action "appelerActionRedirection".
 * @private
 */
function gererRetourAction() {
    
    if(xmlAction.parseErrorXML("popup") == 0) {
    	alert("Mise  jour russie");
    }
}

/**
 * La mthode "form_controlerSurface" est appele lors d'un clique sur le bouton valider. Elle vrifie les champs du formulaire
 */
function form_controlerSurface() {
    
    var retour = true;
    
    // Le login est un champ obligatoire
    retour = ctrlSaisie(formUtilisateur.getDefaultElementById("login").getDomHtmlElement(), "Vous devez renseigner le login de l'utilisateur, merci.");
    
    // Le password est un champ obligatoire
    if (retour) {
        retour = ctrlSaisie(formUtilisateur.getDefaultElementById("password").getDomHtmlElement(), "Vous devez renseigner le password de l'utilisateur, merci.");
    }
        
    // La confirmation du password est un champ obligatoire
    if (retour) {
        retour = ctrlSaisie(formUtilisateur.getDefaultElementById("confPassword").getDomHtmlElement(), "Vous devez confirmer le password, merci.");
    }
    
    // Vrification que la confirmation du password est identique au password
    if (formUtilisateur.getDefaultElementById("confPassword").getValue() != formUtilisateur.getDefaultElementById("password").getValue()) {
        alert("La confirmation du password est diffrente du password, veuillez recommencer s'il vous plait");
        formUtilisateur.getDefaultElementById("confPassword").setValue("");
        formUtilisateur.getDefaultElementById("password").setValue("");
        retour = false;
    }
    
    // Vrification du formatage de l'adresse mail
    if (retour) {
        retour = ctrlSaisie(formUtilisateur.getDefaultElementById("email").getDomHtmlElement(), null, "Mauvais format de l'addresse email, veuillez saisir une adresse mail valide, merci.", null, null, estAdresseEmailString);
    }
    
    return retour;
}

