/**
* @fileoverview Ce fichier Javascript correspond au framework de gestion du composant modle de page d'aide.
* Cette description consiste  prsenter les prototypes des fonctions, des exemples d'appels et les prcisions
* techniques ncessaires  la mise en oeuvre de ce framework.<br>
* Le framework hrite de la classe ComposantArborescence.<br>
* <br><br><br><img src="Image.ComposantAide.jpg"/><br><br><br>
* @author Ministre des Affaires Etrangres, Aubay SA, Steve Pguet
* @version 2.4
* @date 14/11/2006
*/

/*
Copyright ou  ou Copr. 
Ministre des Affaires Etrangres,
Aubay SA,
Steve Pguet, (21/05/2004)

steve.peguet@diplomatie.gouv.fr

Ce logiciel est un programme informatique servant de framework JavaScript 
bas sur les normes W3C (XHTML/CSS/DOM/XML). Il offre la possibilit de 
mettre en uvre facilement les principes ergonomiques et techniques propres 
 un client riche (cumul des avantages du client lger et du client lourd).
Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilit au code source et des droits de copie,
de modification et de redistribution accords par cette licence, il n'est
offert aux utilisateurs qu'une garantie limite.  Pour les mmes raisons,
seule une responsabilit restreinte pse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concdants successifs.

A cet gard  l'attention de l'utilisateur est attire sur les risques
associs au chargement,   l'utilisation,   la modification et/ou au
dveloppement et  la reproduction du logiciel par l'utilisateur tant 
donn sa spcificit de logiciel libre, qui peut le rendre complexe  
manipuler et qui le rserve donc  des dveloppeurs et des professionnels
avertis possdant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invits  charger  et  tester  l'adquation  du
logiciel  leurs besoins dans des conditions permettant d'assurer la
scurit de leurs systmes et ou de leurs donnes et, plus gnralement, 
 l'utiliser et l'exploiter dans les mmes conditions de scurit. 

Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
pris connaissance de la licence CeCILL, et que vous en avez accept les
termes.*/


// Dfinition de la classe ComposantAide reprsentant un composant Aide

/**
* Cre une instance de la classe ComposantAide reprsentant un composant Aide.
* @class La classe <b>ComposantAide</b> est la classe permettant de grer le composant Aide.
* <br> Elle hrite du ComposantArborescence. La ralisation et le mise en place des pages d'aide
* reste  faire par l'utilisateur<br>
* <br><br><br><img src="Image.ComposantAideUML.png"/><br><br><br>
* <br><b>Rendu IHM :<br><br><br><img src="Image.ComposantAide.jpg"/><br><br><br>
* @constructor
* @extends ComposantArborescence
* @param {String_Obligatoire} id : String indiquant l'{@link #id id} du composant  instancier.
* Sa valorisation doit correspondre au nom de la variable JavaScript du composant instanci.
* @param {XMLObjectSauvegarde_Obligatoire} XMLObjectCont : Objet {@link #XMLObjectSauvegarde XMLObjectSauvegarde}
* pour paramtrer le contenu informatif.
* @param {DefaultElementForm_Optionnel} objetOrigin : objet depuis lequel on appelle la page d'aide.
* @return {void}
* @version 2.5
* @date 14/02/2007
*/
function ComposantAide(id, xmlObjectCont, objetOrigin)
{
	//Heritages
	this.extend_ComposantArborescence = ComposantArborescence;
	this.extend_ComposantArborescence(id,'navigation',xmlObjectCont);
	
	//Attributs
	this.objetOrigin=null;
	if(objetOrigin){this.objetOrigin=objetOrigin;}
	
	//Fonctions pour crire la page d'aide
	this.ecrireBindArborescence=this.ecrireBind;
	this.ecrireBind=ComposantAide_ecrireBind;
	this.lierPageDroite=ComposantAide_lierPageDroite;
	this.mettreAJour=ComposantAide_mettreAJour;
}

/**
* La fonction prive <b>lierPageDroite(item)</b> de la classe ComposantAide permet d'associer une page html
*  un lment de l'aide. Ainsi,  l'lment ouvert dans l'arborescence de la frame de gauche, on associe 
* une url  ouvrir dans la frame de droite.<br>
* Les url et le nom de cette fonction doivent etre renseigns dans le fichier XML d'aide (tags URL et FUNC).<br>
* @private
* @param {ObjectItemArborscence_Obligatoire} item : objet {@link #ObjectItemArborscence ObjectItemArborscence} dans lequel est stocke l'url pour l'affichage
* @return {void}
* @version 2.4
* @date 14/11/2006
*/
 function ComposantAide_lierPageDroite(item)
	{
		 parent.window.frames['droite'].location=item.url;
          
  }

/**
* La fonction prive <b>ecrireBind()</b> de la classe ComposantAide permet d'ecrire la page html
* d'un lment de l'aide. Cette mthode va reprer si l'on souhaite afficher une page d'aide avec une
* arborescence ouverte, et appeler la fonction pour afficher l'url qui correspond.<br>
* Elle appelle ensuite la mthode ecrireBind du ComposantArborescence.
* @see #lierPageDroite
* @prive
* @param {string_Optionnel} string correspondant  l'url ou au chemin XML que l'on souhaite afficher
* @return {void}
* @version 2.4
* @date 14/11/2006
*/
function ComposantAide_ecrireBind()
{
		if(arguments.length == 1){
			var tmpAffichage = arguments[0];
						
  			//Recuperation du dernier item pour lien URL sur la page de droite de l'aide
  			var tabAffichage = this.ouvrirArbo(tmpAffichage);
  			var l=tabAffichage.length;
  			if(l != 0){
  				var dernierItem = tabAffichage[l-1];
  			
  				//Ecriture de l'arborescence sur la page de gauche, ouverte  un item donn
  				this.ecrireBindArborescence(tmpAffichage);
  				this.lierPageDroite(dernierItem);
  			  			
  		//Ecriture de l'arborescence sans ouverture  un item prcis
  		}else{this.ecrireBindArborescence();}	
  		  		
		}else{this.ecrireBindArborescence();}
}

/**
* La fonction prive <b>mettreAJour(valeur)</b> de la classe ComposantAide permet de mettre  jour
* un lment de formulaire. Elle est appele depuis un assistant associ  ce mme lment.
* @public
* @param {String ou Array_Obligatoire} valeur ou tableau d'ObjetOptions pour mise  jour d'un lment de formulaire
* @return {void}
* @version 2.5
* @date 14/02/2007
*/
function ComposantAide_mettreAJour(valeur)
{
	//Recuperation de l'element de formulaire depuis lequel on a ouvert la page d'aide
	var elementCourant=parent.window.opener.currentElementAssistant;
	if(typeof valeur == "string"){
		elementCourant.setValue(valeur);
	}else{
		if(elementCourant.setTabOption){
			elementCourant.setTabOption(valeur);
		}}
	
}



