/** 
* @fileoverview Ce fichier Javascript correspond  la base du framework de gestion des
* formulaires. Ses classes utilitaires default n'ont pas pour
* vocation d'tre utilises directement par l'utilisateur du
* framework. Elles sont utilises pour dfinir et
* mutualiser les proprits et les comportements communs.<br>
* On peut les classer selon leurs fonctionnalits en 4 types :
* <ul>
* <li>Les classes <b>{@link DefaultHtml DefaultHtml}</b>
*  et <b>DefaultHtmlXxx</b>
*  rassemblent les attributs HTML et se dclinent selon les
* diffrents tags HTML utilises.
* </li>
* <li>La classe <b>{@link DefaultLibelle DefaultLibelle}</b>
*  implmente la gestion des libells.
* </li>
* <li>La classe <b>{@link DefaultXml DefaultXml}</b>
*  gre la relation entre l'lment de
* formulaire et la structure XML associe.
* </li>
* <li>La classe <b>{@link DefaultElementForm DefaultElementForm}</b>
*  regroupe les autres fonctionnalits communes.
* </li>
* </ul>
* Les classes DefaultXml et DefaultElementForm
* , lorsqu'elles sont associes  des champs
* multivalues,<br>
* utilisent la structure <b>{@link ObjectOption ObjectOption}</b>
* .
* <br><br><b>{@link Fonctions_Globales Fonctions globales} :</b> 
*  {@link Fonctions_Globales#getDefaultElementById getDefaultElementById},
   {@link Fonctions_Globales#getRangOption getRangOption},
*  {@link Fonctions_Globales#ecrireText ecrireText}
* @author Ministre des Affaires Etrangres, Aubay SA, Steve Pguet
* @version 1.1
* @date 25/10/2005
*/

/*
Copyright ou  ou Copr. 
Ministre des Affaires Etrangres,
Aubay SA,
Steve Pguet, (09/04/2004)

steve.peguet@diplomatie.gouv.fr

Ce logiciel est un programme informatique servant de framework JavaScript 
bas sur les normes W3C (XHTML/CSS/DOM/XML). Il offre la possibilit de 
mettre en oeuvre facilement les principes ergonomiques et techniques propres 
 un client riche (cumul des avantages du client lger et du client lourd).
Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilit au code source et des droits de copie,
de modification et de redistribution accords par cette licence, il n'est
offert aux utilisateurs qu'une garantie limite.  Pour les mmes raisons,
seule une responsabilit restreinte pse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concdants successifs.

A cet gard  l'attention de l'utilisateur est attire sur les risques
associs au chargement,   l'utilisation,   la modification et/ou au
dveloppement et  la reproduction du logiciel par l'utilisateur tant 
donn sa spcificit de logiciel libre, qui peut le rendre complexe  
manipuler et qui le rserve donc  des dveloppeurs et des professionnels
avertis possdant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invits  charger  et  tester  l'adquation  du
logiciel  leurs besoins dans des conditions permettant d'assurer la
scurit de leurs systmes et ou de leurs donnes et, plus gnralement, 
 l'utiliser et l'exploiter dans les mmes conditions de scurit. 

Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
pris connaissance de la licence CeCILL, et que vous en avez accept les
termes.*/

//Images
var img_aide="/proto/FrameworkERGO/images/bouton/navig/BoutAideInterog.gif";
var img_aideOver="/proto/FrameworkERGO/images/bouton/navig/BoutAideInterogover.gif";
var img_aide_F="/proto/FrameworkERGO/images/bouton/navig/BoutAideInterog_F.gif";
var img_assist="/proto/FrameworkERGO/images/bouton/navig/BoutAideInterog.gif";
var img_assistOver="/proto/FrameworkERGO/images/bouton/navig/BoutAideInterogover.gif";
var img_assist_F="/proto/FrameworkERGO/images/bouton/navig/BoutAideInterog_F.gif";

//urls
var urlHtmlAide="/proto/FrameworkERGO/html/aide/aide.html";
var urlHtmlAssistant="/proto/FrameworkERGO/html/aide/assistant.html";

// Constantes globales

// STATUT d'un element de formulaire
STATUT_ENABLED=1;
STATUT_DISABLED=3;
STATUT_READONLY=2;
STATUT_AFFICHAGE=4;

// Type de lien vers l'aide
LIEN_AIDE_BOUTTON = 0;
LIEN_AIDE_LIBELLE = 1;
LIEN_AIDE_BOUTON_LIBELLE = 2;

// Type de position de la bulle
POS_BULLE_BOITE = 1; 
POS_BULLE_AIDE = 2; 

// Constantes pour dfinir si un element est de type mono-value ou multi-values
MULTI=true;
MONO=false;


// Variables globales

// tableau de tous les lments et composants de formulaire instancis
var tabElementForm = new Array();

// pour gnrer des ids
var suffixeId=0;


// Fonctions globales

// pour insrer du texte dans une balise identifie par id

/**
* La fonction globale "ecrireText(id, texte)" permet d'insrer du texte dans un document HTML.<br>
* Cette fonction s'avre utile dans bon nombre de situations, le dveloppeur y verra un intert tout 
* particulier pour renseigner les titres de formulaire ou pour placer du texte  l'intrieur d'une fiche.
* <br><br><b>Voir Exemple d'appel aux fonctions globales : </b>
* <a href='exemples_A3.html#ecrireText_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @param {String_Obligatoire} id : Id du tag HTML o sera positionn le texte.
* @param {String_Obligatoire} texte : Chane de caractre  insrer dans le document HTML.
* @return {void}
* @version 1.1
* @date 25/10/2005
*/
function ecrireText(id, texte) {
  document.getElementById(id).innerHTML=texte;
}


// Pour retrouver un Element/Composant du framework par son id

/**
* La fonction globale "getDefaultElementById(id)" recherche un lment de formulaire identifi par le paramtre id,
* dans la variable globale 'tabElementForm'. Cette variable globale contient, sous forme de tableau,
* tout les lments du formulaire de la page. L'lment trouv est retourn par la fonction.
* <br><br><b>Voir Exemple d'appel aux fonctions globales : </b>
* <a href='exemples_A3.html#getDefaultElementById_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @param {String_Obligatoire} id : Identifiant de l'lment recherch.
* @return {DefaultElementForm} Objet reprsentant l'lment du formulaire recherch
* @version 1.1
* @date 25/10/2005
*/
function getDefaultElementById(id) {
  for (var i=0; i<tabElementForm.length; i++) {
    if (tabElementForm[i].id==id) return tabElementForm[i];
  }
  return null;
}


// retourne le rang d'une valeur dans un tableau d'option

/**
* La fonction globale "getRangOption(tab, value)" recherche dans le tableau passe en paramtre, 
* l'option identifie par le paramtre 'value'.<br> La fonction renvoie le rang de l'option trouve
* dans le tableau.<br><br><b>Voir Exemple d'appel aux fonctions globales : </b>
* <a href='exemples_A3.html#getRangOption_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @param {ObjectOption_Obligatoire} tab Tableau d'lment {@link ObjectOption}.
* @param {String_Obligatoire} value Valeur de l'option recherche.
* @return {int}
* @version 1.1
* @date 25/10/2005
*/
function getRangOption(tab, value) {  
  for (var i=0;i<tab.length;i++) {    
    if (tab[i].value==value)
      return i;
  }
  return -1;
}


//****************** Classes de dfinition des attributs HTML***********************


//******************            DefaultHtml                  ***********************

/**
* Cre une instance de la classe DefaultHtml. 
* @class La classe <b>DefaultHtml</b> et ses classes drives <b>DefaultHtml<i>Tag</i></b> dfinissent
* les attributs HTML utiliss dans le framework par les lments de formulaire. Les proprits communes 
* sont dfinies dans DefaultHTML, et les proprits particulires  chaque Tag sont dcrites dans les 
* diffrentes classes DefaultHtml<i>Tag</i>.<br>Les Tags utiliss par le framework sont : 
* <ul>
* <li>&lt;a&gt; associ  la classe <b>DefaultHtmlA</b></li>
* <li>&lt;form&gt; associ  la classe <b>DefaultHtmlForm</b></li>
* <li>&lt;img&gt; associ  la classe <b>DefaultHtmlImg</b></li>
* <li>&lt;input&gt; associ  la classe <b>DefaultHtmlInput</b></li>
* <li>&lt;option&gt; associ  la classe <b>DefaultHtmlOption</b></li>
* <li>&lt;select&gt; associ  la classe <b>DefaultHtmlSelect</b></li>
* <li>&lt;textarea&gt; associ  la classe <b>DefaultHtmlTextarea</b></li></ul>
* <br>Ces types de classe contiennent uniquement des proprits prives qui sont exactement reprsentatives des
* attributs correspondants au tag HTML en question
* <br><br><br><img src="Image.DefaultHtmlUML.png"/><br><br><br>
* @public
* @constructor
* @param {String_Facultatif} id : id de l'lment pour DefaultHtml.
* Identifiant permettant de faire rfrence  un lment unique d'une page
* @param {int_Facultatif} tabindex : position de l'lment lors d'une tabulation
* @version 1.1
* @date 25/10/2005
*/
function DefaultHtml(id, tabindex) {

	/**
	* Cette fonction est inutile pour le dveloppeur. Elle permet de gnrer un nouvel id.
	* @private
	* @param {} Aucun
	* @return {string} id suivant
	* @version 1.1
	* @date 25/10/2005
	*/
  this.newId=function() {return ("elementFormId"+suffixeId++);};
//  this.accesskey=null;
//  this.class;

	/**
	* Attribut id de DefaultHtml. L'id (identifiant) permet de faire rfrence  un 
	* lment de manire unique dans une page.
	* <br>Les ID servent notamment au JavaScript pour localiser des lments HTML.
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/ 
  if (this.id==null) { 
    // si this.id n'a pas encore t dfini utltrieurement
    this.id=this.newId(); // par dfaut
    if (id!=null) this.id=id;
  }

	/**
	* Attribut HTML style de DefaultHtml. Permet de prciser le style  appliquer aux balises.
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005	
	*/  
  this.style=null;
  
	/**
	* Attribut HTML title de DefaultHtml. Permet d'afficher un texte au passage de la souris.
	* <br><br>
	* @protected
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/   
  this.title=null;
//  this.dir=null;
//  this.lang=null;

	/**
	* Attribut HTML name de DefaultHtml. Reprsente le nom associ  un champ de formulaire.
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/
  this.name=this.id; // TF pour <form>
  
	/**
	* Attribut HTML tabindex de DefaultHtml. Permet de spcifier la position de l'lment
	* lors d'une tabulation.
	* <br><br>
	* @private
	* @type int
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.tabindex=null;
  if (tabindex!=null) this.tabindex=tabindex;

	/**
	* La mthode publique setTitle permet de renseigner l'attribut HTML title de
	* la balise HTML courante.<br><br>
	* @public
	* @param {String_Obligatoire} title : attribut title  renseigner pour DefaultHtml
	* @return {void}
	* @version 1.1
	* @date 25/10/2005 
	*/
  this.setTitle= function(title) {
    this.title=title;
  };
  
  /**
	* La mthode publique getTitle retourne la valeur de l'attribut title de
	* la balise HTML courante.<br><br>
	* @public
	* @param {} Aucun
	* @return {String} valeur de l'attribut title
	* @version 2.5
  * @date 14/02/2007 
	*/
  this.getTitle = function() {
    return this.title;
  };
  
  /**
	* La mthode publique getId retourne la valeur de l'attribut id de
	* la balise HTML courante.<br><br>
	* @public
	* @param {} Aucun
	* @return {String} valeur de l'attribut id
	* @version 2.5
  * @date 14/02/2007 
	*/
  this.getId = function() {
    return this.id;
  };
  
	/**
	* La mthode publique setStyle dfinie la valeur de l'attribut style de l'lment HTML courant.
	* @public
	* @param {String_Obligatoire} unStyle : valeur de l'attribut style.
	* @return {void}
	* @version 2.5
	* @date 14/02/2007
	*/
  this.setStyle = function(unStyle) {
  	this.style = unStyle;
  }

	/**
	* La mthode publique getStyle retourne la valeur de l'attribut style de l'lment HTML courant.
	* @public
	* @param {aucun}
	* @return {String} valeur de l'attribut style.
	* @version 2.5
	* @date 14/02/2007
	*/
  this.getStyle = function() {
  	return this.style;
  }
}


//******************            DefaultHtmlForm                 ***********************

/**
* Cre une instance de la classe DefaultHtmlForm. 
* @class La classe <b>DefaultHtmlForm</b> est une sous-classe de
* {@link DefaultHtml}. Elle hrite de ses proprits (dcrivant les attributs HTML communs) et de ses mthodes.<br>
* <b>DefaultHtmlForm modlise le Tag &lt;form&gt;</b> (dont les proprits particulires 
* sont utilises dans le framework). Celui-ci permet de regrouper plusieurs lments de formulaire
* (boutons,champs de saisie,...).
* <br><br><br><img src="Image.DefaultHtmlFormUML.png"/><br><br><br>
* @extends DefaultHtml
* @constructor
* @param {String_Facultatif} id : id de l'lment, hrit de {@link DefaultHtml}
* @param {String_Facultatif} method : attribut html method,
* indiquant sous quelle forme seront envoyes les rponses du formulaire.
* @param {String_Facultatif} action : attribut html action,
* permettant d'indiquer l'adresse d'envoi des donnes du formulaire.
* @param {String_Facultatif} enctype : attribut html enctype,
* facultatif, spcifiant le type de codage des donnes lors du postage du formulaire.
* @version 1.1
* @date 25/10/2005
*/
function DefaultHtmlForm(id, method, action, enctype) {
 this.extend_DefaultHtml = DefaultHtml; 
 this.extend_DefaultHtml(id);

	/**
	* Attribut html action. Permet d'indiquer l'adresse d'envoi des donnes du formulaire
	* (URL, script CGI,  ou adresse email 'mailto:').
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/ 
  this.action=null;
  if (action!=null) this.action=action;
//  this.accept=null;
//  this.acceptcharset=null;

	/**
	* Attribut html enctype. Attribut facultatif spcifiant le codage des donnes lors 
	* de l'envoi du formulaire (toutefois il n'est pas ncessaire de le prciser car la valeur 
	* attribue par dfaut 'application/x-www-form-urlencoded' est la seule valeur valide).
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/ 
  this.enctype=null;
  if (enctype!=null) this.enctype=enctype; // utile pour l'upload de fichier

	/**
	* Attribut html method. Indique sous quelle forme seront envoyes les rponses du formulaire.
	*- <b>Valeur par dfaut : </b> <a href='default-values_A3.html#DefaultHtmlFormProp'>
	* Valeurs par dfaut des Proprits</a>
	*POST est la valeur qui correspond  un envoi de donnes stockes dans le corps de la requte. <br>
	*GET correspond  un envoi des donnes codes dans l'URL, et spares de l'adresse du script 
	* par un point d'interrogation.<br>
	* (pour plus de renseignement sur les mthodes POST et GET, se documenter sur le protocole HTTP).
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/ 
  this.method="GET";
  if (method!=null) this.method=method;
//  this.target="no target";  //TF
}


//******************            DefaultHtmlInput                 ***********************

/**
* Cre une instance de la classe DefaultHtmlInput. 
* @class La classe <b>DefaultHtmlInput</b> est une sous-classe de
* {@link DefaultHtml} . Elle hrite de ses proprits (dcrivant les attributs HTML communs), et de ses mthodes.<br>
* <b>DefaultHtmlInput modlise le Tag &lt;input&gt;</b>. INPUT est une balise essentielle des formulaires,
* permettant de crer nombreux lments "interactifs" (checkbox, hidden, file, image, password, radio, reset, 
* submit, text).
* <br><br><br><img src="Image.DefaultHtmlInputUML.png"/><br><br><br>
* @extends DefaultHtml
* @public
* @constructor
* @param {String_Facultatif} id : id de l'lment, hrit de {@link DefaultHtml}
* @param {String_Facultatif} type : attribut html type, permettant de prciser le type d'lment 
* que reprsente la balise INPUT.
* @param {int_Facultatif} maxlength : attribut html maxlength, permettant de spcifier la taille maximale 
* de caractres autoriss.
* @param {int_Facultatif} size : attribut html size, permettant de dfinir la taille visible 
* du champ en nombre de caractres.
* @param {int_Facultatif} tabindex : attribut html tabindex, hrit de {@link DefaultHtml}
* @version 1.1
* @date :  25/10/2005
*/
function DefaultHtmlInput(id, type, maxlength, size, tabindex) {
  this.extend_DefaultHtml = DefaultHtml;
  this.extend_DefaultHtml(id, tabindex);
//  this.accept=null;
//  this.align=null;  //TF

	/**
	* Attribut html alt de DefaultHtmlInput. Permet de spcifier un texte alternatif.
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/
  this.alt=null;
  
	/**
	* Attribut html checked. Permet de spcifier les deux tats checked (coch) et unchecked (non coch)
	* d'une case  cocher (checkbox)<br>(Lorsque la case est coch la paire nom/valeur est envoye).
	* <br><br>
	* @private
	* @type boolean
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.checked=null;
  
	/**
	* Attribut html disabled. Donne ou dfinit la valeur du statut de la balise.
	* <br><br>
	* @private
	* @type boolean
	* @version 1.1
	* @date 25/10/2005
	*/
  this.disabled=null;
  
	/**
	* Attribut html maxlength. Permet de spcifier la taille maximale de caractres autoriss.
	* <br><br>
	* @private
	* @type int
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.maxlength=null;
  if (maxlength!=null) this.maxlength=maxlength;
  
	/**
	* Attribut html readonly. Permet de sp&ecute;cifier si l'lment est en mode lecture seulement.
	* <br><br>
	* @private
	* @type boolean
	* @version 1.1
	* @date 25/10/2005
	*/
  this.readonly=null;

	/**
	* Attribut html size. Permet de dfinir la taille visible du champ en nombre de caractres.
	* <br><br>
	* @private
	* @type int
	* @version 1.1
	* @date 25/10/2005
	*/
  this.size=null;
  if (size!=null) this.size=size;
//  this.src=null //pas d'image

	/**
	* Attribut html type. Permet de prciser le type d'lment que reprsente la balise INPUT. <br>
	* (Il peut prendre les valeurs : checkbox, hidden, file, image, password, radio, reset, submit, text).
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/
  this.type=null;
  if (type!=null) this.type=type;
  
	/**
	* Attribut html value. Reprsente la valeur du champ de saisie.
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/
  this.value=null;
  
	/**
	* La classe DefaultHtmlInput surcharge la mthode publique 
	* {@link DefaultHtml#setTitle setTitle} de DefaultHtml pour renseigner galement l'attribut HTML alt.
	* <br><br>
	* @public
	* @param {String_Obligatoire} title : L'attribut title  renseigner
	* @version 1.1
	* @date 25/10/2005
	*/ 
  this.setTitle= function(title) {
    this.title=title;
    this.alt=this.title;
  };
}


//******************            DefaultHtmlSelect                 ***********************

/**
* Cre une instance de la classe DefaultHtmlSelect. 
* @class La classe <b>DefaultHtmlSelect</b> est une sous-classe de
* {@link DefaultHtml}. Elle hrite de ses proprits (dcrivant les attributs HTML communs), et de ses mthodes.<br>
* <b>DefaultHtmlSelect modlise le Tag &lt;select&gt;</b> (et ses proprits particulires), permettant de crer
* une liste droulante d'lments.
* <br><br><br><img src="Image.DefaultHtmlSelectUML.png"/><br><br><br>
* @extends DefaultHtml
* @constructor
* @param {String_Facultatif} id : id de l'lment, hrit de {@link DefaultHtml}
* @param {int_Facultatif} size : attribut html size, reprsentant le nombre de lignes dans la liste.
* @param {String_Facultatif} multiple : attribut html multiple,
* permettant de dfinir une liste de choix avec plusieurs choix possibles (multiselect).
* @param {int_Facultatif} tabindex : attribut html tabindex, hrit de {@link DefaultHtml}
* @version 1.1
* @date 25/10/2005
*/
function DefaultHtmlSelect(id, size, multiple, tabindex) {
  this.extend_DefaultHtml = DefaultHtml;
  this.extend_DefaultHtml(id, tabindex);

	/**
	* Attribut html disabled. Permet de crer une liste dsactive, c'est--dire grise.
	* <br><br>
	* @private
	* @type boolean
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.disabled=null;
  
	/**
	* Attribut multiple. Permet de dfinir une liste de choix sous avec plusieurs choix possibles
	* <br>(et pas seulement une liste droulante avec un seul choix possible : size 1).
  * <br><br>
	* @private
	* @type string
	* @version 1.1
	* @date 25/10/2005
	*/ 
  this.multiple=null;
  if (multiple!=null) this.multiple=multiple;
  
	/**
	* Attribut size. Reprsente le nombre de lignes dans la liste
	* (cette valeur peut tre plus grande que le nombre d'lments effectifs dans la liste).
	* <b>Valeur par dfaut : </b> <a href='default-values_A3.html#DefaultHtmlSelectProp'>
	* Valeurs par dfaut des Proprits</a>
  * <br><br>
	* @private
	* @type int
	* @version 1.1
	* @date 25/10/2005
	*/
  this.size="1";
  if (size!=null) this.size=size;
}


//******************            DefaultHtmlOption                 ***********************

/**
* Cre une instance de la classe DefaultHtmlOption. 
* @class La classe <b>DefaultHtmlOption</b> modlise le Tag &lt;option&gt;, permettant de prciser
* les lments d'une liste.
* <br><br><br><img src="Image.DefaultHtmlOptionUML.png"/><br><br><br>
* @constructor
* @version 1.1
* @date 25/10/2005
*/
function DefaultHtmlOption() {
	/**
	* Attribut disabled. Permettant de crer un  lment dsactiv, c'est--dire gris.
	* <br><br>
	* @private
	* @type boolean
	* @version 1.1
	* @date 25/10/2005
	*/
  this.disabled = null;
  
	/**
	* Attribut label. Permettant de dfinir l'intitul de l'lment dans la liste.
	* <br><br>
	* @private
	* @type string
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.label = null;
  
	/**
	* Attribut selected. Permet de prselectionner un item lorsque le formulaire est affich initialement.
	* <br><br>
	* @private
	* @type boolean
	* @version 1.1
	* @date 25/10/2005
	*/   
  this.selected=null;
//  this.value="no value"; // gr par tabOption
}


//******************            DefaultHtmlTextarea                 ***********************

/**
* Cre une instance de la classe DefaultHtmlTextarea. 
* @class La classe <b>DefaultHtmlTextarea</b> est une sous-classe de
* {@link DefaultHtml}. Elle hrite de ses proprits (dcrivant les attributs HTML communs) 
* et de ses mthodes.<br><b>DefaultHtmlTextarea modlise le Tag &lt;textarea&gt;</b>,
* qui permet de dfinir une zone de saisie plus vaste par rapport  la simple ligne de saisie que propose le Tag
* Input.
* <br><br><br><img src="Image.DefaultHtmlTextareaUML.png"/><br><br><br>
* 10/11/2006 : Ajout de l'attribut nbcar correspondant au nombre maximum de caractres de saisie.
* @public
* @extends DefaultHtml
* @constructor
* @param {String_Facultatif} id : id de l'lment, hrit de {@link DefaultHtml}.
* @param {int_Facultatif} cols : attribut html size, reprsentant le nombre de caractres 
* que peut contenir une ligne.
* @param {int_Facultatif} rows : attribut html multiple, reprsentant le nombre de lignes.
* @param {int_Facultatif} tabindex : attribut html tabindex, hrit de {@link DefaultHtml}.
* @param {int_Optionnel} nbcar : Nombre maximal de caractres de la zone de texte.
* @version 2.4
* @date 14/11/2006
*/
function DefaultHtmlTextarea(id, cols, rows, tabindex, nbcar) {
  this.extend_DefaultHtml = DefaultHtml;
  this.extend_DefaultHtml(id, tabindex);

	/**
	* Attribut cols. Reprsente le nombre de caractres que peut contenir une ligne.
	* <br><br>
	* @private
	* @type int
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.cols=null;
  if (cols!=null) this.cols=cols;
  
	/**
	* Attribut rows. Reprsente le nombre de lignes.
	* <br><br>
	* @private
	* @type int
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.rows=null;
  if (rows!=null) this.rows=rows;
  
  /**
	* Attribut nbcar. Reprsente le nombre de caractres que peut contenir la zone de texte.
	* <br><br>
	* @private
	* @type int
	* @version 2.4
	* @date 14/11/2006
	*/  
  this.nbcar=null;
  if (DefaultHtmlTextarea.arguments.length>4){
	  this.nbcar=nbcar;
	 }
	  
  
	/**
	* Attribut disabled. Permet de crer un lment dsactiv, c'est--dire gris.
	* <br><br>
	* @private
	* @type boolean
	* @version 1.1
	* @date 25/10/2005
	*/   
  this.disabled=null;
  
	/**
	* Attribut readonly. Permet d'empcher l'utilisateur de modifier le texte entr par dfaut dans le champ.
	* <br><br>
	* @private
	* @type boolean
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.readonly=null;
}


//******************            DefaultHtmlA                 ***********************

/**
* Cre une instance de la classe DefaultHtmlA. 
* @class La classe <b>DefaultHtmlA</b> modlise le Tag &lt;a&gt;,
* reprsentant les liens hypertextes (ancrages, liens externes, etc...).
* <br><br><br><img src="Image.DefaultHtmlAUML.png"/><br><br><br>
* @public
* @constructor
* @param {String_Facultatif} href : href de l'lment, permettant d'indiquer l'adresse du lien.
* @version 1.1
* @date 25/10/2005
*/
function DefaultHtmlA(href) {
//  this.charset
//  this.coords

	/**
	* Attribut href. Permet d'indiquer l'adresse de direction lorsque l'on clique sur le lien.<br>
	* <b>Valeur par dfaut : </b> <a href='default-values_A3.html#DefaultHtmlAProp'>
	* Valeurs par dfaut des Proprits</a>
	* <br><br>
	* @public
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/
  this.href='javascript:alert("no href");';
  if (href!=null) this.href=href;
  
//  this.hreflang
//  this.name
//  this.rel
//  this.rev
//  this.shape
//  this.target  //TF
//  this.type
}


//******************            DefaultHtmlImg                 ***********************

/**
* Cre une instance de la classe DefaultHtmlImg. 
* @class La classe <b>DefaultHtmlImg</b> est une sous-classe de {@link DefaultHtml}. Elle hrite de 
* ses proprits (dcrivant les attributs HTML communs), et de ses mthodes.<br>
* <b>DefaultHtmlImg modlise le Tag &lt;img&gt;</b> (et ses 
* proprits et mthodes particulires), permettant d'insrer des images.
* <br><br><br><img src="Image.DefaultHtmlImgUML.png"/><br><br><br>
* @extends DefaultHtml
* @constructor
* @param {String_Facultatif} id : id de l'lment, hrit de {@link DefaultHtml}
* @param {int_Facultatif} height : attribut html height, permettant de spcifier la hauteur de l'image.
* @param {int_Facultatif} width : attribut html width, dfinissant la largeur de l'image en pixel.
* @param {int_Facultatif} tabindex : attribut html tabindex, hrit de {@link DefaultHtml}
* @param {String_Facultatif} title : attribut html String, permettant d'afficher une infobulle 
* lors du survol de l'image par le curseur. 
* @version 1.1
* @date 25/10/2005
*/  
function DefaultHtmlImg(id, height, width, tabindex, title) {
  this.extend_DefaultHtml = DefaultHtml;
  this.extend_DefaultHtml(id, tabindex);
  
	/**
	* Attribut alt. Permet d'afficher un texte alternatif lorsque l'image ne s'affiche pas.
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005	
	*/
  this.alt=null;
  
	/**
	* Attribut title. Permet d'afficher une infobulle lors du survol de l'image par le curseur.
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005	
	*/
  if (title!=null) {this.title=title;this.alt=title;}
  
	/**
	* Attribut src. Indique l'emplacement de l'image (obligatoire).
	* <br><br>
	* @public
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.src=null;

//  this.align=null;
//  this.border=null;

	/**
	* Attribut height. Permet de spcifier la hauteur de l'image.
	* <br><br>
	* @private
	* @type {String}
	* @version 1.1
	* @date 25/10/2005
	*/
  this.height=null;
  if (height!=null) this.height=height;
	//  this.hspace
	
	/**
	* Attribut ismap. Identifie l'image comme tant une image en coordonnes ct serveur.
	* <br><br>
	* @private
	* @type {String}
	* @version 1.1
	* @date 25/10/2005
	*/
  this.ismap=null;
  
	/**
	* Attribut longdesc. Spcifie l'URl de la description de l'image pour les navigateurs ne pouvant l'afficher.
	* <br><br>
	* @private
	* @type {String}
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.longdesc=null;
  
	/**
	* Attribut usemap. Spcifiant l'URL ou le nom de l'ancre dfinissant l'image qui va rgir 
	* lorsque l'utilisateur va cliquer dessus.
	* <br><br>
	* @private
	* @type {String}
	* @version 1.1
	* @date 25/10/2005
	*/   
  this.usemap=null;
  
//  this.vspace

	/**
	* Attribut width. Dfinit la largeur de l'image en pixel.
	* <br><br>
	* @private
	* @type {String}
	* @version 1.1
	* @date 25/10/2005
	*/ 
  this.width=null;
  if (width!=null) this.width=width;
  
	/**
	* La classe DefaultHtmlImg surcharge la mthode publique setTitle de DefaultHtml pour renseigner 
	* galement l'attribut HTML {@link DefaultHtmlImg#alt alt}.
	* <br><br>
	* @public
	* @param {String_Obligatoire} newTitle : attribut title  renseigner.
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.setTitle= function(newTitle) {
    this.title=newTitle;
    this.alt=newTitle;
  };
  
	/**
	* La mthode "getWidth" retourne la valeur de l'attribut "width".
	* <br><br>
	* @public
	* @param {aucun}
	* @return {Integer} Valeur de la proprit "width".
	* @version 2.5
	* @date 14/02/2007
	*/  
	this.getWidth = function() {
		return this.width;
  }
  
	/**
	* La mthode "setWidth" dfinit la valeur de l'attribut "width".
	* <br><br>
	* @public
	* @param {String_Obligatoire} newWidth : nouvelle valeur pour l'attribur "width".
	* @return void
	* @version 2.5
	* @date 14/02/2007
	*/  
	this.setWidth = function(newWidth) {
		this.width = newWidth;
  }

	/**
	* La mthode "getHeight" retourne la valeur de l'attribut "height".
	* <br><br>
	* @public
	* @param {aucun}
	* @return {String} Valeur de la proprit "height".
	* @version 2.5
	* @date 14/02/2007
	*/  
	this.getHeight = function() {
		return this.height;
  }
  
	/**
	* La mthode "setHeight" dfinit la valeur de l'attribut "height".
	* <br><br>
	* @public
	* @param {String_Obligatoire} newHeight : nouvelle valeur pour l'attribur "height".
	* @return void
	* @version 2.5
	* @date 14/02/2007
	*/  
	this.setHeight = function(newHeight) {
		this.height = newHeight;
  }  
 
}

//*************** Classes de dfinition des proprits et mthodes XML********************

/**
* Cre une instance de la classe DefaultXml. 
* <br><b>Voir Exemple d'appel au constructeur de l'lment pour hritage</b> : 
* <a href='exemples_A3.html#DefaultXml_constr'>Exemples d'appels aux constructeurs</a>.
* @see XMLObjectSauvegarde
* @class La classe <b>DefaultXml</b> gre la relation entre un lment de formulaire et sa source XML associe.
* Cette source contient les informations telles que la valorisation du champ de formulaire mais aussi le libell.<br>
* Il existe 2 types de structure XML, selon que l'lment de formulaire correspond  un champ mono value ou 
*  un champs multi values. Il n'existe pas de proprit publique pour cette classe.
* <br><br><br><img src="Image.DefaultXmlUML.png"/><br><br><br>
* @public
* @constructor
* @param {XMLObjectSauvegarde_Facultatif} xmlData {@link #xmlData xmlData} : reprsente les donnes XML
* associ  l'lment de formulaire. 
* @param {boolean_Facultatif} multi Boolen : indique s'il s'agit d'un lment mono (false) 
* ou multi-values (true), voir attribut {@link #multi multi}. 
* @version 1.1
* @date 25/10/2005
*/
 
function DefaultXml(xmlData, multi) {
	/**
	* Attribut VALUE_SELECTED. Reprsente la valeur de l'tat d'un lment multi-options lorsqu'il est 
	* slectionn. <b>Constante : </b> <a href='constant-values_A3.html#Prop'>Valeurs des Constantes 
	* - Proprits</a>
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/
  this.VALUE_SELECTED="TRUE";

	/**
	* Attribut VALUE_NO_SELECTED. Reprsente la valeur de l'tat d'un lment multi-options lorsqu'il n'est 
	* pas slectionn. <b>Constante : </b> <a href='constant-values_A3.html#Prop'>Valeurs des Constantes 
	* - Proprits</a>
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/
  this.VALUE_NO_SELECTED="FALSE";
  
	/**
	* Attribut xmlData. Reprsente les donnes XML associes  l'lment de formulaire,
	* utiles pour valoriser les attributs {@link #libelle libelle}, {@link #value value}. 
	* ou tabOption.
	* <br><br>
	* @private
	* @type XMLObjectSauvegarde
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.xmlData=null;
  if (xmlData!=null) this.xmlData=xmlData;
  
	/**
	* Attribut multi. Indique s'il s'agit d'un lment mono (false) ou multi-values (true).
	* - <b>Valeur par dfaut : </b> <a href='default-values_A3.html#DefaultXmlProp'>Valeurs 
	* par dfaut des Proprits</a><br>
	* - <b>Voir aussi Constante : MONO</b>, dfinissant pour DefaultXml un l'lment de type mono-value <a 
	* href='constant-values_A3.html#Globales'>Valeurs des Constantes - Globales</a>
	* <br><br>
	* @private
	* @type boolean
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.multi=MONO;
  if (multi!=null) this.multi=multi;
  
	/**
	* La mthode priv getXmlData() retourne la valeur de l'attribut xmlData (qui reprsente le contenu informatif
	* du flux XML associ  l'lment de formulaire).
	* <br><br>
	* @public
	* @param {} Aucun
	* @return {XMLObjectSauvegarde} attribut {@link #xmlData xmlData}.
	* @version 1.1
	* @date 25/10/2005
	*/ 
  this.getXmlData = function() { return this.xmlData; };
  
	// pour tous les lments mono value

	/* SQ 16/03/06- ATTENTION this.libelle; ne doit pas tre initialis : ceci pour corriger le pb des libells ne s'affichant pas en implmentation javascript
	   mais pour le faire apparatre en tant qu'attribut de la classe DefaultXml dans la jsdoc il faut le documenter de la faon suivante suite 
	   la classe : DefaultXml.prototype.libelle = null; Voir ci-aprs.
	 */
  this.libelle; 
  
	/* SQ 16/03/06- ATTENTION this.value; ne doit pas tre initialis : ceci pour corriger le pb des libells ne s'affichant pas en implmentation javascript
	   mais pour le faire apparatre en tant qu'attribut de la classe DefaultXml dans la jsdoc il faut le documenter de la faon suivante suite 
	   la classe : DefaultXml.prototype.value = null; Voir ci-aprs.
	 */ 
 	this.value; 
 	
	/**
	* La mthode prive setXmlDataMono() est utilise dans le cas d'un lment mono-value pour valoriser 
	* les attributs {@link #libelle libelle} et {@link #value value}  partir de de l'attribut xmlData 
	* dj renseign. <b>Voir Exemple de structure XML mono-value :</b><a href='exemples_A3.html#structXml'>
	* Exemples de structure XML</a>.
	* @private
	* @param {} Aucun
	* @return {void}	
	* @version 2.5
	* @date 10/11/2006	
	*/ 
  this.setXmlDataMono = function() {
    this.libelle=parent.getDataElement(this.xmlData.xmlDoc,"LIBELLE");	
    if (this.libelle == false) this.libelle="undefined";
    if (this.setValue)
    	this.setValue(parent.getDataElement(this.xmlData.xmlDoc,"VALUE"));
    else
    	this.value=parent.getDataElement(this.xmlData.xmlDoc,"VALUE");
    if (this.value == 'false') this.value="";
  };
  
	/* SQ 16/03/06- ATTENTION this.tabOption; ne doit pas tre initialis : ceci pour corriger le pb des libells ne s'affichant pas en implmentation javascript
	   mais pour le faire apparatre en tant qu'attribut de la classe DefaultXml dans la jsdoc il faut le documenter de la faon suivante suite 
	   la classe : DefaultXml.prototype.tabOption = null; Voir ci-aprs.
	 */ 
 	this.tabOption; 


  // pour tous les lments multi options
   	  
	/**
	* La mthode prive setXmlDataMulti() est utilise dans le cas d'un lment multi-value
	* pour valoriser les attributs {@link #libelle libelle} et tabOption  partir de l'attribut
	* xmlData dj renseign. <b>Voir Exemple de structure XML multi-value : </b> 
	* <a href='exemples_A3.html#structXml'>Exemples de structure XML</a>.
	* @private
	* @param {} Aucun
	* @return {void}	
	* @version 1.1
	* @date 25/10/2005	
	*/
  this.setXmlDataMulti = function() {
  	var xmlElements = parent.getChildElements(this.xmlData.xmlDoc, null);
  	if ((xmlElements == null) || (xmlElements.length == 0))
  		return;
  		
    var xmlElement = xmlElements[0];
    this.libelle=parent.getDataElement(xmlElement,"LIBELLE");
    if (this.libelle == false) this.libelle="undefined";
    
    var xmlOption=parent.getChildElements(xmlElement,"OPTIONS");
  	if ((xmlOption == null) || (xmlOption.length == 0))
  		return;
    
    var xmlOptions=xmlOption[0];
    var tabXml=parent.getChildElements(xmlOptions,"OPTION");
  	if ((tabXml == null) || (tabXml.length == 0))
  		return;

    this.tabOption=new Array();
    for (var i=0;i<tabXml.length;i++) {
      opt=new ObjectOption();
      opt.libelle=parent.getDataElement(tabXml[i],"LIBELLE");
      opt.value=parent.getDataElement(tabXml[i],"VALUE");
      if (parent.getDataElement(tabXml[i],"SELECTED",false) == this.VALUE_SELECTED ) opt.selected=true;
      this.tabOption.push(opt);
    }
  };
  
  
  // Mthode gnrale pour interprter xmlData
  
	/**
	* La mthode publique setXmlData() associe  un lment de formulaire des nouvelles donnes XML.
	* Elle renseigne l'attribut {@link #xmlData xmlData} de la classe DefaultXml, puis valorise les attributs 
	* {@link 'libelle' libelle}, {@link 'value' value}, ou 'tabOption' Selon qu'il s'agit 
	* d'un lment mono ou multi-values, cette mthode appellera soit {@link #setXmlDataMono 'setXmlDataMono()'}
	* soit {@link #setXmlDataMulti 'setXmlDataMulti()'}. Si l'argument 'newXmlData' n'est pas renseign, l'attribut
	* {@link #xmlData 'this.xmlData' } reste inchang.
	* @public
	* @param  {XMLObjectSauvegarde_Facultatif} newXmlData L'attribut xmlData  renseigner pour DefaultXml
	* @return {void}
	* @version 1.1
	* @date 25/10/2005
	*/
  this.setXmlData=function(newXmlData) {
    if (newXmlData!=null) this.xmlData=newXmlData;
    if (this.multi)
      this.setXmlDataMulti();
    else
      this.setXmlDataMono();
  };
  
  // traitement effectu par le constructeur
  if (this.xmlData!=null) this.setXmlData();
}


/**
* Attribut libelle. Repsente le libell de l'lment du formulaire susceptible 
* d'tre valoris par {@link #xmlData xmlData}.
* <br><br>
* @private
* @type String
* @version 1.1
* @date 25/10/2005
*/
DefaultXml.prototype.libelle = null;

/**
* Attribut value. Reprsente la valeur d'un  lment de formulaire de type mono-value.
* Correspond gnralement  la valeur(attribut value) de l'lment HTML. Cette attribut est renseign 
* avec les donnes de {@link #xmlData xmlData}.
* <br><br>
* @private
* @type String
* @version 1.1
* @date 25/10/2005
*/ 
DefaultXml.prototype.value = null;

/**
* Attribut tabOption. Reprsente le tableau d'options (ObjectOption) pour un lment de formulaire 
* de type multi-values. Ce tableau est renseign avec les donnes issues de {@link #xmlData xmlData}.
* <br><br><b>Version</b> 1.1 Date : 25/10/2005
* @private
* <br><br>
* @private
* @type ObjectOption
* @version 1.1
* @date 25/10/2005
*/ 
DefaultXml.prototype.tabOption = null;


//*********************** Classe de dfinition des libells*********************

/**
* Cre une instance de la classe DefaultLibelle.<br><b>Voir un exemple d'appel au constructeur de 
* l'lment pour hritage</b> : <a href='exemples_A3.html#DefaultLibelle_constr'>
* Exemples d'appels aux constructeurs</a>.
* @class La classe <b>DefaultHtmlLibelle</b> implmente la gestion, le positionnement et 
* l'affichage du libell d'un lment de formulaire.
* <br>Il n'existe pas de proprit publique pour cette classe.
* <br>Il n'existe pas de mthode prive pour cette classe.
* <br><br><br><img src="Image.DefaultLibelleUML.png"/><br><br><br>
* @public
* @constructor
* @param {String_Facultatif} libelle : libelle associ  l'lment de formulaire.
* @param {boolean_Facultatif} obligatoire : Boolen qui indique si le champ est obligatoire 
* et ncessite d'tre mis en vidence
* @version 1.1
* @date 25/10/2005
*/
function DefaultLibelle(libelle, obligatoire) {

	/**
	* Attribut libelle. Reprsente le libell associ  l'lment de formulaire.
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005	
	*/ 
  this.libelle = null;
  if (libelle!=null) this.libelle=libelle;
  
//  this.classLibelle=null;

	/**
	* Attribut obligatoire. Indique si le champ est obligatoire et ncessite d'tre mis en vidence.
	* - <b>Valeur par dfaut : </b> <a href='default-values_A3.html#DefaultLibelleProp'>
	* Valeurs par dfaut des Proprits</a>
	* <br><br>
	* @private
	* @type boolean
	* @version 1.1
	* @date 25/10/2005
	*/
  this.obligatoire=false;
  if (obligatoire!=null && obligatoire!="false") this.obligatoire=obligatoire;
  
	/**
	* Attribut codeObligatoire. Reprsente le Code html ajout au libell pour indiquer s'il s'agit 
	* d'un champ obligatoire.- <b>Valeur par dfaut : </b> <a href='default-values_A3.html#DefaultLibelleProp'>
	* Valeurs par dfaut des Proprits</a>
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.codeObligatoire="<span>* </span>";
  
//  this.boolSautDeLigne=false;

	/**
	* Attribut divLibelleBind. Reprsente l'id de la balise &lt;div&gt; susceptible d'accueillir le libell 
	* si celui-ci est dissoci du champ de saisie.
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/
  this.divLibelleBind=null;

  
  // mthodes 

	/**
	* La mthode publique getDivLibelleBind() retourne l'id de la balise HTML &lt;div&gt; susceptible 
	* d'accueillir l'lment courant.
	*- <b>Valeur par dfaut : </b> <a href='default-values_A3.html#DefaultLibelleMeth'>
	* Valeurs par dfaut des Mthodes</a>
	* @public
	* @param {} Aucun
	* @return {string} id de la balise HTML &lt;div&gt; susceptible d'accueillir le libell.
	* @version 1.1
	* @date 25/10/2005
	*/ 
  this.getDivLibelleBind=function() { if (this.divLibelleBind!=null) return this.divLibelleBind; else return ("Position_libelle_"+this.id);};

	/**
	* La mthode publique setDivLibelleBind() initialise l'attribut {@link #divLibelleBind divLibelleBind} 
	* avec une nouvelle valeur.
	* @public
	* @param {String_Obligatoire} newDivLibelleBind : Nouvel id (String) du tag &lt;div&gt; 
	* qui va recevoir le libell.
	* @return {void}
	* @version 1.1
	* @date 25/10/2005
	*/ 
  this.setDivLibelleBind=function(newDivLibelleBind) { this.divLibelleBind=newDivLibelleBind; };

	/**
	* La mthode publique getLibelle() retourne l'attibut libelle
	* @public
	* @param {} Aucun
	* @return {String} attribut libell
	* @version 2.5
	* @date 10/11/2006
	*/
	this.getLibelle=function(){return this.libelle;};

	/**
	* La mthode publique ecrireLibelleHtml() gnre le code HTML ncssaire pour afficher le libell et 
	* le retourne sous forme de caractres.
	* @public
	* @param {} Aucun
	* @return {string} code HTML du libell
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.ecrireLibelleHtml = 
    function() {
      var codeHTML="";
      if (this.libelle!=null)
        codeHTML+=this.libelle;
      if (this.obligatoire)
        codeHTML+=this.codeObligatoire;
      codeHTML+="\n";
      return codeHTML;
    };
}


//*************** Classes de dfinition de la structure ObjectOption********************
/**
* Cre une instance de la classe ObjectOption 
* @class La structure <b>ObjectOption</b> sert  dfinir chacune des options possibles pour les lments 
* multi-values.<br> Un lment multi-value est ainsi constitu d'un tableau d'options accessible via la 
* proprit tabOption : voir tabOption.
* <br><br>Il n'existe pas de proprit publique pour cette classe.<br>
* Il n'existe pas de mthode pour cette classe.
* <br><br><b> Fonctions globales utilisables :</b> Lors de l'utilisation de la classe ObjectOption, 
* le dveloppeur peut tre amener  utiliser la fonction globale <b>getRangOption()</b>
* dcrite dans la page {@link Fonctions_Globales#getRangOption}.
* <br><br><br><img src="Image.ObjectOptionUML.png"/><br><br><br>
* @public
* @constructor
* @param {String_Facultatif} libelle {@link #libelle Libell} de l'option.
* @param {String_Facultatif} value {@link #value Valeur} de l'option.
* @param {boolean_Facultatif} selected {@link #selected Boolen} : indique si l'option est slectionne.
* @param {String_Optionnel} positionLibelle {@link #selected Boolen} : indique, 
* dans le cas d'un bouton de type radio, le positionnement du libell par rapport au bouton radio.
* @version 1.1
* @date 25/10/2005
*/
function ObjectOption(libelle, value, selected) {

	/**
	* Attribut libelle. Reprsente le libell de l'option.
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/ 
  this.libelle="";
  
	/**
	* Attribut value. Reprsente la valeur de l'option.
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.value="";

	/**
	* Attribut selected. Reprsente le boolen qui indique si l'option est slectionne ou non.
	* <br><br>
	* @private
	* @type boolean
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.selected=false;
  if (libelle!=null) this.libelle=libelle; 
  if (value!=null) this.value=value; 
  if (selected!=null) this.selected=selected;

//  this.toString = function() { return ("lib = " + this.libelle + "; val = " + this.value + "; sel = " + this.selected); }; 

	/**
	* Attribut positionLibelle de ObjectOption, reprsentant sous la forme d'une chane numrique 
	* de 1  4 la position du libell par rapport au bouton radio (dans le cas ou cette option est partie 
	* intgrante d'un bouton radio), avec la correspondance suivante:<br>
	* - 1:  gauche <br>
	* - 2: au dessus <br>
	* - 3:  droite <br>
	* - 4: au dessous <br>
	* La valeur par dfaut est  null (libell  gauche du bouton radio). Si aucune information de 
	* positionnement n'est fournie par l'utilisateur, un positionnement  gauche sera adopt par dfaut.
	* <br><br>
	* @private
	* @type String
	* @version 2.4
	* @date 14/11/2006
	*/ 
	this.positionLibelle=null;
	
	if(ObjectOption.arguments.length>3)
	this.positionLibelle=ObjectOption.arguments[3];
}



//*************** Classes de dfinition des proprits et mthodes communes  tous les Elements********************

/**
* Cre une instance de la classe DefaultElementForm. <b>Voir Exemple d'appel au constructeur de l'lment 
* pour hritage:</b> <a href='exemples_A3.html#DefaultElementForm_constr'>Exemples d'appels aux constructeurs</a>.
* @see XMLObjectSauvegarde
* @see ObjectOption
* @class La classe <b>DefaultElementForm</b> est la classe de base de chacun des lments et composants 
* de formulaire du framework ergonomique. Elle regroupe les proprits et fonctionnalits les plus couramment 
* utilises. Cette classe impose aux lments qui en hritent, de respecter une certaine conformit. Mais rien n'empche 
* aux sous-lments de redfinir leurs propres mthodes. Il n'existe pas de proprit publique pour cette classe.
* <br><b>Fonctions globales utilisables :</b> lors de l'utilisation de la classe DefaultElementForm 
* par l'intermdiaire de ses classes drives, le dveloppeur peut tre amener  utiliser 
* la fonction globale <b>getDefaultElementById()</b> dcrite dans la page 
* {@link Fonctions_Globales#getDefaultElementById}.
* <br><br><br><img src="Image.DefaultElementFormUML.png"/><br><br><br>
* @public
* @constructor
* @param {String_Facultatif} id : id de l'lment. C'est l'identifiant de l'lment et aussi l'id de  
* l'lment HTML correspondant.
* @param {String_Facultative} value : value de l'lment. Utilis pour un l'lment mono-value, 
* il s'agit de la chane de caractre reprsentant la valeur de l'lment, correspond gnralement  l'attribut HTML 
* value du champ de formulaire.
* @param {ObjectOption_Facultatif} tabOption : tabOption de l'lment. Utilis pour un lment multi-values,
* il s'agit du tableau d'options (ObjectOption) ncessaire pour valoriser l'lment.
* @param {int_Facultatif} statut : statut de l'lment pour DefaultElementForm, qui dfinit le type d'affichage 
* de l'lment (ENABLED : normal, READONLY : non modifiable, DISABLED :  gris).
* @version 1.1
* @date 25/10/2005
*/
function DefaultElementForm(id, value, tabOption, statut) {

	// gnration d'id
	
	/**
	* Cette fonction propose par la classe DefaultElementForm est inutile pour le dveloppeur.
	* Elle permet de gnrer un nouvel id.
	* @private
	* @param{} Aucun
	* @return {string} id suivant
	* @version 1.1
	* @date 25/10/2005
	*/ 
  this.newId=function() {return ("elementFormId"+suffixeId++);};

	/**
	* Attribut readonly. Reprsente la chane de caractre "readonly" correspondant au statut.
	* <a href='constant-values_A3.html#DefaultElementForm'>STATUT_READONLY</a>
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/
	this.readonly=null;

	/**
	* Attribut disabled. Reprsente la chane de caractre "disabled" correspondant au statut.
	* <a href='constant-values_A3.html#DefaultElementForm'> STATUT_DISABLED</a>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/
	this.disabled=null;
  
  if (this.id==null) {  
   
    // si this.id n'a pas encore t dfini utltrieurement
	 
	  /**
	  * Attribut id. Reprsente l'identifiant de l'lment du formulaire et aussi l'id de l'lment 
	  * HTML correspondant.
	  * <br><br>
	  * @private
	  * @type String
	  * @version 1.1
	  * @date 25/10/2005
	  */
    this.id=this.newId(); // par dfaut
    if (id!=null) this.id=id;
  }  


  // attributs communs par dfaut

	/**
	* Attribut value. Chane de caractres utilise pour un lment mono-value reprsentant 
	* la valeur de l'lment : correspond gnralement  l'attribut HTML value du champ de formulaire.
	* -<b>Valeur par dfaut : </b> <a href='default-values_A3.html#DefaultElementFormProp'>
	* Valeurs par dfaut des Proprits</a>
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/ 
  this.value="";
  if (value!=null) this.value=value;
  
	/**
	* Attribut statut. Reprsente le statut de l'lment qui dfinit son type d'affichage. <br>
	* Peut prendre 3 valeurs dfinies par les constantes suivantes :<ul>
	* <li>STATUT_ENABLED (1) : le champ apparat normalement</li>
	* <li>STATUT_READONLY (2) : le champ n'est pas modifiable</li>
	* <li>STATUT_DISABLED (3) : le champ est gris</li></ul>
	* - <b>Valeur par dfaut : </b> 
	* <a href='default-values_A3.html#DefaultElementFormProp'>Valeurs par dfaut des Proprits</a>
	* - <b>Voir aussi <a href='constant-values_A3.html#Globales'>Valeurs des Constantes - Globales</a> :
	* STATUT_ENABLED, STATUT_DISABLED, STATUT_READONLY,STATUT_AFFICHAGE</b>, 
	* dfinissant pour DefaulElementForm le statut d'un l'lment de formulaire. 
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.statut=STATUT_ENABLED;
//  this.statut=STATUT_READONLY;
  if (statut!=null) this.statut=statut;
  
	/**
	* Attribut tabOption. Reprsente le tableau d'options (ObjectOption) ncessaire pour valoriser les lments
	* multi-valus. 
	* <br><br>
	* @private
	* @type ObjectOption
	* @version 1.1
	* @date 25/10/2005	
	*/  
  // this.tabOption=new Array();
  if (tabOption!=null) this.tabOption=tabOption;

	/**
	* Attribut reference. Reprsente la chane de caractre de rfrence  l'lment depuis l'extrieur de la classe.
	* -<b>Valeur par dfaut : </b> <a href='default-values_A3.html#DefaultElementFormProp'>
	* Valeurs par dfaut des Proprits</a>
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005		
	*/   
  this.reference="noRef";

	/**
	* Attribut onChange de DefaultElementForm, reprsentant le pointeur sur la fonction dclenche lors d'un 
	* vnement onChange ou onClick sur un composant formulaire. 
	* Il est par dfaut non valoris; valoris cette fonction permet d'activer la gestion de l'vnement.
	* <br><br>Le tableau ci-dessous recense les composants formulaire et le type d'vnement gr par cet attribut.
	* <table border="1" cellpadding="3" cellspacing="0" ><tr><td><b>Composant de formulaire</b></td>
	* <td><b>Type imput</b></td><td><b>Evnement gr</b></td></tr>
	* <tr class="TableRowColor"><td>ElementFormText</td><td>text</td><td>onChange</td></tr>
	* <tr class="TableRowColor"><td>ElementFormEmail</td><td>text</td><td>onChange</td></tr>
	* <tr class="TableRowColor"><td>ElementFormTextarea</td><td>textarea</td><td>onChange</td></tr>
	* <tr class="TableRowColor"><td>ElementFormPass</td><td>password</td><td>onChange</td></tr>
	* <tr class="TableRowColor"><td>ElementFormCheckbox</td><td>checkbox</td><td>onClick</td></tr>
	* <tr class="TableRowColor"><td>ElementFormRadio</td><td>radio</td><td>onClick</td></tr>
	* <tr class="TableRowColor"><td>ElementFormSelect</td><td>option</td><td><i>Non Autoris</i></td></tr>
	* <tr class="TableRowColor"><td>ElementFormSelectMaster</td><td>option</td><td><i>Non Autoris</i></td></tr>
	* <tr class="TableRowColor"><td>ElementFormHidden</td><td>hidden</td><td><i>Non Autoris</i></td></tr>
	* <tr class="TableRowColor"><td>ElementFormFile</td><td>file</td><td><i>Non Autoris</i></td></tr>
	* <tr class="TableRowColor"><td>ElementFormButton</td><td>text</td><td>onChange</td></tr></table>
	* <br><br>
	* @private
	* @type Function
	* @version 2.1
	* @date 20/06/2006		
	*/  
  this.onChange=null;
  
  /**
	* Attribut onblur. Reprsente le pointeur sur la fonction dclenche lors d'un vnement onblur 
	* sur un composant formulaire. Il est par dfaut non valoris, et valoriser cette fonction permet 
	* d'activer le gestion de l'vnement.
	* <br><br>Le tableau ci-dessous recense les composants formulaire et le type d'vnement gr par cet attribut.
	* <table border="1" cellpadding="3" cellspacing="0" ><tr><td><b>Composant de formulaire</b></td><td><b>Type imput</b></td><td><b>Evnement gr</b></td></tr>
	* <tr class="TableRowColor"><td>ElementFormText</td><td>text</td><td>onblur</td></tr>
	* <tr class="TableRowColor"><td>ElementFormEmail</td><td>text</td><td>onblur</td></tr>
	* <tr class="TableRowColor"><td>ElementFormTextarea</td><td>textarea</td><td>onblur</td></tr>
	* <tr class="TableRowColor"><td>ElementFormPass</td><td>password</td><td>onblur</td></tr>
	* <tr class="TableRowColor"><td>ElementFormCheckbox</td><td>checkbox</td><td>onblur</td></tr>
	* <tr class="TableRowColor"><td>ElementFormRadio</td><td>radio</td><td>onblur</td></tr>
	* <tr class="TableRowColor"><td>ElementFormSelect</td><td>option</td><td><i>Non Autoris</i></td></tr>
	* <tr class="TableRowColor"><td>ElementFormSelectMaster</td><td>option</td><td><i>Non Autoris</i></td></tr>
	* <tr class="TableRowColor"><td>ElementFormHidden</td><td>hidden</td><td><i>Non Autoris</i></td></tr>
	* <tr class="TableRowColor"><td>ElementFormFile</td><td>file</td><td><i>Non Autoris</i></td></tr>
	* <tr class="TableRowColor"><td>ElementFormButton</td><td>text</td><td>Non Autoris</td></tr></table>
	* <br><br>
	* @private
	* @type Function
	* @version 2.1
	* @date 20/06/2006
	*/ 
  this.onblur=null;
  
	/**
	* Attribut formParent. Reprsente le pointeur vers le composant formulaire parent. Il est automatiquement 
	* renseign lors de l'ajout de l'lment  un composant de type {@link ComposantForm ComposantForm}.
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.formParent=null;
  
  /**
	* Proprit prive ongletParent. Reprsente le pointeur vers l'onglet du composant bandeau parent dans le cas
	* ou cet lment est associ  un composant bandeau.<br>
	* Il est renseign et lu manuellement via les deux mthodes getOngletParent() et setOngletParent(String ongPar).
	* @private
	* @type String
	* @version 2.4
	* @date 14/11/2006
	*/  
  this.ongletParent=null;

 /**
	* Proprit prive zoneData. Reprsente le nom de la balise XML associe  un lment de formulaire
	* dans le flux de description des donnes. Cet attribut est utilis lors de la gnration automatique
	* de formulaires.<br>
	* @private
	* @type String
	* @version 3.0
	* @date 01/05/2007
	*/  
  this.zoneData=null;

	/**
	* La proprit prive urlAide correspond  l'url de la page d'aide associe  l'lment.<br>
	* Elle sert  crer le code HTML supplmentaire en cas de page d'aide existante (afficher
	* image d'aide avec un lien).<br> L'url peut etre sous forme de lien vers une page html cre par l'utilisateur,
	* ou sous la forme de chemin dans le fichier XML d'aide separ par des slashs et prcd de 'aide:' (aide:tag1/tag2/tag3...). 
	* Dans le premier cas, le bouton d'aide ouvrira sur la page qui lui est affecte. Dans le second cas, le bouton sera
	* li  la page d'aide par dfaut, il ouvrira alors sur l'arborescence ouverte et affichera la page d'aide
	* correspondante qui a t dclare dans le fichier XML.
	* <br><br>
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.urlAide = null;

	/**
	* La proprit prive altAide correspond au texte alternatif de l'icone d'aide.
	* <br><br>
	* @private
	* @type string
	* @version 2.5
* @date 14/02/2007
	*/
	this.altAide = "";

	/**
	* La proprit prive lienAide correspond aux options de lien vers une page d'aide: 
	* <br> - LIEN_AIDE_BOUTTON (0) : Depuis un bouton d'aide
	* <br> - LIEN_AIDE_LIBELLE (1) : Depuis le libell de l'lement de formulaire
	* <br> - LIEN_AIDE_BOUTON_LIBELLE (2) : Depuis le bouton d'aide et le libell de l'lment de formulaire
	* <br><br>
	* @private
	* @type Number
	* @version 2.5
* @date 14/02/2007
	*/
	this.lienAide = null;

	/**
	* La proprit prive urlAssist correspond  l'url de la page d'assistznt associe  l'lment.<br>
	* Elle sert  crer le code HTML supplmentaire en cas de page d'assistant existante (afficher
	* image d'assistant avec un lien).<br> L'url peut etre sous forme de lien vers une page html cre par l'utilisateur,
	* ou sous la forme de chemin dans le fichier XML d'aide separ par des slashs et prcd de 'aide:' (aide:tag1/tag2/tag3...). 
	* Dans le premier cas, le bouton d'assistant ouvrira sur la page qui lui est affecte. Dans le second cas, le bouton sera
	* li  la page d'assistant par dfaut, il ouvrira alors sur l'arborescence ouverte et affichera la page d'aide
	* correspondante qui a t dclare dans le fichier XML.
	* <br><br>
	* @private
	* @type string
	* @version 2.5
* @date 14/02/2007
	*/
	this.urlAssist = null;

	/**
	* La proprit prive altAssist correspond au texte alternatif de l'icone d'assistant.
	* <br><br>
	* @private
	* @type string
	* @version 2.5
* @date 14/02/2007
	*/
	this.altAssist = "";

	/**
	* La proprit prive bulleInfo contient un pointeur vers un objet de type ComposantBulle 
	* rattacher  l'lment de formulaire.
	* <br><br>
	* @private
	* @type ComposantBulle
	* @version 2.5
* @date 14/02/2007
	*/
	this.bulleInfo = null;

	/**
	* La proprit prive posBulleInfo dtermine la position de la bulle dans le contrle :
	* - POS_BULLE_BOITE (1) : La bulle s'affichera au niveau de l'lment lui-mme (par dfaut).<br> 
	* - POS_BULLE_AIDE (2) : La bulle s'affichera au niveau du bouton d'aide.<br>
	* <br><br>
	* @private
	* @type Integer
	* @version 2.5
* @date 14/02/2007
	*/
	this.posBulleInfo = POS_BULLE_BOITE;

	/**
	* La proprit protge onMouseOut contient les intructions JavaScript  excuter lors du
	* dclenchement de l'vnement onMouseOut (sortie de la souris de la zone de l'lement).
	* <br><br>
	* @protected
	* @type Function
	* @version 2.5
* @date 14/02/2007
	*/
	this.onMouseOut = null;
	
	/**
	* La proprit protge onMouseOver contient les intructions JavaScript  excuter lors du
	* dclenchement de l'vnement onMouseOver (entre de la souris sur la zone de l'lement).
	* <br><br>
	* @protected
	* @type Function
	* @version 2.5
* @date 14/02/2007
	*/
	this.onMouseOver = null;

	/**
	* La proprit protge onMouseMove contient les intructions JavaScript  excuter lors du
	* dclenchement de l'vnement onMouseMove (dplacement de la souris sur la zone de l'lement).
	* <br><br>
	* @protected
	* @type Function
	* @version 2.5
* @date 14/02/2007
	*/
	this.onMouseMove = null;

	/**
	* La proprit protge onMouseMoveBoutonAide contient les intructions JavaScript  excuter lors du
	* dclenchement de l'vnement onMouseMove (dplacement de la souris sur la zone du bouton d'aide 
	* de l'lment).
	* <br><br>
	* @protected
	* @type Function
	* @version 2.5
* @date 14/02/2007
	*/
	this.onMouseMoveBoutonAide = null;

	/**
	* La mthode publique setAltAide permet de dfinir le texte alternatif de l'icone d'aide.
	* <br><br>
	* @public
	* @param {} Aucun.
	* @return {string}
	* @version 2.5
* @date 14/02/2007
	*/
	this.setAltAide = function(texteAlt){this.altAide = texteAlt;}
		
  /**
	* Mthode publique geturlAide permet d'accder  la proprit prive "urlAide".
	* @public
	* @param {} Aucun.
	* @return {string}
	* @version 2.4
	* @date 14/11/2006
	*/  
	this.geturlAide=function(){
		return this.urlAide
	}
	
	/**
	* Mthode publique seturlAide permet de renseigner  la proprit prive "urlAide".
	* @public
	* @param {String Facultatif} url de la page d'aide que l'on veut associer  l'lment, ou chemin 
	* XML sous la forme "aide:item1/.../itemN".
	* @param {Number Optionnel} lien : met  jour l'atribut <a href='DefaultElementForm.html#lienAide'>
	* lienAide</a>, LIEN_AIDE_BOUTTON par dfaut. 
	* @return {void}
	* @version 2.5
* @date 14/02/2007
	*/  
	this.seturlAide=function(url,lien){
		
		if(url!=null){
			this.urlAide=url;
			if(this.lienAide == null || this.lienAide == -1)
				this.lienAide = LIEN_AIDE_BOUTTON;
		}
		if(lien >= 0){
			this.lienAide=lien;
		}
	}
	
		/**
	* La mthode publique setAltAssist permet de dfinir le texte alternatif de l'icone d'assistant.
	* <br><br>
	* @public
	* @param {} Aucun.
	* @return {string}
	* @version 2.5
* @date 14/02/2007
	*/
	this.setAltAssist = function(texteAlt){this.altAssist = texteAlt;}
		
  /**
	* Mthode publique geturlAssist permet d'accder  la proprit prive "urlAssist".
	* @public
	* @param {} Aucun.
	* @return {string}
	* @version 2.5
* @date 14/02/2007
	*/  
	this.geturlAssist=function(){
		return this.urlAssist
	}
	
	/**
	* Mthode publique seturlAssist permet de renseigner  la proprit prive "urlAssist".
	* @public
	* @param {String Facultatif} url de la page d'aide que l'on veut associer  l'lment, ou chemin 
	* XML sous la forme "aide:item1/.../itemN".
	* @return {void}
	* @version 2.5
* @date 14/02/2007
	*/  
	this.seturlAssist=function(url){
		if(url!=null){
			this.urlAssist=url;
		}
	}
	
  /**
	* Mthode publique getOngletParent. Permet d'accder  la proprit prive "ongletParent".
	* @public
	* @param {} Aucun
	* @return {string}
	* @version 2.4
	* @date 14/11/2006
	*/  
	this.getOngletParent=function(){
		return this.ongletParent
	}

  /**
	* Mthode publique setOngletParent. Permet de renseigner la proprit prive "ongletParent".
	* @public
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/  
	this.setOngletParent=function(ongPar){
		this.ongletParent=ongPar;
	}

	/**
	* Mthode publique getZoneData. Permet d'accder  la proprit prive "zoneData".
	* @public
	* @param {} Aucun
	* @return {string}
	* @version 3.0
	* @date 01/05/2007
	*/  
	this.getZoneData=function(){
		return this.zoneData;
	}

  /**
	* Mthode publique setZoneData. Permet de renseigner la proprit prive "zoneData".
	* @public
	* @return {void}
	* @version 3.0
	* @date 01/05/2007
	*/  
	this.setZoneData=function(zoneData){
		this.zoneData=zoneData;
	}

  // Mthodes communes


  // accesseur de l'lment du DOM HTML correspondant
  
	/**
	* La mthode publique getDomHtmlElement() retourne un pointeur (issu du DOM HTML) sur l'lment HTML gnr.
	* @public
	* @param {} Aucun
	* @return {DomHtmlElemet} pointeur sur l'lment HTML gnr.	
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.getDomHtmlElement = function() { return document.getElementById(this.id);};


  // acccesseur pour un lment mono-value

	/**
	* La mthode publique getValue() retourne la valeur courante de l'lment pour un lment mono-value.
	* @public
	* @param {} Aucun
	* @return {object} la valeur courante de l'lment.
	* @version 1.1
	* @date 25/10/2005
	*/ 
  this.getValue = function() { 
    var elm = this.getDomHtmlElement();
    if (elm!=null){
      // si l'lment html est deja gnr, on l'interroge
      this.value=elm.value; // mise  jour de la proprit de l'lment
    }
    return this.value;
  };

	/**
	* La mthode publique setValue(NewValue) renseigne l'attribut {@link #value value} et met  jour 
	* l'lment HTML associ (si celui-ci est dj gnr), pour un lment mono-value.
	* @public
	* @param { String_Obligatoire} newValue Nouvelle valeur  appliquer  l'lment.
	* @return {void}
	* @version 1.1
	* @date 25/10/2005
	*/   
  this.setValue = function(newValue) {
    this.value=newValue.toString();
    var elm = this.getDomHtmlElement();
    if (elm!=null) elm.value=this.value;
  };


  // acccesseur pour un lment multi-values

	/**
	* La mthode publique getTabOption() retourne false et <span style="color: rgb(0, 153, 0);">
  * est  implmenter dans les classes drives</span>. Elle doit retourner le tableau des lments
	* multi-value.<br>
	* - <b>Valeur par dfaut : </b> <a href='default-values_A3.html#DefaultElementFormMeth'>
	* Valeurs par dfaut des Mthodes</a>
	* @public
	* @param {} Aucun
	* @return {false}
	* @version 1.1
	* @date 25/10/2005
	*/ 
  this.getTabOption=function() { return false; /* implmenter dans les classes drives*/};

	/**
	* La mthode publique setTabOption(newTabOPtion) renseigne l'attribut tabOption et 
	* regnre l'lment HTML associ si celui-ci est dj gnr, pour un lment multi-value.
	* @public
	* @param {ObjectOption_Obligatoire} newTabOption : nouvelle valeur  appliquer  l'lment.
	* @return {void}
	* @version 1.1
	* @date 25/10/2005
	*/   
  this.setTabOption=function(newTabOption) {
    this.tabOption=newTabOption;
    // si l'lment est gnr alors on le rgnre
    if (this.getDomHtmlElement()!=null) this.ecrireBind();
  };

	/**
	* La mthode publique setBulleInfo(bulle, position) renseigne les attributa {@link #bulleInfo bulleInfo}
	* , {@link #posBulleInfo posBulleInfo} et valorise les vnements onMouseOver, onMouseOut et onMouseMouse (selon le type de bulle)
	* de l'lment associ. Cette mthode regnre l'lment HTML associ si celui-ci a dj t gnr.<br>
  * Les valeurs possibles pour la position de la bulle sont :<br>
	* - POS_BULLE_BOITE (1) : La bulle s'affichera au niveau de l'lment lui-mme (par dfaut).<br> 
	* - POS_BULLE_AIDE (2) : La bulle s'affichera au niveau du bouton d'aide.<br>
	* @public
	* @param {ComposantBulle_Obligatoire} bulle : ComposantBulle  rattacher  l'lment de formulaire.
	* @param {ComposantBulle_Facultatif} position : Position de la bulle dans le composant.
	* @return {void}
	* @version 2.5
* @date 14/02/2007
	*/   
  this.setBulleInfo = function(bulle, position) {
    // Renseignement des l'attributs
    this.bulleInfo = bulle;
		if (position == null || position == -1)
			this.posBulleInfo = POS_BULLE_BOITE;
		else
			this.posBulleInfo = position;
				    
    // Paramtrage de l'lment courant et de la bulle
    if (this.bulleInfo != null) {
    
      // Positionnement de la bulle de type POS_BULLE_BOITE
      if (this.posBulleInfo == POS_BULLE_BOITE) {
		    	this.onMouseOver = function () {this.bulleInfo.montrer();};
					this.onMouseOut = function () {this.bulleInfo.cacher();};
					if (this.bulleInfo.type == TYPE_BULLE_FLOTTANTE)
							this.onMouseMove = function (e) {eval("composantBulleOnMouseMove(e, " + this.reference + ".bulleInfo);");};
    			this.bulleInfo.setDefaultHtmlElementForm(this); // La bulle est lie  l'lment courant
			}
    								
			// Si l'lment est dj gnr, on le rgnre
      if (this.getDomHtmlElement() != null)
        this.ecrireBind();
    }
  };
  
	// positionnement dans la page html

	/**
	* L'attribut divBind reprsente l'attribut HTML id du tag &lt;div&gt; qui va recevoir l'lment.
	* Par dfaut cette proprit vaut : Position_ + this.id.
	* - <b>Valeur par dfaut : </b> <a href='default-values_A3.html#DefaultElementFormProp'>
	* Valeurs par dfaut des Proprits</a>
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/
  this.divBind="Position_"+this.id;
  
	/**
	* La mthode publique getDivBind() retourne l'attribut {@link #divBind 'divBind'}, c'est  dire
	* l'id de la balise HTML &lt;div&gt; susceptible d'accueillir l'lment courant.
	* @public
	* @param {} Aucun
	* @return {string} l'attribut {@link #divBind 'divBind'}.
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.getDivBind=function() { return this.divBind; };
  
	/**
	* La mthode publique setDivBind(newDivBind) initialise l'attribut {@link #divBind 'divBind'} 
	* avec une nouvelle valeur.
	* @public
	* @param {String_Obligatoire} newDivBind : nouvel id (string) du tag &lt;div&gt; qui va recevoir l'lment.
	* @return {void}
	* @version 1.1
	* @date 25/10/2005
	*/
  this.setDivBind=function(newDivBind) { this.divBind=newDivBind; };
  
  
	// mthode pour gnrer le code html de l'image d'aide
	/**
	* La mthode prive ouvrirAide() initialise la variable globale {@link #currentAide 'currentAide'}
	* et ouvre la fentre de page d'aide, soit sur l'urlAide du DefaultElementForm, soit
	* sur l'url d'aide par defaut. 
	* @private
	* @param {} Aucun
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/
	this.ouvrirAide=function()
	{
		currentAide=this;
		if(this.urlAide.search(/aide:/) == -1){
		OpenWindowFocus(this.urlAide, "Aide", "alwaysRaised, dependent, height=500, width=1024, scrollbars=yes, resizable=yes, toolbar=yes, screenX=10, screenY=10");
    }else{
    	OpenWindowFocus(urlHtmlAide, "Aide", "alwaysRaised, dependent, height=500, width=1024, scrollbars=yes, resizable=yes, toolbar=yes, screenX=10, screenY=10");
    }
	};
	
	// mthode pour gnrer le code html de l'image d'assistant
	/**
	* La mthode prive ouvrirAssistant() initialise la variable globale {@link #currentElementAssistant 'currentElementAssistant'}
	* et ouvre la fentre de page d'assistant, soit sur l'urlAssistant du DefaultElementForm, soit
	* sur l'url d'assistant par defaut. 
	* @private
	* @param {} Aucun
	* @return {void}
	* @version 2.5
* @date 14/02/2007
	*/
	this.ouvrirAssistant=function()
	{
		currentElementAssistant=this;
		if(this.urlAssist.search(/aide:/) == -1){
		OpenWindowFocus(this.urlAssist, "Assistant", "alwaysRaised, dependent, height=500, width=1024, scrollbars=yes, resizable=yes, toolbar=yes, screenX=10, screenY=10");
    }else{
    	OpenWindowFocus(urlHtmlAssistant, "Assistant", "alwaysRaised, dependent, height=500, width=1024, scrollbars=yes, resizable=yes, toolbar=yes, screenX=10, screenY=10");
    }
	};
	
	/**
	* La mthode prive ecrireAideHtml() cre le code HTML de l'image d'aide et des actions qui lui sont
	* associes. Elle est appele dans la mthode {@link #ecrireBind 'ecrireBind'}.
	* @private
	* @param {} Aucun
	* @includeCSS globale.css
	* @return {string}
	* @version 2.4
	* @date 14/11/2006
	*/   
  this.ecrireAideHtml = function() {
    	// Vrification de la prsence de l'aide
    	if (this.urlAide == null && (this.bulleInfo == null || (this.bulleInfo != null && this.posBulleInfo != POS_BULLE_AIDE)))
    		return "";
    	
    	var codeHTML = "";    	
    	if(this.lienAide == LIEN_AIDE_BOUTTON || this.lienAide == LIEN_AIDE_BOUTON_LIBELLE){				
		  		codeHTML +='&nbsp;<a id="a' + this.id + '" href="javascript:'+this.reference+'.ouvrirAide();"';
 					// Dfinition de l'info bulle sur le bouton d'aide si ncessaire
 					if (this.posBulleInfo == POS_BULLE_AIDE) {
				      codeHTML += ' onMouseOver="javascript:document.getElementById(\'icoAide'+ this.id +'\').src=\''+img_aideOver+'\';'+this.reference+'.bulleInfo.montrer();"';
				      codeHTML += ' onMouseOut="javascript:document.getElementById(\'icoAide'+ this.id +'\').src=\''+img_aide+'\';'+this.reference+'.bulleInfo.cacher();"';
				      // Redfinition de l'vnement onMouseMove pour une bulle flottante  
							this.onMouseMoveBoutonAide = function (e) {eval("composantBulleOnMouseMove(e, " + this.reference + ".bulleInfo);");};
				      if (this.bulleInfo.type == TYPE_BULLE_FLOTTANTE)
				       		codeHTML += ' onMouseMove="javascript:'+this.reference+ '.onMouseMoveBoutonAide(event)"';
 					} else {
							// Pas d'info bulle sur le bouton d'aide, juste la gestion de l'image du bouton sera effectue
			 				codeHTML += ' onMouseOver="javascript:document.getElementById(\'icoAide'+ this.id +'\').src=\''+img_aideOver+'\';"';
			 				codeHTML += ' onMouseOut="javascript:document.getElementById(\'icoAide'+ this.id +'\').src=\''+img_aide+'\';"';
					}
		  		// Ecriture de l'image du bouton d'aide
		  		codeHTML += '><img width="18px" height="18px" id="icoAide' + this.id + '" src="' + img_aide +'" border="0" alt="' + this.altAide + '" title="' + this.altAide + '">';
		  		codeHTML += '</a>';
    	} else if (this.bulleInfo != null && this.posBulleInfo == POS_BULLE_AIDE) {
    			// Dfinition de l'info bulle sur le bouton d'aide sans lien d'aide sur le bouton
   	  		codeHTML +='&nbsp;<a id="a' + this.id + '" href="#" ';
		      codeHTML += ' onMouseOver="javascript:document.getElementById(\'icoAide'+ this.id +'\').src=\''+img_aideOver+'\';'+this.reference+'.bulleInfo.montrer();"';
					codeHTML += ' onMouseOut="javascript:document.getElementById(\'icoAide'+ this.id +'\').src=\''+img_aide+'\';'+this.reference+'.bulleInfo.cacher();"';
					// Redfinition de l'vnement onMouseMove pour une bulle flottante
					this.onMouseMoveBoutonAide = function (e) {eval("composantBulleOnMouseMove(e, " + this.reference + ".bulleInfo);");};
		      if (this.bulleInfo.type == TYPE_BULLE_FLOTTANTE)
		       		codeHTML += ' onMouseMove="javascript:'+this.reference+ '.onMouseMoveBoutonAide(event)"';
					// Ecriture de l'image du bouton d'aide
		  		codeHTML += '><img width="18px" height="18px" id="icoAide' + this.id + '" src="' + img_aide +'" border="0" alt="' + this.altAide + '" title="' + this.altAide + '">';
		  		codeHTML += '</a>';
    	}
    	
    	// Ajout du lien sur le libelle de l'lment de formulaire
    	if(this.lienAide == LIEN_AIDE_LIBELLE || this.lienAide == LIEN_AIDE_BOUTON_LIBELLE){
    			var leCodeHTML=document.getElementById(this.getDivLibelleBind()).innerHTML;
    			leCodeHTML="<a class='aide' href='javascript:"+this.reference+".ouvrirAide();'>" + leCodeHTML + "</a>";
    			document.getElementById(this.getDivLibelleBind()).innerHTML=leCodeHTML;
    	}
    	return codeHTML;
    };
    
	/**
	* La mthode publique setPositionBulleInfo(position) dfini la position de la bulle d'aide lie
	* au composant courant. Les valeurs possibles sont :<br>
	* - POS_BULLE_BOITE (1) : La bulle s'affichera au niveau de l'lment lui-mme (par dfaut).<br> 
	* - POS_BULLE_AIDE (2) : La bulle s'affichera au niveau du bouton d'aide.<br>
	* @public
	* @param {Integer_Obligatoire} Position : constante POS_BULLE_BOITE ou POS_BULLE_AIDE
	* @return {void}
	* @version 2.5
* @date 14/02/2007
	*/   
  this.setPositionBulleInfo = function(position) {
			this.setBulleInfo(this.bulleInfo, position);
  };     
    
  /**
	* La mthode prive ecrireAssistHtml() cre le code HTML de l'image d'assistant et des actions qui lui sont
	* associes. Elle est appele dans la mthode {@link #ecrireBind 'ecrireBind'}.
	* @private
	* @param {} Aucun
	* @includeCSS globale.css
	* @return {string}
	* @version 2.5
* @date 14/02/2007
	*/   
  this.ecrireAssistHtml = 
    function() {
    	if(this.urlAssist == null) {return '';}
    	var codeHTML='';    	
    	codeHTML +='&nbsp;<a id="a' + this.id + '" href="javascript:'+this.reference+'.ouvrirAssistant();"';
      codeHTML += ' onMouseOver="javascript:document.getElementById(\'icoAssist'+ this.id +'\').src=\''+img_assistOver+'\';"';
      codeHTML += ' onMouseOut="javascript:document.getElementById(\'icoAssist'+ this.id +'\').src=\''+img_assist+'\';">';
      codeHTML += '<img width="18px" height="18px" id="icoAssist' + this.id + '" src="' + img_assist +'" border="0" alt="' + this.altAssist + '" title="' + this.altAssist + '"/>';
    	codeHTML += '</a>';
    	return codeHTML;
    };
    
    
	// mthode pour gnrer et positionner le code html
	
	/**
	* La mthode publique ecrireBind() appelle la gnration du code HTML du libell, 
	* puis la gnration du code HTML de la bote (lment de saisie). Elle place l'un et l'autre dans 
	* les balises &lt;div&gt; appropries.<br> L'association avec la balise &lt;div&gt; se fait par 
	* la proprit {@link #divBind 'divBind'} pour la boite et {@link #divLibelleBind 'divLibelleBind'} pour 
	* le libell. Si {@link #divLibelleBind 'divLibelleBind'} n'est pas trouv dans la page HTML, 
	* le libell est alors positionn avec la bote.
	* 31/09/2006 : Correction de l'affichage du contrle dans le cas de libell/divLibell vide/inexistant.
	* 10/11/2006 : Affichage possible d'un lien vers une page d'aide
	* 14/11/2006 : Affichage possible d'un lien vers une page d'assistant
	* @public
	* @param {} Aucun
	* @return {void}
	* @version 2.5
* @date 14/02/2007
	*/   
  this.ecrireBind = 
    function() {
      // Verification de l'existance de la div de la boite
      if (document.getElementById(this.getDivBind()) != null) {
        // div de la boite
        var element = document.getElementById(this.getDivBind());
        var codeHTMLElement = "";
        // Vrification de l'existance de la div du libelle
        if ((this.getDivLibelleBind == null) || (document.getElementById(this.getDivLibelleBind()) == null)) {
       		// Div du libell inexistante
       		if (this.ecrireHtml != null)
       			if (this.libelle != "undefined")
       				codeHTMLElement += this.ecrireHtml();  // libell et boite renseign
       			else if(this.ecrireBoiteHtml!=null)
       			  codeHTMLElement += this.ecrireBoiteHtml(); // libell vide
       			else
       				codeHTMLElement +="";
       		else       		
          	codeHTMLElement += "";  // Boite vide
        } else {
          // div du libell existante
          var elementlib = document.getElementById(this.getDivLibelleBind());
	        // Affichage de la boite
	        if ((this.ecrireBoiteHtml != null)) {
	        	codeHTMLElement += this.ecrireBoiteHtml();
					  // Affichage du libell
	          if ((this.libelle != "undefined") && this.ecrireLibelleHtml != null)
		          elementlib.innerHTML = this.ecrireLibelleHtml();
	          else 
		          elementlib.innerHTML = "";	        	
	        } else {
	        	elementlib.innerHTML = "";
	        	codeHTMLElement = "";
	        }
        } 
        
        var codeHTMLAide = this.ecrireAideHtml();
        var codeHTMLAssist = this.ecrireAssistHtml();
        if (codeHTMLAide == "" && codeHTMLAssist == "")
	        element.innerHTML = codeHTMLElement;
	      else {
	        var codeHTML = "<table border='0'><tr><td>";
	        codeHTML += codeHTMLElement;
	        if (codeHTMLAide != ""){
	        	codeHTML += "</td><td valign='center'>";
	        	codeHTML += codeHTMLAide;
	        }
	        if (codeHTMLAssist != ""){
	        	codeHTML += "</td><td valign='center'>";
	        	codeHTML += codeHTMLAssist;
	        }
        	codeHTML += "</td></tr></table>";
	        element.innerHTML = codeHTML;
	      }
      } 
      if (this.ecrireEsclaveBind!=null) this.ecrireEsclaveBind();
      
      // Mise  jour du composant bulle positionn sur le bouton aide
      // (attente de l'affectation du innerHTML pour atteindre l'image du bouton aide). 
      if (this.bulleInfo != null && this.posBulleInfo == POS_BULLE_AIDE) {
					this.bulleInfo.setHtmlElement(document.getElementById("icoAide" + this.id), element, this.reference);
			}
  };
        
  // mthode pour gnrer le code HTML 
    
	/**
	* La mthode publique ecrireHtml() assemble le code HTML du libell et le code HTML de la boite.
	* Le tout est retourn sous forme d'une chane de caractres.
	* @public
	* @param {} Aucun 
	* @return {string} retourne le code HTML (libelle+boite) de l'objet sous forme d'une chane de caractres.
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.ecrireHtml = 
    function() {
      var codeHTML="";
      if (this.ecrireLibelleHtml!=null) codeHTML+=this.ecrireLibelleHtml();
      if (this.ecrireBoiteHtml!=null) codeHTML+=this.ecrireBoiteHtml();      
      return codeHTML;
    };
    
  //this.ecrireHiddenHtml = function() {return "";};  //  implmenter si besoin
  //this.ecrireLibelleHtml = function() { return ""; }; //  implmenter si besoin
  //this.ecrireBoiteHtml = function() { return ""; }; //  implmenter si besoin
  
  // interprtation du statut
  
	/**
	* La mthode publique setStatut(newStatut, update) initialise l'attribut {@link #statut statut} 
	* avec une nouvelle valeur, renseigne les attributs {@link #readonly readonly} et {@link #disabled disabled}
	* et regnre l'lment HTML associ si le paramtre update est vrai.
	* @public
	* @param { int_Obligatoire} newStatut Nouveau statut  appliquer  l'lment.
	* @param { boolean_Facultatif} update Boolen qui indique si le champ est  mettre  jour ou non.
	* @return {void}
	* @version 1.1
	* @date :  25/10/2005
	*/   
  this.setStatut = function (newStatut, update) {
    if (update==null) update=true;
    if (newStatut!=null) this.statut=newStatut;
    if (this.statut==STATUT_ENABLED) {
        this.readonly=null;
        this.disabled=null;
    }
    else if (this.statut==STATUT_READONLY) {
        this.readonly="readonly";
        this.disabled=null;
    }
    else if (this.statut==STATUT_DISABLED) {
        this.readonly=null;
        this.disabled="disabled";
    }
    
    if (update==true) {
      if (this.getDomHtmlElement()!=null) {
        //si l'lment HTML existe on rcupre la valeur courante et on rgnre 
        if (this.getValue!=null) {
          this.getValue();
        } 
        if (this.getTabOption!=null) this.getTabOption();
        this.ecrireBind();
      }  
    }
  };  
  this.setStatut(this.statut); // on applique l'interprtation du statut  


  // dclaration de la fonction porte par l'attribut OnChange

	/**
	* La mthode publique setOnChange(newFonction,update) initialise l'attribut {@link #onChange onChange} 
	* avec une nouvelle valeur, et regnre l'lment HTML associ si le paramtre update est vrai. L'attribut 
	* n'est pas initialis si le composant sur lequel on appelle la mthode ne peut faire l'objet d'un vnement 
	* de type onChange ou onClick.
	* @public
	* @param {fonction_Obligatoire} newFonction : Fonction  appliquer sur l'vnement onChange ou onClick 
		du composant.
	* @param {boolean_Facultatif} update Boolen : qui indique si le champ est  mettre  jour ou non.
	* @return {void}
	* @version 2.1
	* @date 20/06/2006
	*/
  this.setOnChange = function (newFonction,update) {
  	// contrle de la validit du type de composant
  	if ((this.type == "file") || (this.type == "hidden") || (this.type == "hidden"))
  		return; 
  	// valorisation de l'attribut
  	this.onChange=newFonction;
  	// demande de regnration de l'lment HTML
    if (update==true) {
      if (this.getDomHtmlElement()!=null) {
        //si l'lment HTML existe on rcupre la valeur courante et on rgnre 
        if (this.getValue!=null) {
          this.getValue();
        } 
        if (this.getTabOption!=null) this.getTabOption();
        this.ecrireBind();
      }  
    }
 };  
 
  // dclaration de la fonction porte par l'attribut onblur
 
	/**
	* La mthode publique setOnBlur(newFonction,update) initialise l'attribut {@link #onBlur onBlur} avec une 
	* nouvelle valeur, et regnre l'lment HTML associ si le paramtre update est vrai. L'attribut n'est 
	* pas initialis si le composant sur lequel on appelle la mthode ne peut faire l'objet d'un vnement de 
	* type onblur.
	* @public
	* @param {fonction_Obligatoire} newFonction : Fonction  appliquer sur l'vnement onBlur du composant.
	* @param {boolean_Facultatif} update : Boolen qui indique si le champs est  mettre  jour ou non.
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/   
  this.setOnblur = function (newFonction,update) {
  	// contrle de la validit du type de composant
  	if ((this.type == "file") || (this.type == "hidden") || (this.type == "hidden"))
  		return; 
  	// valorisation de l'attribut
  	this.onblur=newFonction;
  	// demande de regnration de l'lment HTML
    if (update==true) {
      if (this.getDomHtmlElement()!=null) {
        //si l'lment HTML existe on rcupre la valeur courante et on rgnre 
        if (this.getValue!=null) {
          this.getValue();
        } 
        if (this.getTabOption!=null) this.getTabOption();
        this.ecrireBind();
      }  
    }
 };  
 

	// comptabilise l'lment dans le tableau global et fournit la rfrence
	
	/**
	* La mthode prive initReference() ajoute l'lment courant dans le tableau tabElementForm[], variable globale 
	* qui recense tous les lments instancis. Puis la proprit 'reference' est initialise  la valeur chane 
	* de caractre 'tabElement[i]', constituant alors une rfrence sur l'lment depuis l'extrieur du script.
	* @public
	* @param {} Aucun
	* @return {void}
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.initReference = function() {
    tabElementForm.push(this);
    indice = tabElementForm.length-1;
    this.reference = "tabElementForm["+indice+"]";
    return;
  };
  
  // initReference
  this.initReference();
    
  // ajout d'une option  
	/**
	* <b>Destine  des lments de formulaire hritants de la classe DefaultElementForm</b> - La mthode publique  addOption ajoute une option
	*  la liste "this.tabOption".
	* @public
	* @param {ObjectOption_Obligatoire} newOption : Option de type {@link ObjectOption ObjectOption}
	*  ajouter au tableau d'options.
	* @return {boolean} false si tabOption n'est pas initialis (pas ElementFormSelect ou ElementFormRadio)
	* @version 2.4
	* @date 14/11/2006
	*/
  this.addOption=function(newOption) {
    if (this.tabOption == null) return false;
    var r=getRangOption(this.tabOption, newOption.value);
    if (r != -1)
    	return true;
    this.tabOption.push(newOption);
    var elm=this.getDomHtmlElement();
    // si l'element html est dja gnr alors on le met  jour
    if ( ((elm!=null) && (elm.options!=null)) || ((elm!=null) && (this.type=="radio"))){
      // Option 2 : regnration de l'lment dans son intgralit
      this.ecrireBind(); 
    }
    return true;
  };
    
  // inversion de la position de deux option
	/**
	* <b>Destine  des lments de formulaire hritants de la classe DefaultElementForm </b>- La mthode publique changeOption change 
	* la position de deux options dans la liste "this.tabOption".
	* @public
	* @param {String_Obligatoire} val : Valeur du premier lment  interchanger
	* @param {String_Obligatoire} val : Valeur du second lment  interchanger
	* @return {boolean} false si un des lments n'a pas t trouve
	* @version 2.4
	* @date 14/11/2006
	*/
  this.changeOption=function(val1, val2) {
  	if (this.tabOption == null) return false;

    var r1=getRangOption(this.tabOption, val1);
    if (r1 == -1)
    	return false;
    var r2=getRangOption(this.tabOption, val2);
    if (r2 == -1)
    	return false;
    
    var option=this.tabOption[r1];
    this.tabOption.splice(r1,1,this.tabOption[r2]);
    this.tabOption.splice(r2,1,option);
    
    var elm=this.getDomHtmlElement();
    // si l'element html est dja gnr alors on le met  jour
    if ( (elm!=null) && (elm.options!=null) ){
      // Option 2 : regnration de l'lment dans son intgralit
      this.ecrireBind(); 
    }
    return true;
  };

  // suppression d'une option
	/**
	* <b>Destine  des lments de formulaire hritants de la classe DefaultElementForm </b>- La mthode publique removeOption soustrait
	* une option  la liste "this.tabOption".
	* @public
	* @param {String_Obligatoire} val : Valeur de l'option  retirer
	* @return {boolean} false si tabOption n'est pas initialis (pas ElementFormSelect ou ElementFormRadio)
	* @version 2.4
	* @date 14/11/2006
	*/
  this.removeOption=function(val) {
  	if (this.tabOption == null) return false;
    var r=getRangOption(this.tabOption, val);
    this.tabOption.splice(r,1);
    var elm=this.getDomHtmlElement();
    // si l'element html est dja gnr alors on le met  jour
    if ( ((elm!=null) && (elm.options!=null)) || ((elm!=null) && (this.type=="radio"))){
      // Option 2 : regnration de l'lment dans son intgralit
      this.ecrireBind(); 
    }
    return true;
  };
}