/** 
* @fileoverview Ce fichier Javascript correspond au framework de gestion des listes. Cette description consiste
*  prsenter les prototypes des fonctions, des exemples d'appel et les prcisions techniques ncessaires  la mise
* en oeuvre de ce framework.<br>
* Le framework liste utilise les classes utilitaires suivantes :<br>&gt; <b>{@link ElementListe ElementListe}</b>
* pour grer l'lment Liste.<br>&gt; <b>{@link ObjectListe ObjectListe}</b> pour
* dcrire l'objet associ  une liste. <br><br>
* <img alt="classesFwListe" src="Image.ElementListeUML.png"><br><br>
* Ainsi, conformment aux principes du framework ergonomique, l'ensemble du contenu informatif peut tre paramtr
* sous forme de flux XML ou par l'intermdiaire d'un tableau JavaScript.
* <br>Le paramtrage du contenu informatif consiste  indiquer pour chaque item de la liste son libell.
* Le libell est une chane de caractres.<br>L'arborescence XML associ  ce paramtrage doit avoir la forme
* suivante :<br><div style="border: 0.5pt solid windowtext; padding: 1pt 4pt; background: rgb(255, 255, 204)
* none repeat scroll 0% 50%; -moz-background-clip: initial; -moz-background-origin:
* initial; -moz-background-inline-policy: initial;"><code>&lt;COMPOSANT&gt;<br>&nbsp;&nbsp;&nbsp; &lt;ITEM&gt;
* <br>&nbsp;&nbsp;&nbsp; &nbsp;&nbsp;&nbsp;
* &lt;LIBELLE&gt;&lt;/LIBELLE&gt;<br>&nbsp;&nbsp;&nbsp; &lt;/ITEM&gt;<br>&lt;/COMPOSANT&gt;<br></code>
* </div>L'lment racine de nom &laquo;COMPOSANT ici peut prendre n'importe quel nom. Ce nom d'lment est utile 
* que lors de la construction de la page pour passer le bon paramtrage lors de la construction du composant.
* <br>La dtermination de ce nom est dtermin soit par un modle de page ou par le dveloppeur de la
* page. <b>Voir Exemple de structure XML du contenu informatif de ce composant pour 2 items : </b>
* <a href='exemples_A3.html#structXml'>Exemples de structure XML</a>.
* <br><br>RENDU IHM<br>Liste simple<br><img alt="exListeSimple" src="Image.ListeSimple.jpg"/>
* <br>Liste numrote<br><img alt="exListeNumerotee" src="Image.ListeNumerotee.jpg"/>
* @author Ministre des Affaires Etrangres, Aubay SA, Steve Pguet
* @version 1.1
* @date 25/10/2005
*/

/*
Copyright ou  ou Copr. 
Ministre des Affaires Etrangres,
Aubay SA,
Steve Pguet, (10/05/2004)

steve.peguet@diplomatie.gouv.fr

Ce logiciel est un programme informatique servant de framework JavaScript 
bas sur les normes W3C (XHTML/CSS/DOM/XML). Il offre la possibilit de 
mettre en uvre facilement les principes ergonomiques et techniques propres 
 un client riche (cumul des avantages du client lger et du client lourd).
Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilit au code source et des droits de copie,
de modification et de redistribution accords par cette licence, il n'est
offert aux utilisateurs qu'une garantie limite.  Pour les mmes raisons,
seule une responsabilit restreinte pse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concdants successifs.

A cet gard  l'attention de l'utilisateur est attire sur les risques
associs au chargement,   l'utilisation,   la modification et/ou au
dveloppement et  la reproduction du logiciel par l'utilisateur tant 
donn sa spcificit de logiciel libre, qui peut le rendre complexe  
manipuler et qui le rserve donc  des dveloppeurs et des professionnels
avertis possdant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invits  charger  et  tester  l'adquation  du
logiciel  leurs besoins dans des conditions permettant d'assurer la
scurit de leurs systmes et ou de leurs donnes et, plus gnralement, 
 l'utiliser et l'exploiter dans les mmes conditions de scurit. 

Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
pris connaissance de la licence CeCILL, et que vous en avez accept les
termes.*/


// Fonction pour initialiser le contenu du tableau refltant l'ensemble des items de la liste prsents
//  partir d'un flux XML

/**
* La mthode prive initTabByXML permet de construire le tableau d'objets rfrenant les items
* prsents dans le flux XML de paramtrage. Elle est appele par le constructeur de la classe lorsqu'un flux
* XML lui est passe en argument.
* @private
* @param {} Aucun
* @return {void}
* @version 1.1
* @date 25/10/2005
*/
function ElementListe_initTabByXML()
{
  var tabItemsListe = parent.getElements(this.XMLObjectListe.xmlDoc,"ITEM");
  var i=0;
  for (i=0;i<tabItemsListe.length;i++)
    this.tabListe[i] = new ObjectListe(parent.getDataElement(tabItemsListe[i],"LIBELLE"));
}


// Objet dfinissant une Liste, son libelle sera le texte d'un item de la liste

/**
* Cre une instance de la classe ObjectListe. 
* @class La classe <b>ObjectListe</b>  est la classe permettant de grer un lment d'une liste.
* <br> Il n'existe pas de proprit prive pour cette classe. Il n'existe pas de mthode pour cette classe. <br>
* <br> Sa proprit publique dcrit l'attribut d'un lment liste et peut tre manipule ou interroge en dehors 
* de la bibliothque du framework ergonomique.
* <br><br><br><img src="Image.ObjectListeUML.png"/><br><br><br>
* @public
* @constructor
* @param {String_Obligatoire} libelle : Chane de caractres indiquant le libell associ  l'item de liste.
* @version 1.1
* @date 25/10/2005
*/
function ObjectListe(libelle)
{
	/**
	* La proprit publique libelle dcrit l'attribut d'un lment liste et peut tre manipule ou 
	* interroge en dehors de la bibliothque du framework ergonomique. C'est une chane de caractres 
	* indiquant le libell associ  l'item de liste.
	* <br><br>
	* @public
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/
  this.libelle = libelle;
}


// Constructeur pour l'lment Liste

/**
* fonction ElementListe_constructor(); permettant d'instancier un objet de type{@link ElementListe ElementListe}.
* @see ElementListe
* @public
* @param {} Aucun
* @version 1.1
* @date 25/10/2005
*/
function ElementListe_constructor()
{
  if (this.divBind == null)
    this.initDivBind();
  if ((this.tabListe.length == 0) && (this.XMLObjectListe != null))
    this.initTabByXML();
}


// Fonction pour renseigner la zone dynamique (DIV) conteneur du composant Liste

/**
* La mthode publique setDivBind(divBind) permet d'associer une zone dynamique (DIV) comme conteneur
* du composant Liste. Elle est utile lors de l'utilisation d'un id sur cette zone diffrent de celui par dfaut
* ("Position_" + Id du composant).
* <br><br> <b>Voir Exemple d'affectation d'une zone dynamique au composant diffrente de celle par dfaut : </b>
* <a href='exemples_A3.html#ElementListe_meth'>Exemples d'appels aux mthodes publiques</a>.
* @public
* @param {objetDOMHtml_Obligatoire} divBind Objet DOM HTML : rfrence la zone dynamique associe au composant.
* @return {void}
* @version 1.1
* @date 25/10/2005
*/
function ElementListe_setDivBind(divBind)
{
  this.divBind = divBind;
}


// Fonction pour initialiser par dfault la zone dynamique (DIV) associe au composant Liste

/**
* La  mthode prive initDivBind() permet de spcifier un pointeur vers le DOM HTML de la zone dynamique
* grant la prsentation du composant liste. Elle est ainsi initialise  l'lment DOM HTML prsent dans la page
* dont l'id est valoris par "Position_" + Id du composant.<br>
* Ce pointeur vers le DOM HTML est stock dans la proprit divBind de l'instance de la classe ElementListe.
* @private
* @param {} Aucun
* @return {void}
* @version 1.1
* @date 25/10/2005
*/
function ElementListe_initDivBind()
{
  if (document.getElementById("Position_" + this.id))
    this.setDivBind(document.getElementById("Position_" + this.id));
}


// Fonction pour gnrer le code HTML associ  l'lment Liste

/**
* La mthode prive ecrireElementDomHTML() est une fonction interne renvoyant le code HTML associ  une liste. 
* Le code est renvoy sous la forme d'une chane de caractres prenant en compte l'ensemble du 
* paramtrage effectu sur la classe.
* @private
* @param {} Aucun
* @return {void}
* @version 1.1
* @date 25/10/2005
*/
function ElementListe_ecrireHTML()
{
  if (this.tabListe.length == 0)
    return "Liste vide";
  var i = 0;
  if (this.boolNum)
    var codeHTML = '<ol>';
  else var codeHTML = '<ul>';
  for (i=0;i<this.tabListe.length;i++)
  {
    codeHTML += '<li>' + this.tabListe[i].libelle + '</li>';
  }
  if (this.boolNum)
    codeHTML += '</ol>';
  else codeHTML += '</ul>';
  return codeHTML;
}


// Fonction pour binder le code HTML gnr dans la zone dynamique associe 

/**
* La mthode publique ecrireBind() dclenche la gnration du code HTML de la zone dynamique associe au composant.
* Par dfaut, la zone dynamique est l'lment DOM HTML dont l'id est valoris par "Position_" + Id du composant.<br>
* Fonctionnement :<br>1. Dsaffichage de la zone dynamique.<br>
* 2. Rcupration du code HTML associ l'lment Liste.<br>
* 3. Bind le code HTML  la zone dynamique associe  la liste.<br>
* 4. Affichage de la zone dynamique<br>
* <br><br><b>Voir Exemple de gnration du code HTML associ au composant pour affichage : </b>
* <a href='exemples_A3.html#ElementListe_meth'>Exemples d'appels aux mthodes publiques</a>.
* @public
* @param {} Aucun
* @return {void}
* @version 1.1
* @date 25/10/2005
*/
function ElementListe_ecrireBind()
{
  this.divBind.innerHTML = this.ecrireElementDomHTML();
}


// Description de la classe "ElementListe"

/**
* Cre une instance de la classe "ElementListe" <bVoir Exemple d'instanciation de ce composant</b>
* pour une liste non numrote : <a href='exemples_A3.html#ElementListe_constr'>Exemples d'appels aux constructeurs</a>.
* @class La classe <b>ElementListe</b>  est la classe permettant de dcrire l'objet associ  une liste.
* <br> Sa proprit publique dcrit les attributs du composant et peut tre manipule ou interroge en dehors de la
* bibliothque du framework ergonomique. Ses proprits prives sont utilises au sein mme
* du framework ergonomique.
* <br><br><br><img src="Image.ElementListeUML.png"/><br><br><br>
* <br><br>RENDU IHM<br>Liste simple<br><img alt="exListeSimple" src="Image.ListeSimple.jpg"/>
* <br>Liste numrote<br><img alt="exListeNumerotee" src="Image.ListeNumerotee.jpg"/><br><br>
* @public
* @constructor
* @param {String_Obligatoire} id String : indique l'id de l'lment  instancier. 
* Sa valorisation doit correspondre au nom de la variable JavaScript du composant instanci.
* @param {boolean_Obligatoire} boolNum Boolen : indique le type de liste dsir. 
* Valeurs possibles : "true" liste numrote, "false" liste non numrotee.
* @param {XMLObjectSauvegarde_Facultatif} XMLObject Objet {@link XMLObjectSauvegarde XMLObjectSauvegarde}
* pour paramtrer le contenu informatif.
* @param {t_ObjectListe_Optionnel} tabItem Tableau d'objets {@link ObjectListe ObjectListe} :
* pour paramtrer le contenu informatif en JavaScript si pas de flux XML pour effectuer ce paramtrage.
* @version 1.1
* @date 25/10/2005
*/
function ElementListe(id, boolNum, xmlObject)
{
  // ***************************
  // Attributs de l'objet
  // ***************************
  
	/**
	* Proprit prive id - C'est l'ID du composant dfinit sous forme de chane de caractres.
	* Il doit obligatoirement tre valoris au nom de la variable JavaScript rfrenant l'instanciation du composant.
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.id = id;
  
	/**
	* Proprit prive boolNum - Boolen prcisant si la liste est de type numrote (true) ou normale (false).
	* <br><br>
	* @private
	* @type boolean
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.boolNum = boolNum;
  
	/**
	* Proprit prive XMLObjectListe. Objet de type XMLObjectSauvegarde rfrenant le flux XML intgrant le
	* paramtrage du contenu informatif du composant. Si ce paramtrage est effectu directement par passage
	* de tableau JavaScript sans flux XML alors cette proprit est valorise  null.
	* <br><br>
	* @private
	* @type XMLObjectSauvegarde
	* @version 1.1
	* @date 25/10/2005
	*/   
  this.XMLObjectListe = xmlObject;
  
	/**
	* Proprit prive divBind. Zone dynamique (objet DOM HTML) associe au composant. Cette zone dynamique
	* permet de binder le code HTML refltant le rendu et le dynamisme du composant. Par dfaut, 
	* cette zone dynamique est l'lment DOM HTML dont l'id est valoris par "Position_" + Id du composant.
	* <b>Valeur par dfaut : </b> <a href='default-values_A3.html#ElementListeProp'>
	* Valeurs par dfaut des Proprits</a>
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.divBind = null;
  
	/**
	* L'lment  argv  dans la classe ElementListe n'est pas une proprit, il permet de rcuprer
	* dans un tableau les arguments passs en paramtres du constructeur de la classe 
	* (utile dans le cas des paramtres facultatifs, pour reprer les paramtres qui ont t soumis par le dveloppeur).
	* Il est dclar 'var'.
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/  
  var argv = ElementListe.arguments;

	/**
	* L'lment  argc  dans la classe ElementListe n'est pas une proprit, il permet de rcuprer 
	* le nombre d'arguments passs en paramtres du constructeur de la classe (utile dans le cas des 
	* paramtres facultatifs, pour compter les paramtres  soumis par le dveloppeur). Il est dclar 'var'.
	* <br><br>
	* @private
	* @type String
	* @version 1.1
	* @date 25/10/2005
	*/  
  var argc = ElementListe.arguments.length;

	/**
	* La proprit publique tabListe peut tre manipule ou interroge en dehors de la bibliothque 
	* du framework ergonomique. C'est un tableau d'objets {@link ObjectListe ObjectListe} refltant 
	* l'ensemble des items prsents dans l'lment Liste. <br>Ce tableau est soit pass en paramtre 
	* du constructeur, soit auto-aliment  partir d'un flux XML pass en paramtre lors
	* de la construction du composant.
	* <br><br>
	* @private
	* @type Array_ObjectListe
	* @version 1.1
	* @date 25/10/2005
	*/  
  this.tabListe = (argc > 3) ? argv[3] : new Array();
  
  // ***************************
  // Mthodes de l'objet
  // ***************************
  
  // Initialisation lie  la prsence d'un objet XML
  this.initTabByXML = ElementListe_initTabByXML;
  
  // Gnration HTML de l'lment Liste
  this.ecrireElementDomHTML = ElementListe_ecrireHTML;
  this.ecrireBind = ElementListe_ecrireBind;
  this.initDivBind = ElementListe_initDivBind;
  this.setDivBind = ElementListe_setDivBind;
  
  // Constructeur
  this.constructor = ElementListe_constructor;
  this.constructor();
}