/** 
* @fileoverview Ce fichier Javascript correspond au framework bulle offrant un ensemble
* de fonctionnalits techniques pour grer l'affichage de bulle.
* <br>
* <br><br>RENDU IHM<br><br>Voici l'affichage d'un composant Bulle, 
* <br><br><br><img alt="exemple IHM ComposantBulle" src="Image.ComposantBulle1.jpg"/>
* <br>Le survol de la zone de texte affiche une bulle de type TYPE_BULLE_FLOTTANTE.
* <br><br><br><img alt="exemple IHM ComposantBulle" src="Image.ComposantBulle2.jpg"/>
* <br>Le survol de la zone de texte affiche une bulle de type TYPE_BULLE_HAUT_DROITE.
* <br>
* @author Ministre des Affaires Etrangres, Aubay SA, Steve Pguet
* @version 2.5
* @date 14/02/2007
*/

/*
Copyright ou  ou Copr. 
Ministre des Affaires Etrangres,
Aubay SA,
Steve Pguet, (06/04/2004)

steve.peguet@diplomatie.gouv.fr

Ce logiciel est un programme informatique servant de framework JavaScript 
bas sur les normes W3C (XHTML/CSS/DOM/XML). Il offre la possibilit de 
mettre en uvre facilement les principes ergonomiques et techniques propres 
 un client riche (cumul des avantages du client lger et du client lourd).
Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilit au code source et des droits de copie,
de modification et de redistribution accords par cette licence, il n'est
offert aux utilisateurs qu'une garantie limite.  Pour les mmes raisons,
seule une responsabilit restreinte pse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concdants successifs.

A cet gard  l'attention de l'utilisateur est attire sur les risques
associs au chargement,   l'utilisation,   la modification et/ou au
dveloppement et  la reproduction du logiciel par l'utilisateur tant 
donn sa spcificit de logiciel libre, qui peut le rendre complexe  
manipuler et qui le rserve donc  des dveloppeurs et des professionnels
avertis possdant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invits  charger  et  tester  l'adquation  du
logiciel  leurs besoins dans des conditions permettant d'assurer la
scurit de leurs systmes et ou de leurs donnes et, plus gnralement, 
 l'utiliser et l'exploiter dans les mmes conditions de scurit. 

Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
pris connaissance de la licence CeCILL, et que vous en avez accept les
termes.*/

// Constantes dsignant les diffrents types de ComposantBulle
var TYPE_BULLE_FLOTTANTE = 1;
var TYPE_BULLE_HAUT_DROITE = 2;
var TYPE_BULLE_MILIEU_DROITE = 3;
var TYPE_BULLE_MILIEU_GAUCHE = 4;
var TYPE_BULLE_HAUT_GAUCHE = 5;
var TYPE_BULLE_BAS_DROITE = 6;
var TYPE_BULLE_BAS_GAUCHE = 7;

/**
* Cre une instance de la classe ComposantBulle reprsentant une bulle.
* @class La classe <b>ComposantBulle</b> est la classe permettant de grer l'affichage d'une bulle
* d'information (ou ToolTip) de manire plus volue qu'avec les attributs <i>alt</i> ou <i>title</i> traditionnels.<br>
* Pour tre utilis, un composant bulle devra tre associ  un lment de formulaire hritant des classes
* {@link DefaultElementForm DefaultElementForm} et {@link DefaultHtml DefaultHtml}.<br>
* La bulle, quel que soit son type, s'affiche lorsque le curseur de la souris survole l'lment de formulaire associ.<br>
* Deux lments caractrisent un composant bulle :<br>
* <ul><li>son contenu (au format HTML)</li><li>et son type :
*  <ul><li>bulle flottante (constante TYPE_BULLE_FLOTTANTE) : la bulle suit le curseur de la souris lors du survol
* de l'lment de formulaire.</li>
* <li>bulle attache dans le coin en haut  droite (constante TYPE_BULLE_HAUT_DROITE) : la bulle s'affiche au niveau du coin suprieur droit
* de l'lment de formulaire.</li>
* <li>bulle attache dans le coin en haut  gauche (constante TYPE_BULLE_HAUT_GAUCHE) : la bulle s'affiche au niveau du coin suprieur gauche
* de l'lment de formulaire.</li>
* <li>bulle attache dans le coin en bas  droite (constante TYPE_BULLE_BAS_DROITE) : la bulle s'affiche au niveau du coin infrieur droit
* de l'lment de formulaire.</li>
* <li>bulle attache dans le coin en bas  gauche (constante TYPE_BULLE_BAS_GAUCHE) : la bulle s'affiche au niveau du coin infrieur gauche
* de l'lment de formulaire.</li>
* <li>bulle attache au centre de l'lment vers la gauche (constante TYPE_BULLE_MILIEU_GAUCHE) : la bulle s'affiche au niveau du centre de l'lment et vers la gauche</li>
* <li>bulle attache au centre de l'lment vers la droite (constante TYPE_BULLE_MILIEU_DROITE) : la bulle s'affiche au niveau du centre de l'lment et vers la droite</li>
* </ul></li></ul>
* <br><br><img src="Image.ComposantBulleUML.png"/><br><br>
* <a href="javascript:ouvrirPopupExemple('./exemples/bulle1.html','Exemple')">Exemple d'utilisation du composant Bulle.</a><br>
* <br><br>RENDU IHM<br><br>Voici l'affichage d'un composant Bulle, 
* <br><br><br><img alt="exemple IHM ComposantBulle" src="Image.ComposantBulle1.jpg"/>
* <br>Le survol de la zone de texte affiche une bulle de type TYPE_BULLE_FLOTTANTE.
* <br><br><br><img alt="exemple IHM ComposantBulle" src="Image.ComposantBulle2.jpg"/>
* <br>Le survol de la zone de texte affiche une bulle de type TYPE_BULLE_HAUT_GAUCHE.<br><br>
* <br><br><br><img alt="exemple IHM ComposantBulle" src="Image.ComposantBulle3.jpg"/>
* <br>Le survol de la zone de texte affiche une bulle de type TYPE_BULLE_HAUT_DROITE.<br><br>
* <br><br><br><img alt="exemple IHM ComposantBulle" src="Image.ComposantBulle4.jpg"/>
* <br>Le survol de la zone de texte affiche une bulle de type TYPE_BULLE_BAS_DROITE.<br><br>
* <br><br><br><img alt="exemple IHM ComposantBulle" src="Image.ComposantBulle5.jpg"/>
* <br>Le survol de la zone de texte affiche une bulle de type TYPE_BULLE_BAS_GAUCHE.<br><br>
* <br><br><br><img alt="exemple IHM ComposantBulle" src="Image.ComposantBulle6.jpg"/>
* <br>Le survol de la zone de texte affiche une bulle de type TYPE_BULLE_MILIEU_DROITE.<br><br>
* <br><br><br><img alt="exemple IHM ComposantBulle" src="Image.ComposantBulle7.jpg"/>
* <br>Le survol de la zone de texte affiche une bulle de type TYPE_BULLE_MILIEU_GAUCHE.<br><br>
* @includeJS technique_fw_bulle.css
* @includeCSS bulle.css
* @constructor
* @param {String_Facultatif} contenu : Code HTML prcisant le contenut de la bulle.  
* @param {Int_Facultatif} type : Entier indiquant le type de la bulle<br><ul>
*											<li>TYPE_BULLE_FLOTTANTE (1) => Bulle suivant le curseur de la souris.</li>
*											<li>TYPE_BULLE_HAUT_GAUCHE (5) => Bulle s'affichant  l'extrmit haute gauche de l'lment.</li>
*											<li>TYPE_BULLE_HAUT_DROITE (2) => Bulle s'affichant  l'extrmit haute droite de l'lment.</li>
*											<li>TYPE_BULLE_BAS_DROITE (6) => Bulle s'affichant  l'extrmit bas droite de l'lment.</li>
*                     <li>TYPE_BULLE_BAS_GAUCHE (7) => Bulle s'affichant  l'extrmit bas gauche de l'lment.</li>
*											<li>TYPE_BULLE_MILIEU_DROITE (3) => Bulle s'affichant au milieu de l'lment (coin haut-gauche de la bulle au milieu de l'lment).</li> 
*											<li>TYPE_BULLE_MILIEU_GAUCHE (4) => Bulle s'affichant au milieu de l'lment (coin haut-droite de la bulle au milieu de l'lment).</li>
*</ul>
* @return {void}
* @version 2.5
* @date 14/02/2007
*/
function ComposantBulle(contenu, type){

	/**
	* La constante OFFSETX dsigne l'cart sur l'axe des abscisses  utiliser
	* entre la souris et la bulle de type 1.
	* <br><br>
	* @final
	* @private
	* @type Int
	* @version 2.5
* @date 14/02/2007
	*/
	this.OFFSETX = 10;

	/**
	* La constante OFFSETY dsigne l'cart sur l'axe des ordonnes  utiliser
	* entre la souris et la bulle de type 1.
	* <br><br>
	* @final
	* @private
	* @type Int
	* @version 2.5
* @date 14/02/2007
	*/
	this.OFFSETY = 10;

	/**
	* La proprit x dsigne la position de la bulle sur l'axe des abscisses.
	* <br><br>
	* @private
	* @type Int
	* @version 2.5
* @date 14/02/2007
	*/	
	this.x = 0;

	/**
	* La proprit y dsigne la position de la bulle sur l'axe des ordonnes.
	* <br><br>
	* @private
	* @type Int
	* @version 2.5
* @date 14/02/2007
	*/	
	this.y = 0;

	/**
	* La proprit divBulle dsigne l'lment DIV ( positionnement absolu)
	* cr pour contenir la bulle.
	* <br><br>
	* @public
	* @type DOMHTMLElement
	* @version 2.5
	* @date 14/02/2007
	*/
	this.divBulle = null;

	/**
	* La proprit htmlElement contient un pointeur sur l'objet de type HtmlElement sur lequel
	* intervient la bulle.
	* <br><br>
	* @private
	* @type HtmlElement
	* @version 2.5
* @date 14/02/2007
	*/
	this.htmlElement = null;

	/**
	* La proprit defaultHtmlElementForm contient un pointeur sur l'objet de type 
	* HtmlElement sur lequel intervient la bulle.
	* <br><br>
	* @private
	* @type DefaultHtmlElementForm
	* @version 2.5
* @date 14/02/2007
	*/
	this.defaultHtmlElementForm = null;

	/**
	* La proprit contenu contient le code HTML  afficher dans la bulle (pass en paramtre).
	* <br><br>
	* @private
	* @type String
	* @version 2.5
* @date 14/02/2007
	*/
	this.contenu = contenu;

	/**
	* La proprit type contient le type de la bulle (pass en paramtre).
	* <br><br>
	* @private
	* @type Int
	* @version 2.5
* @date 14/02/2007
	*/
	this.type = type;

	/**
  * La proprit classDiv correspond au nom de la classe CSS associe  la DIV du composant bulle.
	* <br><br>
	* @private
	* @type String
	* @version 2.5
* @date 14/02/2007
	*/
  this.classeCSSDiv = 'divBulleDefaut';
  
	/**
	* La mthode publique setClasseCSSDiv() renseigne l'attribut priv classeCSSDiv de la classe.<br>
	* @public
	* @param {String_Obligatoire} classe : nom de la classe CSS  appliquer  la DIV de la bulle.
	* @return {void}
	* @version 2.5
* @date 14/02/2007
	*/
  this.setClasseCSSDiv = function (classe) {
  		// Renseignement de l'attribut
  		this.classeCSSDiv = classe;
  		
  		// Modification de l'aspect de la div
  		if (this.divBulle != null) {
	  		this.divBulle.setAttribute("class",this.classeCSSDiv);
			  this.divBulle.setAttribute("className",this.classeCSSDiv);
		  }
  }

	/**
	* La mthode publique setHtmlElement(element, contexte) renseigne l'attribut priv htmlElement
	* de la classe et ajoute la <i>div</i> de la bulle  l'lment contexte pass en paramtre.<br>
	* @public
	* @param {HtmlElement_Obligatoire} element : Pointeur sur un object HtmlElement.
	* @param {DOMElement_Obligatoire) contexte : lment HTML auquel sera ajout la div contenant la bulle.
	* @param {String_Facultatif) reference : nom de la variable rfrencant la bulle.
	* @return {void}
	* @version 2.5
* @date 14/02/2007
	*/
  this.setHtmlElement = function (element, contexte, reference) {
		if (this.htmlElement != element) {
 			// Mise  jour de la proprit
	 		this.htmlElement = element;
	
			// Ajout de la DIV au document
			contexte.parentNode.appendChild(this.divBulle);			

			// Modification des vnement onmouseover et onmouseout de la DIV si ncessaire
			if (this.type == TYPE_BULLE_MILIEU_DROITE || this.type == TYPE_BULLE_MILIEU_GAUCHE) {
				// Gestion des montrer / cacher lors du survol de la bulle
				this.divBulle.setAttribute("onmouseover", reference + ".bulleInfo.montrer()"); // Montrer
				this.divBulle.setAttribute("onmouseout", reference + ".bulleInfo.cacher()"); // Cacher
			}
  	}
  }

	/**
	* La mthode publique setDefaultHtmlElementForm() renseigne l'attribut priv htmlElement de la classe
	*  partir d'un objet hritant des classe DefaultElementForm et DefaultHtml.<br>
	* @public
	* @param {DefaultHtmlElementForm_Obligatoire} element : Pointeur sur un object hritant des classes
	* DefaultElementForm et DefaultHtml.
	* @return {void}
	* @version 2.5
* @date 14/02/2007
	*/
  this.setDefaultHtmlElementForm = function (element) {
		if (this.defaultHtmlElementForm != element) {
 			// Mise  jour de la proprit
	 		this.defaultHtmlElementForm = element;
	
			// Ajout de la DIV au document
			var divElmt = document.getElementById(element.getDivBind());
			divElmt.parentNode.appendChild(this.divBulle);
			
			// Modification des vnement onmouseover et onmouseout de la DIV si ncessaire
			if (this.type == TYPE_BULLE_MILIEU_DROITE || this.type == TYPE_BULLE_MILIEU_GAUCHE) {
				// Gestion des montrer / cacher lors du survol de la bulle
				this.divBulle.setAttribute("onmouseover", element.reference + ".bulleInfo.montrer()"); // Montrer
				this.divBulle.setAttribute("onmouseout", element.reference + ".bulleInfo.cacher()"); // Cacher
			}
  	}
  }
  
	/**
	* La mthode prive montrer() affiche la bulle, et en fonction de son type, dfinit
	* les vnements sur l'lment cibl pour grr son cycle de vie<br>
	* @private
	* @param {} Aucun
	* @return {void}
	* @version 2.5
* @date 14/02/2007
	*/
	this.montrer = function () {

		// Renseignement du contenu de la bulle
    this.divBulle.innerHTML = this.contenu;
 		
 		// Calcul de la position de la bulle en fonction de son type 		
 		if (this.type == TYPE_BULLE_HAUT_DROITE) {
 			var element = (this.htmlElement==null)?this.defaultHtmlElementForm.getDomHtmlElement():this.htmlElement;
 			var tabPos = trouverPosition(element);
 			this.x = tabPos[0] + element.offsetWidth;
 			this.y = tabPos[1] - element.offsetHeight;
 		} else if (this.type == TYPE_BULLE_FLOTTANTE){
 			this.x = this.x + this.OFFSETX;
 			this.y = this.y + this.OFFSETY;
 		} else if (this.type == TYPE_BULLE_MILIEU_DROITE) {
 			var element = (this.htmlElement==null)?this.defaultHtmlElementForm.getDomHtmlElement():this.htmlElement;
 			var tabPos = trouverPosition(element);
 			this.x = tabPos[0] + (element.offsetWidth / 2);
 			this.y = tabPos[1] + (element.offsetHeight / 2);
 		} else if (this.type == TYPE_BULLE_MILIEU_GAUCHE) {
 			var element = (this.htmlElement==null)?this.defaultHtmlElementForm.getDomHtmlElement():this.htmlElement;
 			var tabPos = trouverPosition(element);
 			this.x = tabPos[0] - this.divBulle.offsetWidth + (element.offsetWidth / 2);
 			this.y = tabPos[1] + (element.offsetHeight / 2);
 		} else if (this.type == TYPE_BULLE_HAUT_GAUCHE) {
 			var element = (this.htmlElement==null)?this.defaultHtmlElementForm.getDomHtmlElement():this.htmlElement;
 			var tabPos = trouverPosition(element);
 		  this.x = tabPos[0] - this.divBulle.offsetWidth;
 			this.y = tabPos[1] - this.divBulle.offsetHeight;
 		} else if (this.type == TYPE_BULLE_BAS_DROITE) {
 			var element = (this.htmlElement==null)?this.defaultHtmlElementForm.getDomHtmlElement():this.htmlElement;
 			var tabPos = trouverPosition(element);
 		  this.x = tabPos[0] + element.offsetWidth;
 			this.y = tabPos[1] + element.offsetHeight;
 		} else if (this.type == TYPE_BULLE_BAS_GAUCHE) {
 			var element = (this.htmlElement==null)?this.defaultHtmlElementForm.getDomHtmlElement():this.htmlElement;
 			var tabPos = trouverPosition(element);
 		  this.x = tabPos[0] - this.divBulle.offsetWidth;
 			this.y = tabPos[1] + element.offsetHeight;
 		}
		
		// Placement de la bulle
    this.allerA(this.x, this.y);

		// Affichage de la bulle
		this.divBulle.style.visibility ="visible";
		
	  return false;
	}


	/**
	* La mthode prive cacher() cache la bulle, et en fonction de son type, dfinit
	* les vnements sur l'lment cibl pour grr son cycle de vie<br>
	* @private
	* @param {} Aucun
	* @return {void}
	* @version 2.5
* @date 14/02/2007
	*/
	this.cacher = function () {
		// Vrification de la position de la souris
		
		// Cacher la bulle
		this.divBulle.style.visibility = "hidden";
	}

	/**
	* La mthode prive allerA() dplace la bulle selon les paramtres.<br>
	* @private
	* @param {Int_Obligatoire} xL : nouvel abscisse.
	* @param {Int_Obligatoire} yL : nouvelle ordonne.
	* @return {void}
	* @version 2.5
* @date 14/02/2007
	*/
	this.allerA = function (xL,yL) {
			this.divBulle.style.left = xL +"px";
		  this.divBulle.style.top = yL +"px";
	}

	/**
	* La mthode prive constructor correspond au constructeur de la classe.
	* @public
	* @return {void}
	* @version 2.5
* @date 14/02/2007
	*/
  this.constructor = function () {
		// Cration de l'lment DIV de la bulle
		this.divBulle = document.createElement("div");
		
		// Dfinition du style de la bulle
		this.setClasseCSSDiv(this.classeCSSDiv);
	}
  
  // Appel du constructeur
  this.constructor();
}


// Fonction pour grer l'vnement onmousemove pour les bulles de type 1

/**
* La fonction globale "composantBulleOnMouseMove" gre le traitement de l'vnement
* onmousemove pour les bulles de type 1.
* @public
* @param {Event_Facultatif} e : vnement du navigateur onmousemove
* @param {ToolTip_Obligatoire} composantBulle : rfrence  la bulle
* @return {void}
* @version 2.5
* @date 14/02/2007
*/ 
function composantBulleOnMouseMove (e, composantBulle) {
	// Calcul du positionnement de la souris
	var x, y;	
  if (document.all) {  // traitements pour IE
		x = event.x;
		y = event.y;
  } else {
		x = e.pageX;
		y = e.pageY;   
  }
 
  // Calcul du positionnement de la bulle
  composantBulle.x = x + document.body.scrollLeft;
  composantBulle.y = y + document.body.scrollTop;
 
  // Dplacement de la bulle
  composantBulle.allerA(composantBulle.x + composantBulle.OFFSETX, composantBulle.y + composantBulle.OFFSETY);    
}

/**
* La fonction globale "trouverPosition" retourne un tableau contenant les informations
* suivantes : [0] => abscisses (left) du coin haut gauche de l'lment DOM obj dans le document
*						  [1] => ordonnes (top) du coin haut gauche de l'lment DOM obj dans le document
* @public
* @param {DOMHTMLElement_Obligatoire} obj : rfrence  un lment DOM HTML
* @return {Array_Int}
* @version 2.5
* @date 14/02/2007
*/
function trouverPosition(obj) {
	// Calcul la position obj dans le document
	var curleft = curtop = 0;
	if (obj.offsetParent) {
		curleft = obj.offsetLeft;
		curtop = obj.offsetTop;
		while (obj = obj.offsetParent) {
			curleft += obj.offsetLeft;
			curtop += obj.offsetTop;
		}
	}
	return [curleft,curtop];
}