/** 
* @fileoverview Ce fichier Javascript correspond au framework de gestion des contrles de surface.
* Cette description consiste   prsenter les prototypes des <b>fonctions techniques</b>, des exemples d?appel et les prcisions
* techniques ncessaires  la mise en oeuvre de ce framework.<br>
* <br>Les <b>fonctions techniques de conversion</b> permettent de convertir une chane de caractres en Object Javascript pour pouvoir utiliser les proprits
* et les mthodes intgres de ces derniers : <b>Voir</b> {@link #toEntier toEntier}, {@link #toMontant toMontant} {@link #stringToDate stringToDate}, {@link #datetoString dateToString}.
* <br><br><b>Voir exemple d'utilisation des fonctions techniques pour un contrle de surface complexe : </b><a href='exemples_A3.html#fw_cs_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* <br>
* @author Ministre des Affaires Etrangres, Aubay SA, Steve Pguet
* @version 1.1
* @date 25/10/2005
*/
/*
Copyright ou  ou Copr. 
Ministre des Affaires Etrangres,
Aubay SA,
Steve Pguet, (07/07/2003)

steve.peguet@diplomatie.gouv.fr

Ce logiciel est un programme informatique servant de framework JavaScript 
bas sur les normes W3C (XHTML/CSS/DOM/XML). Il offre la possibilit de 
mettre en uvre facilement les principes ergonomiques et techniques propres 
 un client riche (cumul des avantages du client lger et du client lourd).
Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilit au code source et des droits de copie,
de modification et de redistribution accords par cette licence, il n'est
offert aux utilisateurs qu'une garantie limite.  Pour les mmes raisons,
seule une responsabilit restreinte pse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concdants successifs.

A cet gard  l'attention de l'utilisateur est attire sur les risques
associs au chargement,   l'utilisation,   la modification et/ou au
dveloppement et  la reproduction du logiciel par l'utilisateur tant 
donn sa spcificit de logiciel libre, qui peut le rendre complexe  
manipuler et qui le rserve donc  des dveloppeurs et des professionnels
avertis possdant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invits  charger  et  tester  l'adquation  du
logiciel  leurs besoins dans des conditions permettant d'assurer la
scurit de leurs systmes et ou de leurs donnes et, plus gnralement, 
 l'utiliser et l'exploiter dans les mmes conditions de scurit. 

Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
pris connaissance de la licence CeCILL, et que vous en avez accept les
termes.*/

//Fonction technique pour vrifier si la saisie est une chane de caractres valide vis  vis d'une expression rgulire
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique globale de <b>controle de format </b>
* estFormatString( maString, monFormat, op); elle permet de vrifier si maString est une chane de caractres valide suivant l'expression rgulire donne.
* <br> Si maString n'est pas valide la fonction retourne false sinon elle renvoie la chane de caractres formate.
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#estFormatString_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @param {String_Obligatoire} maString Chane de caractres  tester.
* @param {String_Obligatoire} monFormat Expression rgulire.
* @param {String_Facultatif} op Option expression rgulire.
 *@return {boolean} : false si maString n'est pas valide sinon retourne la  chane de caractres.
* @version 1.1
* @date 25/10/2005
*/
function estFormatString( maString, monFormat, op)
{
  var expREG = new RegExp(monFormat, op?op:"");
  if(expREG.test(maString)) return maString;
  else return false;
}

//Contrle de surface pour vrifier si la saisie est un nombre
//Option : vrifier si le nombre est born
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique globale de <b>controle de format simple </b> 
* estNumString( numString, min, max); elle permet de vrifier si le numString  est valide (numrique et compris entre min et max inclus).
* <br> Si numString  n'est pas valide la fonction retourne false sinon elle renvoie la chane de caractres formate reprsentant le nombre.
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#estNumString_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @see #estFormatString
* @param {String_Obligatoire} numString Chane de caractres  tester.
* @param {int_Facultatif} min Borne min
* @param {int_Facultatif} max Borne max.
* @return {boolean} : false si numString n'est pas valide sinon retourne la  chane de caractres  reprsentant le nombre.
* @version 1.1
* @date 25/10/2005
*/
function estNumString( numString, min, max)
{
  return estFormatString(numString, "^[0-9]"+((min)?((max)?("{"+min+","+max+"}"):("{"+min+"}")):"+")+"$");
}

//Contrle de surface pour vrifier si la saisie est seulement en alpha
//Option : vrifier si la saisie est borne alphabtiquement
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique globale de contrle de surface
* estAlphaString( alphaString, min, max); elle permet de vrifier si la saisie est seulement en alpha et permet de vrifier en option
* si la saisie est borne alphabtiquement.
* @public
* @see #estFormatString
* @param {String_Obligatoire} alphaString Chane de caractres  tester.
* @param {char_Facultatif} min Borne min
* @param {char_Facultatif} max Borne max.
* @return {boolean} : false si alphaString n'est pas valide sinon retourne la  chane de caractres.
* @version 1.1
* @date 25/10/2005
*/
function estAlphaString( alphaString, min, max)
{
  return estFormatString(alphaString, "^[A-Za-z_]"+((min)?((max)?("{"+min+","+max+"}"):("{"+min+"}")):"+")+"$");
}

//Contrle de surface pour vrifier si la saisie est seulement en alphanumrique
//Option : vrifier si la saisie est borne alphabtiquement ou numriquement
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique globale de contrle de surface
* estAlphanumString( alphanumString, min, max); elle permet de vrifier si la saisie est seulement en alphanumrique et permet de vrifier en option
* si la saisie est borne alphabtiquement ou numriquement.
* @public
* @see #estFormatString
* @param {String_Obligatoire} alphanumString Chane de caractres  tester.
* @param {char_Facultatif} min Borne min
* @param {char_Facultatif} max Borne max.
* @return {boolean} : false si alphanumString n'est pas valide sinon retourne la  chane de caractres.
* @version 1.1
* @date 25/10/2005
*/
function estAlphanumString( alphanumString, min, max)
{
  return estFormatString(alphanumString, "^[0-9A-Za-z_]"+((min)?((max)?("{"+min+","+max+"}"):("{"+min+"}")):"+")+"$");
}

//Contrle de surface pour vrifier si la saisie est un texte autoris excluant certains caractres interdits  la saisie
//Option : vrifier si la saisie est borne
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique globale de contrle de surface
* estTexteString( txtString, min, max); elle permet de vrifier si la variable txtString est un texte autoris excluant certains caractres interdits  la saisie et permet de vrifier en option
* si la saisie est borne.
* @public
* @see #estFormatString
* @param {String_Obligatoire} txtString Chane de caractres  tester.
* @param {char_Facultatif} min Borne min
* @param {char_Facultatif} max Borne max.
* @return {boolean} : false si txtString n'est pas valide sinon retourne la chane de caractres.
* @version 1.1
* @date 25/10/2005
*/
function estTexteString(txtString, min, max)
{
  return estFormatString(txtString, "^[^%&<=>|\"]"+((min)?((max)?("{"+min+","+max+"}"):("{"+min+"}")):"+")+"$");
}

//Fonction technique pour vrifier si une chane de caractres est un entier de base 10
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique globale de <b>conversion en format simple </b> 
* toEntier( entierString); elle permet de vrifier si entierString  est valide (entier) et de le convertir en objet Entier.
* <br> Si entierString  n'est pas valide la fonction retourne false sinon elle renvoie un objet Entier.
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#toEntier_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @param {String_Obligatoire} entierString Chane numrique reprsentant un entier.
* @return {boolean} : false si entierString n'est pas valide sinon retourne un objet Entier.
* @version 1.1
* @date 25/10/2005
*/
function toEntier( entierString)
{
  var val = parseInt(entierString, 10);
  if( isNaN(val)) return 0;
  else return val;
}

//Contrle de surface pour vrifier si la saisie est un entier
//Option : vrifier si la saisie est borne numriquement
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique globale de <b>controle de format simple </b> 
* estEntierString( entierString, min, max); elle permet de vrifier si entierString  est valide (entier et compris entre min et max inclus).
* <br> Si entierString  n'est pas valide la fonction retourne false sinon elle renvoie la chane de caractres formate reprsentant l'entier.
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#estEntierString_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @see #toEntier
* @param {String_Obligatoire} entierString Chane de caractres  tester.
* @param {int_Facultatif} min Entier minimum.
* @param {int_Facultatif} max Entier maximum.
* @return {boolean} : false si entierString n'est pas valide sinon retourne la  chane de caractres formate reprsentant l'entier.
* @version 1.1
* @date 25/10/2005
*/
function estEntierString( entierString, min, max)
{
  var expREG = /^[+-]?[0]*[0-9]{1,15}$/;
  var ok = expREG.test(entierString);
  if(ok)
  { var val = toEntier(entierString);
    if(min) ok = (val>=min);
    if(ok && max) ok = (val<=max);
    if(ok) return val.toString();
  }
  return false;
}

//Fonction technique pour vrifier si la saisie est nombre  virgule
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique globale de <b>conversion format simple </b> 
* toMontant( montantString); elle permet de vrifier si montantString est valide (montant) et de le convertir en objet Float.
* <br> Si montantString  n'est pas valide la fonction retourne false sinon elle renvoie un objet Float.
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#toMontant_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @param {String_Obligatoire} montantString Chane de caractres  convertir.
* @return {boolean} : false si montantString n'est pas valide sinon retourne un objet Float.
* @version 1.1
* @date 25/10/2005
*/
function toMontant( montantString)
{
  var val = parseFloat( montantString.replace(",", "."));
  if( isNaN(val)) return 0;
  else return val;
}

//Contrle de surface pour vrifier si la saisie est un nombre  virgule
//Option : vrifier si la saisie est borne numriquement, le nombre de dcimaux attendus et le sparateur de virgule
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique globale de <b>controle de format simple </b> 
* estMontantString( montantString, min, max, decim, sep); elle permet de vrifier si montantString  est valide (dcimal et compris entre min et max inclus).
* <br> Si montantString  n'est pas valide la fonction retourne false sinon elle renvoie la chane de caractres reprsentant le montant (ie nombre
* dcimal par ex. montant financier ou quantit&eaccute;) avec un separateur sep et formate au nombre de dcimales decim.
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#estMontantString_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @see #toMontant
* @param {String_Obligatoire} montantString Chane de caractres  tester.
* @param {int_Facultatif} min Montant minimum.
* @param {int_Facultatif} max Montant maximum.
* @param {int_Facultatif} decim Nb de dciales, par dfaut 0 (=nb de dcimales non prcis) - <a href='default-values_A3.html#FctTech'>Valeurs par dfaut des Fonctions techniques</a>
* @param {int_Facultatif} sep Le sparateur "." ou ",", par dfaut "."  - <a href='default-values_A3.html#FctTech'>Valeurs par dfaut des Fonctions techniques</a>
* @return {boolean} : false si montantString n'est pas valide sinon retourne la  chane de caractres reprsentant le montant (ie nombre
* dcimal par ex. montant financier ou quantit&eaccute;) formate au nombre de dcimales.
* @version 1.1
* @date 25/10/2005
*/
function estMontantString( montantString, min, max, decim, sep)
{
  var dec = (decim && decim>0 && decim <15) ? decim : 0;
  var expREG = new RegExp( (dec!=0)?"^[+-]?[0]*[0-9]{1,"+(15-dec)+"}([,.][0-9]{0,"+dec+"}[0]*)?$" : "^[+-]?[0]*[0-9]{1,15}$");
  var ok = expREG.test((dec!=0)? montantString : montantString.replace(/[.,]/, ""));
  if(ok)
  { var val = toMontant(montantString);
    if(min) ok = (val>=min);
    if(ok && max) ok = (val<=max);
    if(ok)
    { val = val.toString();
      if(dec!=0)
      { val = val+(val.indexOf(".")<0?".":"")+"000000000000000";
        val = val.substring(0,val.indexOf(".")+dec+1);
      }
      return val.replace(/[.,]/,(sep?sep:"."));
    }
  }
  return false;
}

//Fonction technique pour convertir une chane de caractres en objet Date
//Option : Format de la date
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique globale de <b>conversion de format simple </b> 
* stringToDate( dateString, formatDateSrc); elle permet de vrifier si dateString  est valide (date) et de le convertir en objet Date.
* <br> Si dateString  n'est pas valide la fonction retourne false sinon elle renvoie un objet Date au bon format.
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#stringToDate_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* <br><br><u>Format Date :</u><ul><li>Le format des dates est une chane de type "J/M/A", "A/M/J"... avec ou sans sparateur "/" ou "-"</li>
* <li>S'il n'y a pas de sparateur, le mois et le jour sont sur 2 chiffres et l'anne sur au moins 2 chiffres.</li>
* <li>En sortie, le mois et le jour sont toujours sur 2 chiffres et l'anne sur 4 chiffres.</li></ul>
* <br><br><b>Voir : </b> <a href='constant-values_A3.html#Form'>Valeurs des Constantes - Formats</a>.
* @public
* @param {String_Obligatoire} dateString Chane de caractres  convertir.
* @param {String_Facultatif} formatDateSrc Par dfaut "J/M/A" - <a href='default-values_A3.html#FctTech'>Valeurs par dfaut des Fonctions techniques</a>
* @return {boolean} : false si dateString n'est pas valide sinon retourne un objet Date au bon format.
* @version 1.1
* @date 25/10/2005
*/
function stringToDate( dateString, formatDateSrc)
{
  var frmSrc, j,m,a, rg0,rg, t, d;
  dateString = dateString.replace(new RegExp("([/-][0-9])$"),"$1-");
  rg0 = new RegExp("[/-]","g");
  frmSrc = "^"+((formatDateSrc)?formatDateSrc.toUpperCase():"J/M/A")+"$";
  frmSrc = frmSrc.replace(rg0,"");
  j = frmSrc.indexOf("J");
  m = frmSrc.indexOf("M");
  a = frmSrc.indexOf("A");
  if(j<1 || j>3 || m<1 || m>3 || a<1 || a>3) return false;

  frmSrc = frmSrc.replace("J","([0-9][/-]|[0-9]{2}[/-]?)");
  frmSrc = frmSrc.replace("M","([0-9][/-]|[0-9]{2}[/-]?)");
  frmSrc = frmSrc.replace("A","([0-9][/-]|[0-9]{2,4}[/-]?)");
  rg = new RegExp(frmSrc,"g");
  if( ! rg.test(dateString) ) return false;

  t = dateString.replace(rg, "Array($"+j+",$"+m+",$"+a+")");
  t = eval(t.replace(rg0,""));
  if(t[2] < 1000) t[2] += 2000;
  d = new Date(t[2], t[1]-1, t[0]);
  if( isNaN(d) || d.getDate() != t[0] || (d.getMonth()+1) != t[1]) return false;
  return d;
}

//Fonction technique pour convertir un objet Date en chane de caractres
//Option : Format de la date
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique globale de <b>conversion de format simple </b> 
* dateToString( dateObj, formatDateCib); elle permet de vrifier si dateObj  est valide (date) et de le convertir en chane de caractres.
* <br> Si dateObj  n'est pas valide la fonction retourne une chaine de caractres vide : "", sinon elle renvoie une chane de caractres au format formatDateCib.
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#dateToString_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @param {String_Obligatoire} dateObj Objet Date.
* @param {String_Facultatif} formatDateCib Par dfaut "J/M/A" - <a href='default-values_A3.html#FctTech'>Valeurs par dfaut des Fonctions techniques</a>
* @return {String} : "" si dateObj n'est pas valide sinon retourne une chane de caractres au format formatDateCib.
* @version 1.1
* @date 25/10/2005
*/
function dateToString( dateObj, formatDateCib)
{
  var frmCib, j,m,a;
  frmCib = ((formatDateCib)?formatDateCib.toUpperCase():"J/M/A");
  if(!dateObj) return "";
  j = dateObj.getDate();
  m = dateObj.getMonth()+1;
  a = dateObj.getFullYear();
  
  frmCib = frmCib.replace("J",((j<10)?"0":"")+j);
  frmCib = frmCib.replace("M",((m<10)?"0":"")+m);
  frmCib = frmCib.replace("A",""+a);
  return frmCib;
}

//Contrle de surface pour vrifier si la saisie est une date
//Option : vrifier si la saisie est borne en date et les formats de date d'entre/sortie
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique globale de <b>controle de format simple </b> 
* estDateString( dateString, formatDateSrc, minDateObj, maxDateObj, formatDateCib); elle permet de vrifier si dateString  est valide (date et compris entre minDateObj et maxDateObj inclus).
* <br> Si dateString  n'est pas valide la fonction retourne false sinon elle renvoie la chane de caractres formate reprsentant la date. Le format de la date initial et 
* le format de la date retourne peuvent tre diffrents, ils correspondent aux variables facultatives formatDateSrc et formatDateCib. 
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#estDateString_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @see #stringToDate
* @param {String_Obligatoire} dateString Chane de caractres  tester.
* @param {String_Facultatif} formatDateSrc Format source par dfaut "J/M/A".
* @param {Date_Facultatif} minDateObj Objet Date minimum.
* @param {Date_Facultatif} maxDateObj Objet Date maximum.
* @param {String_Facultatif} formatDateCib Format cible par dfaut gale au format source.
* @return {boolean} : false si dateString n'est pas valide sinon retourne la  chane de caractres formate reprsentant la date.
* @version 1.1
* @date 25/10/2005
*/
function estDateString( dateString, formatDateSrc, minDateObj, maxDateObj, formatDateCib)
{
  var d = stringToDate( dateString, formatDateSrc);
  if( !d || (minDateObj && d<minDateObj) || (maxDateObj && d>maxDateObj)) return false;
  return dateToString( d, formatDateCib?formatDateCib:formatDateSrc);
}

//Fonction gnrique de contrle de surface
//Option : voir documentation
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique globale de <b>controle de saisie </b> 
* ctrlSaisie(champ, msgSiVide, msgSiFormatErr, valSiErr, majSiOk, funCtrl, a1,a2,a3,a4,a5,a6,a7,a8,a9); elle permet de vrifier si le champ est valide.
* <br> Si champ  n'est pas valide la fonction retourne false sinon elle renvoie la chane de caractres formate reprsentant le contrle.
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#ctrlSaisie_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @param {ObjectDOMHTML_Obligatoire} champ Objet champ de saisie txt, password...
* @param {String_Facultatif} msgSiVide "" : le champ peut tre vide - "msg" : le champ est obligatoire, si vide : affiche msg dans fentre d'alerte 
* et positionne le focus sur champ.
* @param {String_Facultatif} msgSiFormatErr "" : ne contrle pas le format - "msg" : excute la fonction de contrle sur le champ, 
* si erreur affiche msg dans fentre d'alerte et positionne le focus sur champ.
* @param {String_Facultatif} valSiErr "": rien - "valeur par defaut" : si erreur remplace par la valeur par default.
* @param {Boolean_Facultatif} majSiOk False: rien - True : si contrle OK, remplace par la valeur formate de retour de la fonction de contrle de format.
* @param {funcCtrl_Facultatif} funCtrlOption Fonction de contrle de saisie (funCtrl) et ses arguments (a1  a9)
* @param {arg_Facultatif} a1 Argument de la fonction de contrle de saisie (funCtrl)
* @param {arg_Facultatif} a2 Argument de la fonction de contrle de saisie (funCtrl)
* @param {arg_Facultatif} a3 Argument de la fonction de contrle de saisie (funCtrl)
* @param {arg_Facultatif} a4 Argument de la fonction de contrle de saisie (funCtrl)
* @param {arg_Facultatif} a5 Argument de la fonction de contrle de saisie (funCtrl)
* @param {arg_Facultatif} a6 Argument de la fonction de contrle de saisie (funCtrl)
* @param {arg_Facultatif} a7 Argument de la fonction de contrle de saisie (funCtrl)
* @param {arg_Facultatif} a8 Argument de la fonction de contrle de saisie (funCtrl)
* @param {arg_Facultatif} a9 Argument de la fonction de contrle de saisie (funCtrl)
* @return {boolean} : false si champ n'est pas valide sinon retourne la  chane de caractres formate reprsentant le contrle.
* @version 1.1
* @date 25/10/2005
*/
function ctrlSaisie(champ, msgSiVide, msgSiFormatErr, valSiErr, majSiOk, funCtrl, a1,a2,a3,a4,a5,a6,a7,a8,a9)
{
  var ret = true;
  if( champ.value.length > 0)
  {
    if(funCtrl)
    {
      ret = funCtrl(champ.value,a1,a2,a3,a4,a5,a6,a7,a8,a9);
      if(!ret && msgSiFormatErr) alert(msgSiFormatErr);
      if(ret && majSiOk) champ.value = ret;
    }
  }
  else
  {
    if(msgSiVide) {ret=false; alert(msgSiVide);}
  }
  if(!ret && valSiErr) champ.value = valSiErr;
  if(!ret && (msgSiVide || msgSiFormatErr)) {try{champ.focus();}catch(e){}}
  return ret;
}

//Fonction technique pour interdire la slection d'une option d'une bote de slection
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique globale de <b>contrle </b> 
* ctrlComboSelect(champCombo,indiceInterdit,msgSiIndiceInterdit); elle contrle si l'indice selectionn dans la liste est diffrent de 'indiceInterdit',
* sinon elle affiche un message d'alerte et positionne le focus sur le select.
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#ctrlComboSelect_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @param {ObjetDOMHTML_Obligatoire} champCombo Objet DOM HTML de type combo ou select en HTML.
* @param {int_Obligatoire} indiceInterdit Entier indiquant l' indice du combo  interdir, ex : 0.
* @param {String_Obligatoire} msgSiIndiceInterdit String indiquant le message  afficher.
* @return {boolean} : false si l'indice selectionn est diffrent de 'indiceInterdit' sinon raffiche un message d'alert et positionne le focus sur le select.
* @version 1.1
* @date 25/10/2005
*/
function ctrlComboSelect(champCombo,indiceInterdit,msgSiIndiceInterdit)
{
  var ret = champCombo.selectedIndex != indiceInterdit;
  if (!ret)
  {	
    alert(msgSiIndiceInterdit);
    try {champCombo.focus();}
    catch(e){}
  }
  return ret;
}

//Fonction technique pour remplacer le symbole euro HTML &#8364; par E
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique
* remplaceSaisieEuro(maString); elle permet de remplacer le symbole &#8364; par E.
* @public
* @param {String_Obligatoire} maString Chane initiale comprenant le symbole &#8364;  remplacer.
* @return {String} : chane contenant E au lieu de &#8364;
* @version 1.1
* @date 25/10/2005
*/
function remplaceSaisieEuro(maString)
{
  var carEuro = String.fromCharCode(8364);
  var retString = maString;
  var i;

  while((i = retString.indexOf(carEuro)) >= 0)
  {
    retString = retString.substring(0,i) + "E" + retString.substring(i+1, retString.length);
  }
  return retString ;
}

//Fonction technique pour vrifier si une chane de caractres ne contient que des espaces
/**
* Le framework technique <a href='overview-summary-technique_fw_cs.js.html'>fw_cs.js</a>  propose la fonction technique globale de <b>contrle </b> 
* estBlancString(maString); elle teste si une chane de caractres ne contient que des caractres blancs. Elle renvoie un
* boolen (true (1) si c'est le cas et sinon false(0)).
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#estBlancString_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @see #estFormatString
* @param {String_Obligatoire} maString String  tester.
* @return {boolean}
* @version 1.1
* @date 25/10/2005
*/
function estBlancString(maString )
{
  if(estFormatString(maString,"^ +$"))return true;
  else return false;
}

//Fonction technique pour controler le format d'une adresse e-mail
/**
*Fonction permettant de controler le format d'une adresse e-mail en s'appuyant sur l'expression rgulire suivante:</br>
*"^[a-zA-Z0-9][-._a-zA-Z0-9]*@[a-zA-Z0-9][-._a-zA-Z0-9]*\.[a-zA-Z]{2,4}$"
* @public
* @param {String_Obligatoire} emailStr la chane reprsentant l'e-mail  contrler 
* @return {boolean}
* @version 2.4
* @date 14/11/2006
*/
function estAdresseEmailString(emailStr)
{
	var result=false;
	if(emailStr!=null)
	{
		var tmp=emailStr.match(/^[a-zA-Z0-9][-._a-zA-Z0-9]*@[a-zA-Z0-9][-._a-zA-Z0-9]*\.[a-zA-Z]{2,4}$/)
		if (tmp!=null)
			if(tmp.length==1)
				result=true;
 	}
 	return result;
}