/** 
* @fileoverview Ce fichier Javascript correspond au framework de gestion des formulaires.
* Cette description consiste  prsenter les prototypes des <b>fonctions de validation</b>, des exemples d'appel et les prcisions
* techniques ncessaires  la mise en oeuvre de ce framework.<br>
* <br><br><b>Voir exemple de dclaration d'une fonction de validation de formulaire et de ses appels sur :  clic d'un lien, clic d'un bouton, {@link #initForm touche 'Entre'} - </b><a href='exemples_A3.html#fw_form_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* <br>
* @author Ministre des Affaires Etrangres, Aubay SA, Steve Pguet
* @version 1.1
* @date 25/10/2005
*/
/*
Copyright ou  ou Copr. 
Ministre des Affaires Etrangres,
Aubay SA,
Steve Pguet, (07/07/2003)

steve.peguet@diplomatie.gouv.fr

Ce logiciel est un programme informatique servant de framework JavaScript 
bas sur les normes W3C (XHTML/CSS/DOM/XML). Il offre la possibilit de 
mettre en uvre facilement les principes ergonomiques et techniques propres 
 un client riche (cumul des avantages du client lger et du client lourd).
Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilit au code source et des droits de copie,
de modification et de redistribution accords par cette licence, il n'est
offert aux utilisateurs qu'une garantie limite.  Pour les mmes raisons,
seule une responsabilit restreinte pse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concdants successifs.

A cet gard  l'attention de l'utilisateur est attire sur les risques
associs au chargement,   l'utilisation,   la modification et/ou au
dveloppement et  la reproduction du logiciel par l'utilisateur tant 
donn sa spcificit de logiciel libre, qui peut le rendre complexe  
manipuler et qui le rserve donc  des dveloppeurs et des professionnels
avertis possdant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invits  charger  et  tester  l'adquation  du
logiciel  leurs besoins dans des conditions permettant d'assurer la
scurit de leurs systmes et ou de leurs donnes et, plus gnralement, 
 l'utiliser et l'exploiter dans les mmes conditions de scurit. 

Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
pris connaissance de la licence CeCILL, et que vous en avez accept les
termes.*/

//Variable pour tester la prsence d'Opra
var estOpera = (navigator.userAgent.toLowerCase().indexOf("opera")) != -1 ? 1 : 0;

//Fonctions techniques pour activer ou non des fonctions
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_form.js.html'>fw_form.js</a>  propose la fonction technique
* fctfalse(); elle permet de dsactiver une fonction.
* @public
* @param {} Aucun
* @return {boolean} : false.
* @version 1.1
* @date 25/10/2005
*/
function fctfalse(){return false;};

/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_form.js.html'>fw_form.js</a>  propose la fonction technique
* fcttrue(); elle permet d'activer une fonction.
* @public
* @param {} Aucun
* @return {boolean} : true
* @version 1.1
* @date 25/10/2005
*/
function fcttrue(){return true;};

//Gestion d'vnement pour NS 4.X 
if (navigator.appName.indexOf("Netscape") >= 0)
  document.captureEvents(Event.KEYDOWN);

//Enregistrement d'vnement pour grer la touche ENTER
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_form.js.html'>fw_form.js</a> propose la fonction globale
* fctOnKeyDown(e); elle permet d'enregistrer un vnement pour grer la touche ENTER. La touche sera alors associe  l'vnement e.
* @public
* @see #fctKeyDown13
* @param {String_Obligatoire} e Evnement enregistr pour grer la touche ENTER.
* @return {Object}
* @version 1.1
* @date 25/10/2005
*/
function fctOnKeyDown(e)
{
  var key = e ? (e.which ? e.which : e.keyCode) : event.keyCode;
  var elm = e ? e.target : event.srcElement;
  if (key == 13 && elm.form && elm.type!="button" && elm.type!="textarea")
    return document.onkeydown13(elm);
}

//Fonction pour associer une fonction aux liens d'une page
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_form.js.html'>fw_form.js</a>  propose la fonction globale
* fctClickLink(fct); elle permet d'associer une fonction aux liens d'une page.
* @public
* @param {String_Obligatoire} fct fonction associe aux liens de la page.
* @return {void}
* @version 1.1
* @date 25/10/2005
*/
function fctClickLink(fct)
{
  for(var i=0; i<document.links.length; i++)
  {
    if (fct)
      document.links[i].onclick = fct;
  }
}

//Fonction pour associer une fonction de validation  un formulaire
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_form.js.html'>fw_form.js</a>  propose la fonction globale
* fctClickForm(fct,fct2); elle permet d'associer une fonction de validation  un formulaire.
* @public
* @param {String_Obligatoire} fct fonction de validation associe au formulaire.
* @param {String_Obligatoire} fct2 fonction appele  la soumission du formulaire.
* @return {void}
* @version 1.1
* @date 25/10/2005
*/
function fctClickForm(fct,fct2)
{
  for (var i=0; i<document.forms.length; i++ )
  { 
    document.forms[i].onsubmit = fct2?fct2:fctfalse;
    if (fct)
    { 
      for (var j=0;j<document.forms[i].elements.length; j++ )
      {
        if (document.forms[i].elements[j].type=="button")
          document.forms[i].elements[j].onclick = fct;
      }
    }
  }  
}

//Fonction associe  la touche ENTER
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_form.js.html'>fw_form.js</a>  propose la fonction globale
* fctKeyDown13(fct); elle permet d'associer une fonction  la touche ENTER.
* @public
* @param {String_Obligatoire} fct fonction  associe  la touche ENTER.
* @return {void}
* @version 1.1
* @date 25/10/2005
*/
function fctKeyDown13(fct)
{
  document.onkeydown13 = fct?fct:fcttrue;
  document.onkeydown = fctOnKeyDown;
}

//Fonction d'initialisation du formualaire vis  vis de la fonction de validation
//La touche ENTER est associe  la validation du formulaire et au lancement de fct
/**
* Le framework technique <a href='overview-summary-technique_fw_form.js.html'>fw_form.js</a>  propose la <b>fonction liee  la validation de formulaire</b>
* initForm(fct); c'est la fonction d'initialisation pour la gestion des formulaires et d'affectation de la fonction de validation de formulaire sur l'vnement touche 'Entre'. 
* <br>La touche "Entre" est associe  la validation du formulaire et au lancement de la fonction fct.
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#initForm_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @see #fctClickForm
* @see #fctKeyDown13
* @param {String_Facultatif} fct Fonction de validation de formulaire  appeler, prototype : valider(elem) - elem est l'objet lment qui a
* provoqu l'vnement touche 'Entre'.
* @return {void}
* @version 1.1
* @date 25/10/2005
*/
function initForm(fct)
{
  fctClickForm(0,fctfalse);
  fctKeyDown13(fct);
}

//Fonction qui dsactive les autres actions de la page en attendant le rsultat de la validation du formulaire
/**
* Le framework technique <a href='overview-summary-technique_fw_form.js.html'>fw_form.js</a>  propose la <b>fonction lie  la validation de formulaire</b>
* disableAllAction(); c'est la fonction de dsactivation de toutes les actions click et touche 'Entre' de l'ensemble des formulaires prsents dans la page.
* Cette fonction permet d'attendre le rsultat de la validation du formulaire.
* @public
* @see #fctClickLink
* @see #fctClickForm
* @see #fctKeyDown13
* @param {} Aucun
* @return {void}
* @version 1.1
* @date 25/10/2005
*/
function disableAllAction()
{
  fctClickLink(fctfalse);
  if (estOpera) 
    fctClickForm(0,fcttrue);
  setTimeout("fctClickForm(fctfalse,fctfalse)",1);
  fctKeyDown13(fctfalse);
}