/** 
* @fileoverview Ce fichier Javascript correspond au framework de gestion des mises en forme de donnes.
* Cette description consiste  prsenter les prototypes des <b>fonctions techniques</b>, des exemples d'appel et les prcisions
* techniques ncessaires  la mise en oeuvre de ce framework.<br>
* <br>Les <b>fonctions techniques de mise en formes</b> permettent  partir d'une chane de caractres de mettre en forme son contenu : <b>Voir</b> {@link # toEntier}.
* <br><br><b>Voir exemple d'utilisation des fonctions techniques pour des mises en formes dans un tableau : </b><a href='exemples_A3.html#fw_format_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* <br>
* @author Ministre des Affaires Etrangres, Aubay SA
* @version 2.3
* @date 28/09/2006
*/
/*
Copyright ou  ou Copr. 
Ministre des Affaires Etrangres,
Aubay SA,

Ce logiciel est un programme informatique servant de framework JavaScript 
bas sur les normes W3C (XHTML/CSS/DOM/XML). Il offre la possibilit de 
mettre en uvre facilement les principes ergonomiques et techniques propres 
 un client riche (cumul des avantages du client lger et du client lourd).
Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilit au code source et des droits de copie,
de modification et de redistribution accords par cette licence, il n'est
offert aux utilisateurs qu'une garantie limite.  Pour les mmes raisons,
seule une responsabilit restreinte pse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concdants successifs.

A cet gard  l'attention de l'utilisateur est attire sur les risques
associs au chargement,   l'utilisation,   la modification et/ou au
dveloppement et  la reproduction du logiciel par l'utilisateur tant 
donn sa spcificit de logiciel libre, qui peut le rendre complexe  
manipuler et qui le rserve donc  des dveloppeurs et des professionnels
avertis possdant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invits  charger  et  tester  l'adquation  du
logiciel  leurs besoins dans des conditions permettant d'assurer la
scurit de leurs systmes et ou de leurs donnes et, plus gnralement, 
 l'utiliser et l'exploiter dans les mmes conditions de scurit. 

Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
pris connaissance de la licence CeCILL, et que vous en avez accept les
termes.*/

//Objet NumberFormat 
/**
* Cre une nouvelle instance NumberFormat.<br> 
* Le constructeur de NumberFormat cre une instance de la classe , utile pour appeler soit les mthodes publiques associes  cette dernire
* soit pour interroger ses proprits publiques.
* @class La classe <b>NumberFormat</b> est la classe permettant de manipuler les nombres et leurs diffrentes formes possibles.
* @constructor
* @param {String_Obligatoire} num nombre principal manipul dans la classe
* @param {String_Facultatif} inputDecimal caractre qui caractrisera un nobre dcimal (par dfaut this.PERIOD)
* @version 2.4
* @date 14/11/2006
*/
function NumberFormat(num, inputDecimal)
{
// Attributs : CONSTANTES
	// Version de la classe
	/**
	* Numro de version de la classe
	* @public
	* @final
	* @type String
	*/
	this.VERSION = 'Number Format v1.5.4';
	
	//Caractres utiles
	/**
	* Virgule
	* @private
	* @final
	* @type String
	*/
	this.COMMA = ',';	

	/**
	* Sparateur de milliers (point)
	* @private
	* @final
	* @type String
	*/
	this.PERIOD = '.';
	
	/**
	* Tiret
	* @private
	* @final
	* @type String
	*/
	this.DASH = '-'; 
	
	/**
	* Parenthse gauche
	* @private
	* @final
	* @type String
	*/
	this.LEFT_PAREN = '('; 
	
	/**
	* Parenthse droite
	* @private
	* @final
	* @type String
	*/
	this.RIGHT_PAREN = ')';
	
	//Caractres de controle 
	/**
	* Indice de position 0
	* @private
	* @final
	* @type number
	*/
	this.LEFT_OUTSIDE = 0;
	
	/**
	* Indice de position 1
	* @private
	* @final
	* @type number
	*/
	this.LEFT_INSIDE = 1;  
	
	/**
	* Indice de position 2
	* @private
	* @final
	* @type number
	*/
	this.RIGHT_INSIDE = 2;  
	
	/**
	* Indice de position 3
	* @private
	* @final
	* @type number
	*/
	this.RIGHT_OUTSIDE = 3;  
	
	/**
	* Indice 0
	* @private
	* @final
	* @type number
	*/
	this.LEFT_DASH = 0; 
	
	/**
	* Indice 1
	* @private
	* @final
	* @type number
	*/
	this.RIGHT_DASH = 1; 
	
	/**
	* Indice 2
	* @private
	* @final
	* @type number
	*/
	this.PARENTHESIS = 2; 
	
	/**
	* Indice -1
	* @private
	* @final
	* @type number
	*/
	this.NO_ROUNDING = -1 

//Attributs de la classe

/**
* Nombre.
* @public
* @type String 
* @version 2.4
* @date 14/11/2006
*/
	this.num;
	
/**
* Sauvegarde du nombre num.
* @public
* @type String
* @version 2.4
* @date 14/11/2006
*/ 
	this.numOriginal;

/**
* Variable mise  jour lors des initialisations de sparateurs.
* @private
* @type boolean
* @version 2.4
* @date 14/11/2006
*/ 
	this.hasSeparators = false;  

/**
* Caractre sparateur de milliers dans un nombre (xx,xxx,xxx), par dfaut this.COMA.
* @private
* @type String
* @version 2.4
* @date 14/11/2006
*/ 
	this.separatorValue; 

/**
* Caractre de sparation dans les nombres dcimaux entre partie entire et partie dcimale,
* par dfaut this.PERIOD.
* @public
* @type String
* @version 2.4
* @date 14/11/2006
*/ 
	this.inputDecimalValue; 

/**
* Partie dcimale d'un nombre.
* @private
* @type int
* @version 2.4
* @date 14/11/2006
*/ 
	this.decimalValue;  
	
/**
* Caractre reprsentant le format ngatif.
* @public
* @type String 
* @version 2.4
* @date 14/11/2006
*/
	this.negativeFormat; 
	
/**
* Pour affichage ou non des nombres ngatifs sur fond rouge.
* @public
* @type boolean
* @version 2.4
* @date 14/11/2006
*/
	this.negativeRed; 
	
/**
* Variable signifiant s'il existe une position courante ( mettre  jour).
* @public
* @type boolean
* @version 2.4
* @date 14/11/2006
*/
	this.hasCurrency;  
	
/**
* Position courante dans l'objet nombre.
* @public
* @type int
* @version 2.4
* @date 14/11/2006
*/
	this.currencyPosition;  
	
/**
* Valeur courante.
* @public
* @type String
* @version 2.4
* @date 14/11/2006
*/
	this.currencyValue;  

/**
* Nombre de chiffres aprs la virgule.
* @public
* @type int 
* @version 2.4
* @date 14/11/2006
*/
	this.places;
	
	/**
* On arrondit les rsultats si cette variable est  true.
* @private
* @type boolean
* @version 2.4
* @date 14/11/2006
*/
	this.roundToPlaces; 
	
/**
* S'il est renseign  true, les arrondis seront effectus par dfaut (et non par excs).
* @private
* @type boolean
* @version 2.4
* @date 14/11/2006
*/
	this.truncate; 
	
//Dfinition des mthodes spcifiques, voir commentaires individuels ci-dessous
	this.setNumber = setNumberNF;
	this.toUnformatted = toUnformattedNF;
	this.setInputDecimal = setInputDecimalNF; 
	this.setSeparators = setSeparatorsNF; 
	this.setCommas = setCommasNF;
	this.setNegativeFormat = setNegativeFormatNF; 
	this.setNegativeRed = setNegativeRedNF; 
	this.setCurrency = setCurrencyNF;
	this.setCurrencyPrefix = setCurrencyPrefixNF;
	this.setCurrencyValue = setCurrencyValueNF; 
	this.setCurrencyPosition = setCurrencyPositionNF; 
	this.setPlaces = setPlacesNF;
	this.toFormatted = toFormattedNF;
	this.toPercentage = toPercentageNF;
	this.getOriginal = getOriginalNF;
	this.moveDecimalRight = moveDecimalRightNF;
	this.moveDecimalLeft = moveDecimalLeftNF;
	this.getRounded = getRoundedNF;
	this.preserveZeros = preserveZerosNF;
	this.justNumber = justNumberNF;
	this.expandExponential = expandExponentialNF;
	this.getZeros = getZerosNF;
	this.moveDecimalAsString = moveDecimalAsStringNF;
	this.moveDecimal = moveDecimalNF;
	this.addSeparators = addSeparatorsNF;
	this.dateFormat = dateFormatNF;
	this.monnaieFormat = monnaieFormatNF;
	this.entierFormat = entierFormat;
	this.numberFormat = numberFormat;

//Initialisation de l'objet NumberFormat	
	if (inputDecimal == null) {
		this.setNumber(num, this.PERIOD);
	} else {
		this.setNumber(num, inputDecimal); 
	}
	this.setCommas(true);
	this.setNegativeFormat(this.LEFT_DASH); 
	this.setNegativeRed(false); 
	this.setCurrency(false); 
	this.setCurrencyPrefix('$');
	this.setPlaces(2);
}

//Mthode d'initialisation de l'attribut inputDecimalValue de l'objet NumberFormat 
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a> propose la mthode
* setInputDecimal; elle permet d'initialiser l'attribut inputDecimalValue de l'objet NumberFormat.
* @public
* @param {String_Obligatoire} val Nombre dcimal
* @return {void}
* @version 2.4
* @date 14/11/2006
*/	
function setInputDecimalNF(val)
{
	this.inputDecimalValue = val;
}

//Reinitialisation des attributs num et inputDecimalValue
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la mthode
* setNumber; elle permet de rinitialiser l'attribut num par un nombre format, de sauvegarder sa valeur initiale,
* et de rinitialiser en mme temps l'attribut inputDecimalValue. Ces attributs appartiennent  l'objet NumberFormat.
* @public
* @see #justNumber
* @see #setInputDecimal
* @param {String_Obligatoire} num Nombre  formater pour rinitialisation de l'attribut num
* @param {String_Optionnel} inputDecimal Decimal pour rinitialisation de inputDecimalValue
* @return {void}
* @version 2.4
* @date 14/11/2006
*/
function setNumberNF(num, inputDecimal)
{
	if (inputDecimal != null) {
		this.setInputDecimal(inputDecimal); 
	}
	this.numOriginal = num;
	this.num = this.justNumber(num);
}

//Fonction retournant l'attribut num
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la fonction globale
* toUnformatted; elle permet d'accder  l'attribut num de l'objet NumberFormat.
* @public
* @param {} Aucun
* @return {number} : attribut num de l'objet NumberFormat
* @version 2.4
* @date 14/11/2006
*/
function toUnformattedNF()
{
	return (this.num);
}

//Fonction retournant l'attribut de sauvegarde numOriginal
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a> propose la fonction
* getOriginal; elle permet d'accder  l'attribut de sauvegarde numOriginal de l'objet NumberFormat.
* @public
* @param {} Aucun
* @return {number} : attribut numOriginal de l'objet NumberFormat
* @version 2.4
* @date 14/11/2006
*/
function getOriginalNF()
{
	return (this.numOriginal);
}

//Reinitialisation de l'attribut negativeFormat
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la mthode
* setNegativeFormat; elle permet de rinitialiser l'attribut negativeFormat de l'objet NumberFormat par un argument en paramtre. 
* @public
* @param {String_Obligatoire} format String correspondant  la nouvelle valeur de l'attribut negativeFormat
* @return {void}
* @version 2.4
* @date 14/11/2006
*/
function setNegativeFormatNF(format)
{
	this.negativeFormat = format;
}

//Reinitialisation de l'attribut negativeRed
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la mthode
* setNegativeRed; elle permet de rinitialiser l'attribut negativeRed de l'objet NumberFormat par un argument en paramtre. 
* @public
* @param {String_Obligatoire} isRed String correspondant  la nouvelle valeur de l'attribut negativeRed
* @return {void}
* @version 2.4
* @date 14/11/2006
*/
function setNegativeRedNF(isRed)
{
	this.negativeRed = isRed;
}

//Reinitialisation des attributs decimalValue et separatorValue, mais galement hasSeparators 
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la mthode
* setSeparators; elle permet de rinitialiser les attributs decimalValue et separatorValue de l'objet NumberFormat par des arguments en paramtre
* Elle rinitialise galement le boolen hasSeparators avec isC.
* @public
* @param {boolean_Obligatoire} isC Boolen pour rinitialiser l'attribut hasSeparators
* @param {String_Facultatif} separator String pour rinitialiser l'attribut separator
* @param {String_Facultatif} decimal String pour rinitialiser l'attribut decimalValue
* @return {void}
* @version 2.4
* @date 14/11/2006
*/
function setSeparatorsNF(isC, separator, decimal)
{
	this.hasSeparators = isC;
	if (separator == null) separator = this.COMMA;
	if (decimal == null) decimal = this.PERIOD;
	if (separator == decimal) {
		this.decimalValue = (decimal == this.PERIOD) ? this.COMMA : this.PERIOD;
	} else {
		this.decimalValue = decimal;
	}
	this.separatorValue = separator;
}

//Rinitialisation du sparateur de nombre et du sparateur dcimal. Mise  jour de l'attribut hasSeparators 
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la mthode
* setCommas; elle permet de rinitialiser  leurs valeurs par dfaut le sparateur de nombre (separatorValue) 
* et le sparateur dcimal (decimalValue) de l'objet NumberFormat.<br> Elle met galement  jour
* l'attribut hasSeparators  partir de la variable isC passe en argument. 
* @public
* @see #setSeparators
* @param {boolean_Obligatoire} isC boolen pour rinitialiser l'attribut hasSeparators
* @return {void}
* @version 2.4
* @date 14/11/2006
*/
function setCommasNF(isC)
{
	this.setSeparators(isC, this.COMMA, this.PERIOD);
}

//Rinitialisation de l'attribut hasCurrency de l'objet NumberFormat 
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la mthode
* setCurrency; elle permet de rinitialiser l'attribut hasCurrency de l'objet NumberFormat par une variable passe en paramtre.
* @public
* @param {boolean_Obligatoire} isC boolen pour rinitialiser l'attribut hasCurrency
* @return {void}
* @version 2.4
* @date 14/11/2006
*/
function setCurrencyNF(isC)
{
	this.hasCurrency = isC;
}

//Rinitialisation de l'attribut currencyValue de l'objet NumberFormat 
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la mthode
* setCurrencyValue; elle permet de rinitialiser l'attribut currencyValue de l'objet NumberFormat par une valeur passe en paramtre.
* @public
* @param {String_Obligatoire} val valeur pour rinitialiser l'attribut currencyValue
* @return {void}
* @version 2.4
* @date 14/11/2006
*/
function setCurrencyValueNF(val)
{
	this.currencyValue = val;
}

//Rinitialisation de la valeur courante (currencyValue) et de la position courante (currencyPosition)
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la fonction globale
* setCurrencyPrefix; elle permet de rinitialiser la valeur courante (currencyValue) et la position courante (currencyPosition) de l'objet NumberFormat.<br> 
* La position courante sera initialise par dfaut ( LEFT_OUTSIDE), tandis que la valeur correspondra au paramtre de la fonction.
* @public
* @see #setCurrencyValue
* @see #setCurrencyPrefix
* @param {String_Obligatoire} cp valeur pour rinitialiser l'attribut currencyValue
* @return {void}
* @version 2.4
* @date 14/11/2006
*/
function setCurrencyPrefixNF(cp)
{
	this.setCurrencyValue(cp);
	this.setCurrencyPosition(this.LEFT_OUTSIDE);
}

//Rinitialisation de l'attribut currencyPosition de l'objet NumberFormat
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la mthode
* setCurrencyPosition; elle permet de rinitialiser l'attribut currencyPosition de l'objet NumberFormat par une valeur passe en paramtre.
* @public
* @param {String_Obligatoire} cp variable pour rinitialiser l'attribut currencyPosition
* @return {void}
* @version 2.4
* @date 14/11/2006
*/
function setCurrencyPositionNF(cp)
{
	this.currencyPosition = cp
}

//Rinitialisation des variables roundToPlaces, truncate et places.
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la fonction globale
* setPlaces; elle permet de rinitialiser les variables roundToPlaces, truncate et places de l'objet NumberFormat.
* @public
* @param {String_Obligatoire} p nombre 
* @param {boolean_Facultatif} tr boolen
* @return {void}
* @version 2.4
* @date 14/11/2006
*/
function setPlacesNF(p, tr)
{
	this.roundToPlaces = !(p == this.NO_ROUNDING); 
	this.truncate = (tr != null && tr); 
	this.places = (p < 0) ? 0 : p; 
}

//Fonction ajoutant des sparateurs : sparateur outD aprs caractre inD dans nStr, et sparateur sep de milliers. 
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la mthode
* addSeparators; elle permet d'ajouter des sparateurs dans un nombre nStr donn. <br>
* Elle ajoute le sparateur outD aprs la premire occurence de inD dans nStr. <br>
* Elle ajoute le sparateur sep entre les milliers du nombre.
* @public
* @param {String_Facultatif} nStr Nombre sur lequel la fonction travaille
* @param {String_Facultatif} inD caractre qui sera recherch dans nStr pour ajout d'un sparateur outD
* @param {String_Facultatif} outD caractre qui sera ajout aprs la premire occurence de inD
* @param {String_Facultatif} sep sparateur de milliers dans un nombre (avec sep="." : xx.xxx.xxx)
* @return {String} reprsentant un nombre avec nouveaux sparateurs
* @version 2.4
* @date 14/11/2006
*/
function addSeparatorsNF(nStr, inD, outD, sep)
{
	nStr += '';
	var dpos = nStr.indexOf(inD);
	var nStrEnd = '';
	if (dpos != -1) {
		nStrEnd = outD + nStr.substring(dpos + 1, nStr.length);
		nStr = nStr.substring(0, dpos);
	}
	var rgx = /(\d+)(\d{3})/;
	while (rgx.test(nStr)) {
		nStr = nStr.replace(rgx, '$1' + sep + '$2');
	}
	return nStr + nStrEnd;
}

//Fonction pour changer le format d'un nombre (parenthses, signe)
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la mthode
* toFormatted; elle permet de  changer le format d'un nombre (parenthses, signe)
* @private
* @see #addSeparators
* @param {} Aucun
* @return {String} : nombre format
* @version 2.4
* @date 14/11/2006
*/
function toFormattedNF()
{	
	var pos;
	var nNum = this.num; 
	var nStr;            
	var splitString = new Array(2);   
	if (this.roundToPlaces) {
		nNum = this.getRounded(nNum);
		nStr = this.preserveZeros(Math.abs(nNum)); 
	} else {
		nStr = this.expandExponential(Math.abs(nNum)); 
	}
	if (this.hasSeparators) {
		nStr = this.addSeparators(nStr, this.PERIOD, this.decimalValue, this.separatorValue);
	} else {
		nStr = nStr.replace(new RegExp('\\' + this.PERIOD), this.decimalValue); 
	}
	var c0 = '';
	var n0 = '';
	var c1 = '';
	var n1 = '';
	var n2 = '';
	var c2 = '';
	var n3 = '';
	var c3 = '';
	var negSignL = (this.negativeFormat == this.PARENTHESIS) ? this.LEFT_PAREN : this.DASH;
	var negSignR = (this.negativeFormat == this.PARENTHESIS) ? this.RIGHT_PAREN : this.DASH;
	if (this.currencyPosition == this.LEFT_OUTSIDE) {
		if (nNum < 0) {
			if (this.negativeFormat == this.LEFT_DASH || this.negativeFormat == this.PARENTHESIS) n1 = negSignL;
			if (this.negativeFormat == this.RIGHT_DASH || this.negativeFormat == this.PARENTHESIS) n2 = negSignR;
		}
		if (this.hasCurrency) c0 = this.currencyValue;
	} 
	else if (this.currencyPosition == this.LEFT_INSIDE) {
		if (nNum < 0) {
			if (this.negativeFormat == this.LEFT_DASH || this.negativeFormat == this.PARENTHESIS) n0 = negSignL;
			if (this.negativeFormat == this.RIGHT_DASH || this.negativeFormat == this.PARENTHESIS) n3 = negSignR;
		}
		if (this.hasCurrency) c1 = this.currencyValue;
	}	
	else if (this.currencyPosition == this.RIGHT_INSIDE) {
		if (nNum < 0) {
			if (this.negativeFormat == this.LEFT_DASH || this.negativeFormat == this.PARENTHESIS) n0 = negSignL;
			if (this.negativeFormat == this.RIGHT_DASH || this.negativeFormat == this.PARENTHESIS) n3 = negSignR;
		}
		if (this.hasCurrency) c2 = this.currencyValue;
	} 
	else if (this.currencyPosition == this.RIGHT_OUTSIDE) {
		if (nNum < 0) {
			if (this.negativeFormat == this.LEFT_DASH || this.negativeFormat == this.PARENTHESIS) n1 = negSignL;
			if (this.negativeFormat == this.RIGHT_DASH || this.negativeFormat == this.PARENTHESIS) n2 = negSignR;
		}
		if (this.hasCurrency) c3 = this.currencyValue;
	}
	nStr = c0 + n0 + c1 + n1 + nStr + n2 + c2 + n3 + c3;
	if (this.negativeRed && nNum < 0) {
		nStr = '<font color="red">' + nStr + '</font>';
	}
	return (nStr);
}

//Fonction de conversion de num en pourcentage.
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la fonction globale
* toPercentage; elle permet de convertir le nombre num associ  l'objet NumberFormat en pourcentage, tout en l'arrondissant.
* @public
* @see #getRounded
* @param {} Aucun
* @return {String} : nombre en pourcentage xx%
* @version 2.4
* @date 14/11/2006
*/
function toPercentageNF()
{
	nNum = this.num * 100;
	nNum = this.getRounded(nNum);
	return nNum + '%';
}

//Fonction qui cre un nombre contenant des zros (places correspond au nombre de 0)
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la mthode
* getZeros; elle permet de crer un nombre contenant des zros. Elle est appele par d'autres mthodes de l'objet NumberFormat.
* @private
* @param {String_Obligatoire} places nombre de zros souhaits
* @return {String} : nombre sous forme de String compos de zros
* @version 2.4
* @date 14/11/2006
*/
function getZerosNF(places)
{
	var extraZ = '';
	var i;
	for (i=0; i<places; i++) {
		extraZ += '0';
	}
	return extraZ;
}

//Mthode pour dcalage de la virgule dans un nombre
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la mthode
* expandExponential; elle permet de dcaler la virgule d'un nombre
* @private
* @see #moveDecimalAsString
* @param {String_Obligatoire} origVal Nombre sur lequel on travaille
* @return {number} : nombre reformat
* @version 2.4
* @date 14/11/2006
*/
function expandExponentialNF(origVal)
{
	if (isNaN(origVal)) return origVal;
	var newVal = parseFloat(origVal) + ''; 
	var eLoc = newVal.toLowerCase().indexOf('e');
	if (eLoc != -1) {
		var plusLoc = newVal.toLowerCase().indexOf('+');
		var negLoc = newVal.toLowerCase().indexOf('-', eLoc); 
		var justNumber = newVal.substring(0, eLoc);
		if (negLoc != -1) {
			var places = newVal.substring(negLoc + 1, newVal.length);
			justNumber = this.moveDecimalAsString(justNumber, true, parseInt(places));
		} else {
			if (plusLoc == -1) plusLoc = eLoc;
			var places = newVal.substring(plusLoc + 1, newVal.length);
			justNumber = this.moveDecimalAsString(justNumber, false, parseInt(places));
		}
		newVal = justNumber;
	}
	return newVal;
} 

//Fonction qui dcale le caractre dcimal (.) d'un nombre de places vers la droite dans un nombre val 
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la fonction globale
* moveDecimalRight; elle permet de dcaler le caractre dcimal (.) d'un nombre de places vers la droite dans un nombre val.
* @public
* @see #moveDecimal
* @param {String_Facultatif} val Nombre sur lequel on travaille
* @param {String_Optionnel} places nombre de chiffres  dcaler
* @return {number}
* @version 2.4
* @date 14/11/2006
*/
function moveDecimalRightNF(val, places)
{
	var newVal = '';
	if (places == null) {
		newVal = this.moveDecimal(val, false);
	} else {
		newVal = this.moveDecimal(val, false, places);
	}
	return newVal;
}

//Fonction qui dcale le caractre dcimal (.) d'un nombre de places vers la gauche dans un nombre val 
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la fonction globale
* moveDecimalLeft; elle permet de dcaler le caractre dcimal (.) d'un nombre de places vers la gauche dans un nombre val.
* @public
* @see #moveDecimal
* @param {String_Facultatif} val Nombre sur lequel on travaille
* @param {String_Optionnel} places nombre de chiffres  dcaler
* @return {number}
* @version 2.4
* @date 14/11/2006
*/
function moveDecimalLeftNF(val, places)
{
	var newVal = '';
	if (places == null) {
		newVal = this.moveDecimal(val, true);
	} else {
		newVal = this.moveDecimal(val, true, places);
	}
	return newVal;
}

//Fonction qui dcale le caractre dcimal (.) d'un nombre de places vers la gauche ou vers la droite dans un nombre val
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la fonction globale
* moveDecimalAsString; elle permet de dcaler le caractre dcimal (.) d'un nombre de places vers la gauche ou vers la droite dans un nombre val.
* @private
* @see #getZeros
* @param {String_Facultatif} val Nombre sur lequel on travaille
* @param {boolean_Facultatif} left indique dans quel sens on dcale la virgule (true : vers la gauche, false vers la droite)
* @param {String_Optionnel} places nombre de chiffres  dcaler
* @return {String} : nouveau nombre sous forme String
* @version 2.4
* @date 14/11/2006
*/
function moveDecimalAsStringNF(val, left, places)
{
	var spaces = (arguments.length < 3) ? this.places : places;
	if (spaces <= 0) return val; 
	var newVal = val + '';
	var extraZ = this.getZeros(spaces);
	var re1 = new RegExp('([0-9.]+)');
	if (left) {
		newVal = newVal.replace(re1, extraZ + '$1');
		var re2 = new RegExp('(-?)([0-9]*)([0-9]{' + spaces + '})(\\.?)');		
		newVal = newVal.replace(re2, '$1$2.$3');
	} else {
		var reArray = re1.exec(newVal); 
		if (reArray != null) {
			newVal = newVal.substring(0,reArray.index) + reArray[1] + extraZ + newVal.substring(reArray.index + reArray[0].length); 
		}
		var re2 = new RegExp('(-?)([0-9]*)(\\.?)([0-9]{' + spaces + '})');
		newVal = newVal.replace(re2, '$1$2$4.');
	}
	newVal = newVal.replace(/\.$/, ''); 
	return newVal;
}

//Fonction qui dcale le caractre dcimal (.) d'un nombre de places vers la gauche ou vers la droite dans un nombre val
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la fonction globale
* moveDecimal; elle permet de dcaler le caractre dcimal (.) d'un nombre de places vers la gauche ou vers la droite dans un nombre val.
* @private
* @see #moveDecimalAsString
* @param {String_Facultatif} val Nombre sur lequel on travaille
* @param {boolean_Facultatif} left indique dans quel sens on dcale la virgule (true : vers la gauche, false vers la droite)
* @param {String_Optionnel} places nombre de chiffres  dcaler
* @return {number}
* @version 2.4
* @date 14/11/2006
*/
function moveDecimalNF(val, left, places)
{
	var newVal = '';
	if (places == null) {
		newVal = this.moveDecimalAsString(val, left);
	} else {
		newVal = this.moveDecimalAsString(val, left, places);
	}
	return parseFloat(newVal);
}

//Fonction pour arrondir un nombre
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la fonction globale
* getRounded; elle permet d'arrondir le nombre val  n(=attribut places de l'objet NumberFormat) chiffres aprs la virgule.<br>
* La valeur sera arrondie par dfaut si l'attribut truncate est "true", sinon, elle sera arrondie au plus proche.
* @public
* @see #moveDecimalRight
* @see #moveDecimalLeft
* @param {float_Facultatif} val valeur  arrondir  "places" chiffres aprs la virgule
* @return {number}
* @version 2.4
* @date 14/11/2006
*/
function getRoundedNF(val)
{
	val = this.moveDecimalRight(val);
	if (this.truncate) {
		val = val >= 0 ? Math.floor(val) : Math.ceil(val); 
	} else {
		val = Math.round(val);
	}
	val = this.moveDecimalLeft(val);
	return val;
}

//Fonction pour complter un nombre dcimal par autant de zros que ncessaire pour tre au centime, millime ... prs.
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la fonction globale
* preserveZeros; elle permet de complter un nombre dcimal par autant de zros que ncessaire pour tre au centime, millime ... prs.<br>
* la prcision souhaite correspond  l'attribut places de l'objet NumberFormat qui reprsente le nombre de chiffres aprs la virgule. 
* @private
* @see #expandExponential
* @param {String_Obligatoire} val nombre sur lequel on travaille
* @return {String}
* @version 2.4
* @date 14/11/2006
*/
function preserveZerosNF(val)
{
	var i;
	val = this.expandExponential(val);
	if (this.places <= 0) return val; 
	var decimalPos = val.indexOf('.');
	if (decimalPos == -1) {
		val += '.';
		for (i=0; i<this.places; i++) {
			val += '0';
		}
	} else {
		var actualDecimals = (val.length - 1) - decimalPos;
		var difference = this.places - actualDecimals;
		for (i=0; i<difference; i++) {
			val += '0';
		}
	}
	return val;
}

//Fonction de formatage d'un nombre :
//remplace un pourcentage nn% par 0.nn, enlve les espaces ou parenthses ou caractres spciaux
//enlve les "traits" pour ajouter un signe "-" devant les nombres ngatifs
/**
* Le framework ergonomique <a href='overview-summary-ergonomique_fw_format.js.html'>fw_format.js</a>  propose la fonction globale
* justNumber; elle permet de formater un nombre :<br>
* remplace un pourcentage nn% par 0.nn, enlve les espaces ou parenthses ou caractres spciaux
* enlve les "traits" pour ajouter un signe "-" devant les nombres ngatifs.
* @private
* @param {String_Obligatoire} val String : Nombre  reformater
* @return {String} : nombre sous sa nouvelle forme
* @version 2.4
* @date 14/11/2006
*/
function justNumberNF(val)
{
	newVal = val + '';
	var isPercentage = false;
	if (newVal.indexOf('%') != -1) {
		newVal = newVal.replace(/\%/g, '');
		isPercentage = true; 
	}
	var re = new RegExp('[^\\' + this.inputDecimalValue + '\\d\\-\\+\\(\\)eE]', 'g');	
	newVal = newVal.replace(re, '');
	var tempRe = new RegExp('[' + this.inputDecimalValue + ']', 'g');
	var treArray = tempRe.exec(newVal); 
	if (treArray != null) {
		var tempRight = newVal.substring(treArray.index + treArray[0].length); 
		newVal = newVal.substring(0,treArray.index) + this.PERIOD + tempRight.replace(tempRe, ''); 
	}
	if (newVal.charAt(newVal.length - 1) == this.DASH ) {
		newVal = newVal.substring(0, newVal.length - 1);
		newVal = '-' + newVal;
	}
	else if (newVal.charAt(0) == this.LEFT_PAREN
	&& newVal.charAt(newVal.length - 1) == this.RIGHT_PAREN) {
		newVal = newVal.substring(1, newVal.length - 1);
		newVal = '-' + newVal;
	}
	newVal = parseFloat(newVal);
	if (!isFinite(newVal)) {
		newVal = 0;
	}
	if (isPercentage) {
		newVal = this.moveDecimalLeft(newVal, 2);
	}
	return newVal;
}

//Fonction technique pour modifier le format de restitution d'une date
/**
* Le framework technique <a href='overview-summary-technique_fw_format.js.html'>fw_format.js</a>  propose la fonction technique globale de <b>mise en forme</b> 
* dateFormat( maDate, formatCible, formatSource); elle permet de vrifier si maDate est une date et de retourner cette mme date dans un autre formet.
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#dateFormat_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @param {String_Obligatoire} maDate Chane de caractres contenant la date.
* @param {String_Obligatoire} formatCible Chane de caractres contenant le format cible.
* @param {String_Optionnel} formatSource Chane de caractres contenant le format d'origine.
* @return  la date convertie si la date transmise est valide, null sinon.
* @version 2.3
* @date 28/09/2006
*/
function dateFormat( maDate, formatCible, formatSource)
{
	var tabMois = new Array("janv", "fvr", "mars", "avr", "mai", "juin", "juil", "aot", "sept", "oct", "nov", "dc");
	var maDateFormate;
	
	// format source par dfaut
	if (formatSource == null) formatSource="DDMMYYYY";
	
	// bascule format source
	formatSource=formatSource.replace(/J/,"DD");
	formatSource=formatSource.replace(/A/,"YYYY");

	// controle date valide par rapport au format source
	var regsource="^"+formatSource+"$";
	var regJour=regsource;
	var regMois=regsource;
	var regStMois=regsource;
	var regAnnee=regsource;
	regsource=regsource.replace(/DD/,"[0-9]{2}");
	regJour=regJour.replace(/DD/,"([0-9]{2})");
	regMois=regMois.replace(/DD/,"[0-9]{2}");
	regStMois=regStMois.replace(/DD/,"[0-9]{2}");
	regAnnee=regsource.replace(/DD/,"[0-9]{2}");

	regsource=regsource.replace(/MM/,"[0-9]{2}");
	regJour=regJour.replace(/MM/,"[0-9]{2}");
	regMois=regMois.replace(/MM/,"([0-9]{2})");
	regStMois=regStMois.replace(/MM/,"[0-9]{2}");
	regAnnee=regAnnee.replace(/MM/,"[0-9]{2}");

	regsource=regsource.replace(/mmm/,"[a-zA-Z]{3,4}");
	regJour=regJour.replace(/mmm/,"[a-zA-Z]{3,4}");
	regMois=regMois.replace(/mmm/,"[a-zA-Z]{3,4}");
	regStMois=regStMois.replace(/mmm/,"([a-zA-Z]{3,4})");
	regAnnee=regAnnee.replace(/mmm/,"[a-zA-Z]{3,4}");

	regsource=regsource.replace(/YYYY/,"[0-9]{4}");
	regJour=regJour.replace(/YYYY/,"[0-9]{4}");
	regMois=regMois.replace(/YYYY/,"[0-9]{4}");
	regStMois=regStMois.replace(/YYYY/,"[0-9]{4}");
	regAnnee=regAnnee.replace(/YYYY/,"([0-9]{4})");

	regsource=regsource.replace(/YY/,"[0-9]{2}");
	regJour=regJour.replace(/YY/,"[0-9]{2}");
	regMois=regMois.replace(/YY/,"[0-9]{2}");
	regStMois=regStMois.replace(/YY/,"[0-9]{2}");
	regAnnee=regAnnee.replace(/YY/,"([0-9]{2})");

	rg = new RegExp(regsource,"g");
  test = rg.test(maDate);
		
	// si date non valide par rapport au format alors on interrompt la convertion 
	if (test == false)
		return null;
		

	// si date valide extraction du jour, du mois et de l'anne		
	rg = new RegExp(regJour,"g");
	rg.exec(maDate);
	var jour=RegExp.$1;

	rg = new RegExp(regMois,"g");
	rg.exec(maDate);
	var mois=RegExp.$1;

	rg = new RegExp(regStMois,"g");
	rg.exec(maDate);
	var stMois=RegExp.$1;
	if ((stMois != null) && (stMois != "")) {
		for (mois=0 ; mois<12 ; mois++)
			if (tabMois[mois] == stMois) break;
		mois++;
		if (mois < 10) mois="0"+mois;
	}

	rg = new RegExp(regAnnee,"g");
	rg.exec(maDate);
	var annee=RegExp.$1;
	if (annee<1000) annee+=2000;
	
	// controle date valide
	var d = new Date(annee, mois-1, jour);
  if ( isNaN(d) || (d.getDate()!=jour) || ((d.getMonth()+1)!= mois)) 
  	return null;
	
	// bascule format cible
	formatCible=formatCible.replace(/J/,"DD");
	formatCible=formatCible.replace(/A/,"YYYY");
	
	var maDateFormate=formatCible;
	maDateFormate=maDateFormate.replace(/DD/,jour);	
	maDateFormate=maDateFormate.replace(/MM/,mois);	
	maDateFormate=maDateFormate.replace(/mmm/,tabMois[mois-1]);	
	maDateFormate=maDateFormate.replace(/YYYY/,annee);	
	maDateFormate=maDateFormate.replace(/YY/,annee.substring(2,4));	

	return maDateFormate;
}
//Fonction technique pour modifier le format de restitution d'une date
/**
* Le framework technique <a href='overview-summary-technique_fw_format.js.html'>fw_format.js</a>  propose la fonction technique globale de <b>mise en forme</b> 
* dateFormat( maDate, formatCible, formatSource); elle permet de vrifier si maDate est une date et de retourner cette mme date dans un autre format.
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#dateFormat_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @param {String_Obligatoire} maDate Chane de caractres contenant la date.
* @param {String_Obligatoire} formatCible Chane de caractres contenant le format cible.
* @param {String_Facultatif} formatSource Chane de caractres contenant le format d'origine.
* @return {String} : date convertie si la date transmise est valide, null sinon.
* @version 2.3
* @date 28/09/2006
*/
function dateFormatNF( maDate, formatCible, formatSource)
{
	var tabMois = new Array("janv", "fvr", "mars", "avr", "mai", "juin", "juil", "aot", "sept", "oct", "nov", "dc");
	var maDateFormate;
	
	// format source par dfaut
	if (formatSource == null) formatSource="DDMMYYYY";
	
	// bascule format source
	formatSource=formatSource.replace(/J/,"DD");
	formatSource=formatSource.replace(/A/,"YYYY");

	// controle date valide par rapport au format source
	var regsource="^"+formatSource+"$";
	var regJour=regsource;
	var regMois=regsource;
	var regStMois=regsource;
	var regAnnee=regsource;
	regsource=regsource.replace(/DD/,"[0-9]{2}");
	regJour=regJour.replace(/DD/,"([0-9]{2})");
	regMois=regMois.replace(/DD/,"[0-9]{2}");
	regStMois=regStMois.replace(/DD/,"[0-9]{2}");
	regAnnee=regsource.replace(/DD/,"[0-9]{2}");

	regsource=regsource.replace(/MM/,"[0-9]{2}");
	regJour=regJour.replace(/MM/,"[0-9]{2}");
	regMois=regMois.replace(/MM/,"([0-9]{2})");
	regStMois=regStMois.replace(/MM/,"[0-9]{2}");
	regAnnee=regAnnee.replace(/MM/,"[0-9]{2}");

	regsource=regsource.replace(/mmm/,"[a-zA-Z]{3,4}");
	regJour=regJour.replace(/mmm/,"[a-zA-Z]{3,4}");
	regMois=regMois.replace(/mmm/,"[a-zA-Z]{3,4}");
	regStMois=regStMois.replace(/mmm/,"([a-zA-Z]{3,4})");
	regAnnee=regAnnee.replace(/mmm/,"[a-zA-Z]{3,4}");

	regsource=regsource.replace(/YYYY/,"[0-9]{4}");
	regJour=regJour.replace(/YYYY/,"[0-9]{4}");
	regMois=regMois.replace(/YYYY/,"[0-9]{4}");
	regStMois=regStMois.replace(/YYYY/,"[0-9]{4}");
	regAnnee=regAnnee.replace(/YYYY/,"([0-9]{4})");

	regsource=regsource.replace(/YY/,"[0-9]{2}");
	regJour=regJour.replace(/YY/,"[0-9]{2}");
	regMois=regMois.replace(/YY/,"[0-9]{2}");
	regStMois=regStMois.replace(/YY/,"[0-9]{2}");
	regAnnee=regAnnee.replace(/YY/,"([0-9]{2})");

	rg = new RegExp(regsource,"g");
  test = rg.test(maDate);
		
	// si date non valide par rapport au format alors on interrompt la convertion 
	if (test == false)
		return null;
		

	// si date valide extraction du jour, du mois et de l'anne		
	rg = new RegExp(regJour,"g");
	rg.exec(maDate);
	var jour=RegExp.$1;

	rg = new RegExp(regMois,"g");
	rg.exec(maDate);
	var mois=RegExp.$1;

	rg = new RegExp(regStMois,"g");
	rg.exec(maDate);
	var stMois=RegExp.$1;
	if ((stMois != null) && (stMois != "")) {
		for (mois=0 ; mois<12 ; mois++)
			if (tabMois[mois] == stMois) break;
		mois++;
		if (mois < 10) mois="0"+mois;
	}

	rg = new RegExp(regAnnee,"g");
	rg.exec(maDate);
	var annee=RegExp.$1;
	if (annee<1000) annee+=2000;
	
	// controle date valide
	var d = new Date(annee, mois-1, jour);
  if ( isNaN(d) || (d.getDate()!=jour) || ((d.getMonth()+1)!= mois)) 
  	return null;
	
	// bascule format cible
	formatCible=formatCible.replace(/J/,"DD");
	formatCible=formatCible.replace(/A/,"YYYY");
	
	var maDateFormate=formatCible;
	maDateFormate=maDateFormate.replace(/DD/,jour);	
	maDateFormate=maDateFormate.replace(/MM/,mois);	
	maDateFormate=maDateFormate.replace(/mmm/,tabMois[mois-1]);	
	maDateFormate=maDateFormate.replace(/YYYY/,annee);	
	maDateFormate=maDateFormate.replace(/YY/,annee.substring(2,4));	

	return maDateFormate;
}
//Fonction technique pour modifier le format de restitution d'un nombre en tant que monnaie
/**
* Le framework technique <a href='overview-summary-technique_fw_format.js.html'>fw_format.js</a>  propose la fonction technique globale de <b>mise en forme</b> 
* monnaieFormat( monChiffre, devise); elle permet de retourner monChiffre dans un autre format montaire.
* @public
* @param {String_Obligatoire} monChiffre Chane de caractres contenant le nombre.
* @param {String_Obligatoire} devise Chane de caractres contenant le symbole de la devise.
* @return {String} : nombre converti en format montaire.
* @version 2.3
* @date 28/09/2006
*/
function monnaieFormatNF( monChiffre, devise)
{
	var num = new NumberFormat();
	num.setInputDecimal('.');
	num.setPlaces('2', false);
	num.setCurrencyValue((devise==null)?"":" "+devise);
	num.setCurrency(true);
	num.setCurrencyPosition(num.RIGHT_OUTSIDE);
	num.setNegativeFormat(num.LEFT_DASH);
	num.setNegativeRed(false);
	num.setSeparators(true, ' ', ' ');
	num.setNumber(monChiffre); 
	return num.toFormatted().replace(".", ",");
}
//Fonction technique pour modifier le format de restitution d'un nombre en tant que monnaie
/**
* Le framework technique <a href='overview-summary-technique_fw_format.js.html'>fw_format.js</a>  propose la fonction technique globale de <b>mise en forme</b> 
* monnaieFormat( monChiffre, devise); elle permet de retourne monChiffre dans un autre format montaire.
* @param {String_Obligatoire} monChiffre Chane de caractres contenant le nombre.
* @param {String_Obligatoire} devise Chane de caractres contenant le symbole de la devise.
* @return {String} le nombre converti en format montaire.
* @version 2.3
* @date 28/09/2006
*/
function monnaieFormat( monChiffre, devise)
{
	var num = new NumberFormat();
	num.setInputDecimal('.');
	num.setPlaces('2', false);
	num.setCurrencyValue((devise==null)?"":" "+devise);
	num.setCurrency(true);
	num.setCurrencyPosition(num.RIGHT_OUTSIDE);
	num.setNegativeFormat(num.LEFT_DASH);
	num.setNegativeRed(false);
	num.setSeparators(true, ' ', ' ');
	num.setNumber(monChiffre); 
	return num.toFormatted().replace(".", ",");
}
//Fonction technique pour modifier le format d'un nombre par un autre format entier
/**
* Le framework technique <a href='overview-summary-technique_fw_format.js.html'>fw_format.js</a>  propose la fonction technique globale de <b>mise en forme</b> 
* entierFormat( monChiffre); elle permet de retourner monChiffre dans un autre format entier.
* @public
* @param {String_Obligatoire} monChiffre Chane de caractres contenant le nombre.
* @return {String} : nombre converti en format entier.
* @version 2.3
* @date 28/09/2006
*/
function entierFormatNF( monChiffre)
{
	var num = new NumberFormat();
	num.setPlaces('0', false);
	num.setCurrencyValue('');
	num.setCurrency(true);
	num.setCurrencyPosition(num.RIGHT_OUTSIDE);
	num.setNegativeFormat(num.LEFT_DASH);
	num.setNegativeRed(false);
	num.setSeparators(true, ' ', ' ');
	num.setNumber(monChiffre); 
	return num.toFormatted();
}
//Fonction technique pour modifier le format de restitution d'un nombre en tant que monnaie
/**
* Le framework technique <a href='overview-summary-technique_fw_format.js.html'>fw_format.js</a>  propose la fonction technique globale de <b>mise en forme</b> 
* entierFormat( monChiffre); elle permet de retourne monChiffre dans un autre format entier.
* @param {String_Obligatoire} monChiffre Chane de caractres contenant le nombre.
* @return  le nombre converti en format entier.
* @version 2.3
* @date 28/09/2006
*/
function entierFormat( monChiffre)
{
	var num = new NumberFormat();
	num.setPlaces('0', false);
	num.setCurrencyValue('');
	num.setCurrency(true);
	num.setCurrencyPosition(num.RIGHT_OUTSIDE);
	num.setNegativeFormat(num.LEFT_DASH);
	num.setNegativeRed(false);
	num.setSeparators(true, ' ', ' ');
	num.setNumber(monChiffre); 
	return num.toFormatted();
}

// Fonction technique pour modifier le format de restitution d'un nombre

/**
* Le framework technique <a href='overview-summary-technique_fw_format.js.html'>fw_format.js</a>  propose la fonction technique globale de <b>mise en forme</b> 
* numberFormat( monChiffre, formatCible); elle permet de vrifier si monChiffre est un nombre et de retourner ce mme nombre dans un autre formet.
* <br><br><b>Voir Exemple  : </b> <a href='exemples_A3.html#numberFormat_fctGlob'>Exemples d'appel aux fonctions globales</a>.
* @public
* @param {String_Obligatoire} monChiffre Chane de caractres contenant le nombre.
* @param {String_Obligatoire} formatCible Chane de caractres contenant le format cible.
* @return {String} : nombre converti si le nombre transmis est valide, null sinon.
* @version 2.3
* @date 28/09/2006
*/
function numberFormat( monChiffre, formatCible)
{
	// controle nombre valide
  if (isNaN(monChiffre)) {
		monChiffre = parseFloat(monChiffre.replace(",", "."));
		if( isNaN(monChiffre)) return null;
	}
		
	switch (formatCible) {
		case "ENTIER" :
			return entierFormat(monChiffre);
			break;
		case "MONNAIE" :
			return monnaieFormat(monChiffre);
			break;
		case "EURO" :
			return monnaieFormat(monChiffre,"&#8364;");
			break;
		default :
			return null;
	}
}


// Objet NombreFormate

/**
* Cre une nouvelle instance NombreFormate.<br> 
* @class La classe <b>NombreFormate</b> est la classe permettant de manipuler un nombre dans le but
* de lui donner diffrentes formes possibles via une chaine de formatage.
* Cette chaine de formatage doit tre constitue comme suit :<br>
* [prefixe+|prefixe-][motif_partie_entiere+|motif_partie_entiere-]
* [motif_partie_decimale+|motif_partie_decimale-][postfixe+|postfixe-]
* [options]<br>
* <ul><li>prefixe+/- : prfixe  afficher avant le nombre positif ou ngatif. Dans le cas o un seul
* prefixe est prcis ([prefixe]), il sera utilis indifferement pour un nombre ngatif ou positif.</li>
* <li>motif_partie_entiere+/- : motif priodique  respecter pour l'affichage de la partie entire
* du nombre. Le caractre 0 reprsente un chiffre. Ex.: 0 000 pour un motif avec un espace comme 
* sparateur de milliers. Dans le cas o un seul motif est prcis ([motif]), il sera utilis
* indifferement pour un nombre ngatif ou positif.</li>
* <li>motif_partie_decimale+/- : motif priodique  respecter pour l'affichage de la partie dcimale
* du nombre. Le caractre 0 reprsente un chiffre. Ex.: 0 000 pour un motif avec un espace comme 
* sparateur de milliers. Dans le cas o un seul motif est prcis ([motif]), il sera utilis
* indifferement pour un nombre ngatif ou positif.</li>
* <li>postfixe+/- : postfixe  afficher aprs le nombre positif ou ngatif. Dans le cas o un seul
* postfixe est prcis ([postfixe]), il sera utilis indifferement pour un nombre ngatif ou positif.</li>
* <li>options : liste des options  utiliser lors du formatage [{arrondi}{+/-}|{nb_decimales}|
* {separateur}|{symbol}|{position_symbol:0|1|2|3|4}|{facteur_multiplicateur}|{format_affichage : N|S}]
*	<ul> <li>arrondi : Nombre prcisant  quelle valeur doit tre effectu l'arrondi,
* suivi de (+) pour l'arrondi  la valeur suprieur ou (-) pour l'arrondi  la valeur infrieur.
* Ces paramtres sont optionnels. Valeur par dfault : 0.5+</li>
* <li>nb_decimales : Nombre de chiffre  laisser apparatre aprs le sparateur de la partie dcimale.
* La valeur 0 indique qu'aucune partie dcimale n'est affiche.
* Ce paramtre est optionnel. Valeur par dfault : 0</li>
* <li>sparateur : Caractre  afficher entre la partie entire et la partie dcimale du nombre.
* Ce paramtre est optionnel. Valeur par dfault : ,</li>
* <li>symbole : Caractre  afficher dans le formatage et dont la position est renseign au paramtre
* suivant. Ce paramtre est optionnel. Valeur par dfault : ""</li>
* <li>position symbol : Dfini l'emplacement du symbole 0-Avant le prefixe, 1-entre le prefixe
* et la partie entire du nombre 2- entre la partie entire et la partie dcimale (avant le sparateur)
* 3- entre la partie dcimale et le postfixe 4- aprs le postfixe. Valeur par dfault : 4</li>
* <li>facteur_multiplicateur : Coefficient  appliquer ventuellement. Valeur par dfault : 1</li>
* <li>format_affichage : S pour l'affichage scientifique (puissance de 10 : E+/-n) ou N pour
* l'affichage normal. Valeur par dfault : N</li>
* </ul>
* </ul>
* @constructor
* @param {String_Facultatif} unNombre : Nombre principal manipul dans la classe
* @param {String_Obligatoire} uneExpressionFormatage : Chaine de formatage prcisant le format de conversion souhait
* @version 2.4
* @date 14/11/2006
*/
function NombreFormate(unNombre, uneExpressionFormatage) {

	// Constantes
	
	/**
	* Constante dsignant le sparateur utilis entre les options de la chaine de formatage.
	* @private
	* @type {string}
	* @final
	* @version 2.4
	* @date 14/11/2006
	*/
	this.SEPARATEUR = "|";
	
	/**
	* Constante dsignant l'expression rgulire utilise pour vrifier le format de la
	* chaine de formatage.
	* @private
	* @type {string}
	* @final
	* @version 2.4
	* @date 14/11/2006
	*/
	this.EXPREG = /^\[[^||]*[||]?[^||]*\]\[[^||]*[||]?[^||]*\]\[[^||]*[||]?[^||]*\]\[[^||]*[||]?[^||]*\]\[([0-9].[0-9])?[\+|-]?[||][0-9]?[||][^||]*[||][^||]*[||][0-4]?[||][^||]*[||][N|S]?\]$/;

	/**
	* Constante dsignant la chaine de formatage par dfaut.
	* @private
	* @type {string}
	* @final
	* @version 2.5
* @date 14/02/2007
	*/
	this.FORMATDEF = "[+ |-(] [0 000] [00] [ |) ] [|2|.| | | |1|N]";

	/**
	* Constante dsignant la valeur par dfaut du paramtre type d'arrondi.
	* @private
	* @type {string}
	* @final
	* @version 2.4
	* @date 14/11/2006
	*/
	this.TYPEARRONDIDEF = "";

	/**
	* Constante dsignant la valeur par dfaut du paramtre seuil d'arrondi.
	* @private
	* @type {string}
	* @final
	* @version 2.4
	* @date 14/11/2006
	*/
	this.SEUILARRONDIDEF = 0.5;	

	/**
	* Constante dsignant la valeur par dfaut du paramtre nombre de dcimale.
	* @private
	* @type {string}
	* @final
	* @version 2.4
	* @date 14/11/2006
	*/
	this.NBDECIMALDEF = 0;
	
	/**
	* Constante dsignant la valeur par dfaut du paramtre sparateur.
	* @private
	* @type {string}
	* @final
	* @version 2.4
	* @date 14/11/2006
	*/	
	this.SEPARATEURDECIMALDEF = ",";

	/**
	* Constante dsignant la valeur par dfaut du paramtre symbol.
	* @private
	* @type {string}
	* @final
	* @version 2.4
	* @date 14/11/2006
	*/
	this.SYMBOLDEF = "";

	/**
	* Constante dsignant la valeur par dfaut du paramtre position du symbole.
	* @private
	* @type {string}
	* @final
	* @version 2.4
	* @date 14/11/2006
	*/
	this.POSSYMBOLDEF = "4";

	/**
	* Constante dsignant la valeur par dfaut du paramtre facteur de multiplicateur.
	* @private
	* @type {string}
	* @final
	* @version 2.4
	* @date 14/11/2006
	*/
	this.FACTEURCONVERSIONDEF = 1;

	/**
	* Constante dsignant la valeur par dfaut du paramtre format d'affichage.
	* @private
	* @type {string}
	* @final
	* @version 2.4
	* @date 14/11/2006
	*/
	this.FORMATAFFICHAGEDEF = "N";

	/**
	* Constante dsignant la valeur par dfaut du paramtre format de la partie dcimale ngative.
	* @private
	* @type {string}
	* @final
	* @version 2.4
	* @date 14/11/2006
	*/
	this.FPDECNEG = "";

	/**
	* Constante dsignant la valeur par dfaut du paramtre format de la partie dcimale positive.
	* @private
	* @type {string}
	* @final
	* @version 2.4
	* @date 14/11/2006
	*/
	this.FPDEC = "";

	/**
	* Constante dsignant la valeur par dfaut du paramtre format de la partie entire ngative.
	* @private
	* @type {string}
	* @final
	* @version 2.4
	* @date 14/11/2006
	*/
	this.FPENTNEG = "";

	/**
	* Constante dsignant la valeur par dfaut du paramtre format de la partie entire.
	* @private
	* @type {string}
	* @final
	* @version 2.4
	* @date 14/11/2006
	*/
	this.FPENT = "";
		
	
	// Proprits
	
	/**
	* Proprit dsignant si le nombre courant est positif ou ngatif.
	* @private
	* @type boolean
	* @version 2.4
	* @date 14/11/2006
	*/
	this.positif = true;

	/**
	* Proprit dsignant le nombre courant dans son format d'origine (format de saisie).
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.nombre = unNombre;

	/**
	* Proprit dsignant le nombre courant dans un format normalis pour l'exploitation algorithmique.
	* @private
	* @type float
	* @version 2.4
	* @date 14/11/2006
	*/
	this.nombreNormalise = "";

	/**
	* Proprit dsignant le nombre courant dans son tat format, c'est--dire l'tat du nombre aprs
	* lui avoir appliqu la chaine de formatage.
	* @public
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.nombreFormate = "";

	/**
	* Proprit dsignant l'expression de formatage  utiliser lors du formatage du nombre.
	* @public
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/	
	this.expressionFormatage = ((uneExpressionFormatage=="")?this.FORMATDEF:uneExpressionFormatage);

	/**
	* Proprit dsignant la partie entire du nombre dans son format normalis.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.partieEntiere = "";

	/**
	* Proprit dsignant la partie entire du nombre dans sa version format.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.partieEntiereFormate = "";	

	/**
	* Proprit dsignant la partie dcimale du nombre dans son format normalis.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.partieDecimale = "";
	
	/**
	* Proprit dsignant la partie entire du nombre dans sa version format.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.partieDecimaleFormate = "";

	/**
	* Proprit dsignant le prfixe  utiliser lors du formatage, dans le cas d'un nombre
	* positif et/ou dans le cas d'un nombre ngatif si aucun format n'est dfini pour ce cas.
	* @public
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.prefixe = "";

	/**
	* Proprit dsignant le prfixe  utiliser lors du formatage, dans le cas d'un nombre
	* ngatif.
	* @public
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.prefixeNegatif = "";

	/**
	* Proprit dsignant le postfixe  utiliser lors du formatage, dans le cas d'un nombre
	* positif et/ou dans le cas d'un nombre ngatif si aucun format n'est dfini pour ce cas.
	* @public
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.postfixe = "";

	/**
	* Proprit dsignant le postfixe  utiliser lors du formatage, dans le cas d'un nombre
	* ngatif.
	* @public
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.postfixeNegatif = "";	

	/**
	* Proprit dsignant le motif  utiliser pour la partie entire, dans le cas d'un nombre
	* positif et/ou dans le cas d'un nombre ngatif si aucun format n'est dfini pour ce cas.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.formatPartieEntiere = this.FPENT;

	/**
	* Proprit dsignant le motif  utiliser pour la partie entire, dans le cas d'un nombre
	* ngatif.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.formatPartieEntiereNegatif = this.FPENTNEG;

	/**
	* Proprit dsignant le motif  utiliser pour la partie dcimale, dans le cas d'un nombre
	* positif et/ou dans le cas d'un nombre ngatif si aucun format n'est dfini pour ce cas.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.formatPartieDecimale = this.FPDEC;
	
	/**
	* Proprit dsignant le motif  utiliser pour la partie dcimale, dans le cas d'un nombre
	* ngatif.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.formatPartieDecimaleNegatif = this.FPDECNEG;
	
	/**
	* Proprit dsignant la valeur du paramtre seuil de l'arrondi.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/	
	this.seuilArrondi = this.SEUILARRONDIDEF;

	/**
	* Proprit dsignant la valeur du paramtre type de l'arrondi.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.typeArrondi = this.TYPEARRONDIDEF;

	/**
	* Proprit dsignant la valeur du paramtre nombre de dcimales.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.nbDecimale = this.NBDECIMALDEF;

	/**
	* Proprit dsignant la valeur du paramtre sparateur.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.separateur = this.SEPARATEURDECIMALDEF;

	/**
	* Proprit dsignant la valeur du paramtre symbole.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.symbol = this.SYMBOLDEF;
	
	/**
	* Proprit dsignant la valeur du paramtre position du symbol.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.posSymbol = this.POSSYMBOLDEF;

	/**
	* Proprit dsignant la valeur du paramtre coefficient multiplicateur.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.facteurConversion = this.FACTEURCONVERSIONDEF;

	/**
	* Proprit dsignant la valeur du paramtre format de l'affichage.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.formatAffichage = this.FORMATAFFICHAGEDEF;

	/**
	* Proprit dsignant la valeur de la puissance de dix dans le cas d'un affichage scientifique.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/
	this.puissancesE = "";
		
	// Mthodes
	
	/**
	* La mthode estExpressionCorrecte() renvoie true si la chaine l'expression de formatage
	* passe en paramtre du constructeur est valide, false sinon.
	* @public
	* @param {} Aucun.
	* @return {boolean}
	* @version 2.4
	* @date 14/11/2006
	*/
	this.estExpressionCorrecte = function() {
		return this.EXPREG.test(this.expressionFormatage);
	}

	/**
	* La mthode estNombrePositif() renvoie true si le nombre exploit par la classe est positif,
	* false sinon.
	* @private
	* @param {} Aucun.
	* @return {boolean}
	* @version 2.4
	* @date 14/11/2006
	*/
	this.estNombrePositif = function() {
		return (this.positif);
	}
	
	/**
	* La mthode donneNombreFormate() retourne une chaine de caractre contenant le nombre convertit
	* au format spcifi par l'expression de formatage. Retourne null en cas d'erreur.
	* @public
	* @param {} Aucun.
	* @return {string}
	* @version 2.4
	* @date 14/11/2006
	*/
	this.donneNombreFormate = function () {
		// Verification et normalisation du nombre en entre 
		if (this.nombre==""&&this.nombre!=0)
			return null;
			
		if (isNaN(this.nombre)) {
			this.nombre = this.nombre.replace(",", ".");
			if(isNaN(this.nombre))
				return null;
		}
		this.nombreNormalise = this.nombre;
		
		// Dtermination du signe (+/-)
		if (this.nombreNormalise<0) {
			this.positif = false;
			// On supprime le signe
			this.nombreNormalise = this.nombreNormalise * (-1);
		}
		
		// Initialisation des attributs intervenant dans le parametrage du formatage
		this.initPrefixe();
		this.initPostfixe();
		this.initPartieEntiere();
		this.initPartieDecimale();
		this.initOptions();
				
		// Application de l'option facteur mutiplicatif
		this.factoriserNombre();

		// Application de l'option format d'affichage (normal ou scientifique)
		this.formaterAffichage();
		
		// Application de l'option arrondi + nombre de dcimales
		this.arrondirNombre();

		// Initialisation des parties entires et dcimales
		this.initNombre();			
		
		// Formatage des parties entires et dcimales
		this.formaterPartieEntiere();
		if (this.partieDecimale != "")
			this.formaterPartieDecimale();
	
		// Gnration finale du nombre format
		var valeur = "";
		var estPositif = this.estNombrePositif();
		valeur += ((this.symbol != "" && this.posSymbol == "0")?this.symbol:"");
		valeur += ((estPositif)?this.prefixe:this.prefixeNegatif);
		valeur += ((this.symbol != "" && this.posSymbol == "1")?this.symbol:"");
		valeur += this.partieEntiereFormate;
		valeur += ((this.symbol != "" && this.posSymbol == "2")?this.symbol:"");
		valeur += ((this.partieDecimale!="")?this.separateur:"");
		valeur += ((this.partieDecimale!="")?this.partieDecimaleFormate:"");
		valeur += ((this.formatAffichage=="S")?"E"+this.puissancesE:"");
		valeur += ((this.symbol != "" && this.posSymbol == "3")?this.symbol:"");
		valeur += ((estPositif)?this.postfixe:this.postfixeNegatif);
		valeur += ((this.symbol != "" && this.posSymbol == "4")?this.symbol:"");		
		this.nombreFormate = valeur;
		
		return valeur; 
	}

	/**
	* La mthode donneOrigineNombreFormate() retourne une chaine de caractre contenant le nombre
	* normalis qui tait  l'origine du formatage obtenu dans resultatFormate.
	* Retourne une chaine vide "" en cas d'erreur dans le paramtre.
	* @public
	* @param {} Aucun.
	* @return {string}
	* @version 2.4
	* @date 14/11/2006
	*/
	this.donneOrigineNombreFormate = function (resultatFormate) {
		// Prise en compte du nombre format
		this.nombreFormate = resultatFormate;
		
		// Initialisation des attributs intervenant dans le parametrage du formatage
		this.initPrefixe();
		this.initPostfixe();
		this.initPartieEntiere();
		this.initPartieDecimale();
		this.initOptions();
		
		// Dtermination du signe
		if ((this.prefixeNegatif != "" && this.nombreFormate.indexOf(this.prefixeNegatif) != -1)
				|| (this.nombreFormate.indexOf(this.postfixeNegatif) != -1 && this.postfixeNegatif != ""))
			this.positif = false;
			
		// Dtermination de l'existance de la partie dcimale
		var estDecimal = false;
		if (this.nombreFormate.indexOf(this.separateur)!=-1)
			estDecimal = true;
		
		// Extraire les parties entires et decimales
		this.extrairePartieEntiere();
		if (this.partieEntiere == "")
			return "";
		if (estDecimal)
			this.extrairePartieDecimale();
		
		// ***
		// Gnration de la valeur normalis
	
		// Analyse du signe
		this.nombreNormalise = ((this.positif)?"":"-") + this.partieEntiere + "." + this.partieDecimale;
		this.nombreNormalise = parseFloat(this.nombreNormalise);
		
		// Analyse du format d'affichage
		if (this.puissancesE!="")
			if (this.puissancesE.charAt(0) == "+")
				this.nombreNormalise = this.nombreNormalise * Math.pow(10,parseInt(this.puissancesE.substring(1,this.puissancesE.length)));
			else
				this.nombreNormalise = this.nombreNormalise / Math.pow(10,parseInt(this.puissancesE.substring(1,this.puissancesE.length)));			
			
		// Analyse de la factorisation
		this.nombreNormalise = this.nombreNormalise / this.facteurConversion;
		
		// Arrondi
		if (this.typeArrondi == "+")
			this.typeArrondi = "-";
		else
			this.typeArrondi = "+";
		this.arrondirNombre();
		
		return this.nombreNormalise;					
	}
	
	
	/**
	* La mthode extrairePartieDecimale() renseigne la proprit "partieDecimale" de l'objet
	* (contenant la partie dcimale du nombre au format normalis)  partir du nombre format.
	* @private
	* @param {} Aucun.
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/
	this.extrairePartieDecimale = function () {
		var posDebDecimal = 0;
		var posFinDecimal = 0;
		var estPositif = this.estNombrePositif();
		
		// Dtermination de l'index de dbut de la partie dcimale
		posDebDecimal = this.nombreFormate.indexOf(this.separateur)+1;
		
		// Dtermination de l'index de fin de la partie dcimale
		if (this.formatAffichage=="S") {
			// Cas d'une puissance
			posFinDecimal = ((this.nombreFormate.indexOf("E+")==-1)?this.nombreFormate.indexOf("E-"):this.nombreFormate.indexOf("E+"));
			this.extrairePuissance();
	  } else
	  	posFinDecimal = this.nombreFormate.length - ((estPositif)?this.postfixe.length:this.postfixeNegatif.length) - ((this.posSymbol == "3" || this.posSymbol == "4")?this.symbol.length:0);	  
		
		// Affectation de la partie decimale
		if (posDebDecimal>=posFinDecimal) {
			this.partieDecimale = 0;
			return;
		}
		
		var index = posDebDecimal;
		var carCourant = "";
		this.partieDecimale = "";
		while (index != posFinDecimal) {
			carCourant = this.nombreFormate.charAt(index);
			if (carCourant.search(/[0-9]/) != -1)
				this.partieDecimale = this.partieDecimale + carCourant;
			index++;
		}
	}
	
	
	/**
	* La mthode extrairePartieEntiere() renseigne la proprit "partieEntiere" de l'objet
	* (contenant la partie entire du nombre au format normalis)  partir du nombre format.
	* @private
	* @param {} Aucun.
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/
	this.extrairePartieEntiere = function () {
		var posDebEntier = 0;
		var posFinEntier = 0;
		var estPositif = this.estNombrePositif();
		
		// Dtermination de l'index de dbut de la partie entire
		if (this.symbol != "" && this.posSymbol == "0")
			posDebEntier += this.symbol.length;
		if (estPositif)
			posDebEntier += this.prefixe.length;
		else
			posDebEntier += this.prefixeNegatif.length;
		if (this.symbol != "" && this.posSymbol == "1")
			posDebEntier += this.symbol.length;
		
		// Dtermination de l'index de fin de la partie entire
		var posSeparateur = this.nombreFormate.indexOf(this.separateur);
		if (posSeparateur!=-1) {
			// Sparateur trouv
			posFinEntier = posSeparateur;
			if (this.symbol != "" && this.posSymbol == "2")
				posFinEntier -= this.symbol.length;		
		} else {
			// Sparateur non trouv
			if (this.formatAffichage=="S") {
				// affichage scientifique
				posFinEntier = ((this.nombreFormate.indexOf("E+")==-1)?this.nombreFormate.indexOf("E-"):this.nombreFormate.indexOf("E+"));
				this.extrairePuissance();
			} else
				  // Il ne reste que le postfixe, un symbole ou rien aprs l'entier
					posFinEntier = this.nombreFormate.length - ((estPositif)?this.postfixe.length:this.postfixeNegatif.length) - ((this.posSymbol == "2" || this.posSymbol == "3" || this.posSymbol == "4")?this.symbol.length:0);
		}		
		
		// Affectation de la partie entiere
		if (posDebEntier>=posFinEntier) {
			this.partieEntiere = "";
			return;
		}
		
		var index = posDebEntier;
		var carCourant = "";
		this.partieEntiere = "";
		while (index != posFinEntier) {
			carCourant = this.nombreFormate.charAt(index);
			if (carCourant.search(/[0-9]/) != -1)
				this.partieEntiere = this.partieEntiere + carCourant;
			index++;
		}
	}
	
	/**
	* La mthode extrairePuissance() renseigne la proprit "puissancesE" de l'objet
	* (contenant la valeur de la puissance de 10 lie  l'affichage scientifique)
	*  partir du nombre format.
	* @private
	* @param {} Aucun.
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/
	this.extrairePuissance = function () {
		var index;
		var carCourant = "";
		this.puissancesE = "";
		
		// Dtermination du type de puissance
		if (this.nombreFormate.indexOf("E+")==-1) {
			index = this.nombreFormate.indexOf("E-") + 2;
			this.puissancesE = "-";
		} else {
			index = this.nombreFormate.indexOf("E+") + 2;
			this.puissancesE = "+";		
		}
		
		// Recherche de la valeur de la puissance
		while (index < this.nombreFormate.length) {
			carCourant = this.nombreFormate.charAt(index);
			if (carCourant.search(/[0-9]+/) != -1)
				this.puissancesE = this.puissancesE + carCourant;
			else
				break;
			index++;
		}
	}
	
	/**
	* La mthode initPrefixe() initialise les attributs de la classe relatifs  la gestion du/des
	* prefixes.
	* @private
	* @param {} Aucun.
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/	
	this.initPrefixe = function() {
		// Rcupration des valeurs de l'expression sous forme de tableau
		var tableauExpReg = this.expressionFormatage.split("][");
		var posSeparateur;
		
		// Initialisation des attributs relatifs au(x) prfixe(s)
		if (tableauExpReg[0].length-1!=0) {
			// Il existe un format pour le prfixe
			posSeparateur=tableauExpReg[0].indexOf(this.SEPARATEUR);
			if (posSeparateur!=-1) {
				// 2 formats pour le prfixe
				this.prefixe = tableauExpReg[0].slice(1,posSeparateur);
				this.prefixeNegatif = tableauExpReg[0].slice(posSeparateur+1,tableauExpReg[0].length);		
			} else {
				// 1 format pour le prfixe
				this.prefixe = tableauExpReg[0].slice(1,tableauExpReg[0].length);
				this.prefixeNegatif = this.prefixe;
			}
		}				
	}

	/**
	* La mthode initPostfixe() initialise les attributs de la classe relatifs  la gestion du/des
	* postfixes.
	* @private
	* @param {} Aucun.
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/
	this.initPostfixe = function() {
		// Rcupration des valeurs de l'expression sous forme de tableau
		var tableauExpReg = this.expressionFormatage.split("][");
		var posSeparateur;
		// Initialisation des attributs relatifs au(x) postfixe(s)
		if (tableauExpReg[3].length!=0) {
			// Il existe un format pour le postfixe
			posSeparateur=tableauExpReg[3].indexOf(this.SEPARATEUR);
			if (posSeparateur!=-1) {
				// 2 formats pour le postfixe
				this.postfixe = tableauExpReg[3].slice(0,posSeparateur);
				this.postfixeNegatif = tableauExpReg[3].slice(posSeparateur+1,tableauExpReg[3].length);		
			} else {
				// 1 format pour le postfixe
				this.postfixe = tableauExpReg[3].slice(0,tableauExpReg[3].length);
				this.postfixeNegatif = this.postfixe;
			}
		}
	}

	/**
	* La mthode initPartieEntiere() initialise les attributs de la classe relatifs  la gestion
	* de la partie entire du nombre.
	* @private
	* @param {} Aucun.
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/	
  this.initPartieEntiere = function() {
		// Rcupration des valeurs de l'expression sous forme de tableau
		var tableauExpReg = this.expressionFormatage.split("][");
		var posSeparateur;
		
		// Initialisation des attributs relatifs au(x) partie(s) entire(s)
		if (tableauExpReg[1].length!=0) {
			// Il existe un format pour la partie entire
			posSeparateur=tableauExpReg[1].indexOf(this.SEPARATEUR);
			if (posSeparateur!=-1) {
				// 2 formats pour la partie entire
				this.formatPartieEntiere = tableauExpReg[1].slice(0,posSeparateur);
				this.formatPartieEntiereNegatif = tableauExpReg[1].slice(posSeparateur+1,tableauExpReg[1].length);		
			} else {
				// 1 format pour la partie entire
				this.formatPartieEntiere = tableauExpReg[1].slice(0,tableauExpReg[1].length);
				this.formatPartieEntiereNegatif = this.formatPartieEntiere;
			}
		}
	}

	/**
	* La mthode initPartieDecimale() initialise les attributs de la classe relatifs  la gestion
	* de la partie dcimale du nombre.
	* @private
	* @param {} Aucun.
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/
  this.initPartieDecimale = function() {
		// Rcupration des valeurs de l'expression sous forme de tableau
		var tableauExpReg = this.expressionFormatage.split("][");
		var posSeparateur;
		
		// Initialisation des attributs relatifs au(x) partie(s) dcimale(s)
		if (tableauExpReg[2].length!=0) {
			// Il existe un format pour la partie dcimale
			posSeparateur=tableauExpReg[2].indexOf(this.SEPARATEUR);
			if (posSeparateur!=-1) {
				// 2 formats pour la partie dcimale
				this.formatPartieDecimale = tableauExpReg[2].slice(0,posSeparateur);
				this.formatPartieDecimaleNegatif = tableauExpReg[2].slice(posSeparateur+1,tableauExpReg[2].length);		
			} else {
				// 1 format pour le partie dcimale
				this.formatPartieDecimale = tableauExpReg[2].slice(0,tableauExpReg[2].length);
				this.formatPartieDecimaleNegatif = this.formatPartieDecimale;
			}
		}
	}

	/**
	* La mthode initOptions() initialise les attributs de la classe relatifs  la gestion
	* des options de conversion.
	* @private
	* @param {} Aucun.
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/	
	this.initOptions = function() {
		// Rcupration des valeurs de l'expression sous forme de tableau
		var tableauExpReg = this.expressionFormatage.split("][");
		var options;
		var tableauOptions;
		
		// ***
		// Initialisation des attributs relatifs aux options
		options = tableauExpReg[4].slice(0,tableauExpReg[4].length-1);
		tableauOptions = options.split("|");
		
		// Type et seuil de l'arrondi
		if (tableauOptions[0]!="") {
			if (tableauOptions[0].indexOf("+")==-1&&tableauOptions[0].indexOf("-")==-1) {
				// Aucun parametres
				this.typeArrondi = "";
				this.seuilArrondi = 0;
			} else {
				if (tableauOptions[0].length != 1) {
					// Le seuil de l'arrondi et son type sont prcis
					this.seuilArrondi = tableauOptions[0].slice(0,tableauOptions[0].length-1);
					this.typeArrondi = tableauOptions[0].slice(tableauOptions[0].length-1,tableauOptions[0].length);
				} else {
					// Seul le type de l'arrondi est prcis
					this.typeArrondi = tableauOptions[0];
				}
			}
		}
		this.nbDecimale = (tableauOptions[1]!="")?tableauOptions[1]:this.nbDecimale;
		this.separateur = (tableauOptions[2]!="")?tableauOptions[2]:this.separateur;
		this.symbol = (tableauOptions[3]!="")?tableauOptions[3]:this.symbol;
		this.posSymbol = (tableauOptions[4]!="")?tableauOptions[4]:this.posSymbol;
		this.facteurConversion = (tableauOptions[5]!="")?tableauOptions[5]:this.facteurConversion;
		this.formatAffichage = (tableauOptions[6]!="")?tableauOptions[6]:this.formatAffichage;
	}

	/**
	* La mthode initNombre() initialise les attributs de la classe relatifs  la gestion
	* du nombre (renseigne les attributs partieEntiere et partieDecimale  partir du nombre
	* normalis).
	* @private
	* @param {} Aucun.
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/		
	this.initNombre = function() {
	  var chaineNormalise = this.nombreNormalise + "";
		var posSeparateur = chaineNormalise.indexOf(".");
		if (posSeparateur!=-1){
			this.partieEntiere = chaineNormalise.slice(0, posSeparateur);
			this.partieDecimale = chaineNormalise.slice(posSeparateur+1, chaineNormalise.length);
		} else this.partieEntiere = chaineNormalise;
	}

	/**
	* La mthode formaterPartieEntiere() formate la partie entire du nombre.
	* @private
	* @param {} Aucun.
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/	
	this.formaterPartieEntiere = function() {
		var motifEnCours = "";
		
		// Si aucun formatage
		if ((this.formatPartieEntiere=="" && this.formatPartieEntiereNegatif=="")
				||(this.estNombrePositif()&&this.formatPartieEntiere=="")
				||(!this.estNombrePositif()&&this.formatPartieEntiereNegatif=="")) {
			this.partieEntiereFormate = this.partieEntiere;
			return;
		}
		
		// Dfinition du format  utiliser
		if (this.estNombrePositif())
			motifEnCours = this.formatPartieEntiere;
		else
			motifEnCours = this.formatPartieEntiereNegatif;
			
		// Formatage
		var indexNombre = 0;
		var lgNombre = this.partieEntiere.length;
		var indexMotif = 0;
		var lgMotif = motifEnCours.length;
		var sortie = "";
		while (indexNombre<lgNombre) {
			if (motifEnCours.charAt(lgMotif-1-indexMotif)!="0")
				// Insrer le motif dans la chaine de sortie
				sortie = motifEnCours.charAt(lgMotif-1-indexMotif) + sortie;
			else {
				// Insrer le caractre courant du nombre dans la chaine de sortie
				sortie = this.partieEntiere.charAt(lgNombre-1-indexNombre) + sortie;
				indexNombre++;
			}
			indexMotif++;
			
			// RAZ de l'index motif
			if (indexMotif == lgMotif-1)
				indexMotif = 0;
		}
		
		// Mise  jour de l'objet
		this.partieEntiereFormate = sortie;
	}
	
	/**
	* La mthode formaterPartieDecimale() formate la partie dcimale du nombre.
	* @private
	* @param {} Aucun.
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/	
	this.formaterPartieDecimale = function() {
		var motifEnCours = "";
		
		// Si aucun formatage
		if ((this.formatPartieDecimale=="" && this.formatPartieDecimaleNegatif=="")
				||(this.estNombrePositif()&&this.formatPartieDecimale=="")
				||(!this.estNombrePositif()&&this.formatPartieDecimaleNegatif=="")) {
			this.partieDecimaleFormate = this.partieDecimale;
			return;
		}
		
		// Dfinition du format  utiliser
		if (this.estNombrePositif())
			motifEnCours = this.formatPartieDecimale;
		else
			motifEnCours = this.formatPartieDecimaleNegatif;
			
		// Formatage
		var indexNombre = 0;
		var lgNombre = this.partieDecimale.length;
		var indexMotif = 0;
		var lgMotif = motifEnCours.length;
		var sortie = "";
		while (indexNombre<lgNombre) {
			if (motifEnCours.charAt(lgMotif-1-indexMotif)!="0")
				// Insrer le motif dans la chaine de sortie
				sortie = sortie + motifEnCours.charAt(lgMotif-1-indexMotif);
			else {
				// Insrer le caractre courant du nombre dans la chaine de sortie
				sortie = sortie + this.partieDecimale.charAt(indexNombre);
				indexNombre++;
			}
			indexMotif++;
			
			// RAZ de l'index motif
			if (indexMotif == lgMotif-1)
				indexMotif = 0;
		}
		
		// Mise  jour de l'objet
		this.partieDecimaleFormate = sortie;
	}
	
	
	/**
	* La mthode factoriserNombre() applique l'opration demande par l'option du 
	* facteur mutiplicatif dans la chaine de formatage.
	* @private
	* @param {} Aucun.
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/		
	this.factoriserNombre = function() {
		this.nombreNormalise = this.nombreNormalise * this.facteurConversion; 
	}
	
	/**
	* La mthode arrondirNombre() applique l'opration demande par l'option de 
	* l'arrondi + nombre de dcimales dans la chaine de formatage.
	* @private
	* @param {} Aucun.
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/
	this.arrondirNombre = function() {
		if (this.nombreNormalise-Math.floor(this.nombreNormalise) == 0)
			return;
		
		if (this.typeArrondi == "")
		{
			// Pas d'arrondi et calcul du nombre de dcimales
			if (this.nbDecimale == 0)
				this.nombreNormalise = Math.floor(this.nombreNormalise);
			else {
				var entier = Math.floor(this.nombreNormalise);
				var multiple = Math.pow(10,parseInt(this.nbDecimale));
				var decimales = (this.nombreNormalise-Math.floor(this.nombreNormalise))*multiple;
				this.nombreNormalise = "" + entier + "." + Math.floor(decimales);
			}
		} else {
			// Calcul de l'arrondi et du nombre de dcimales
			var multiple = Math.pow(10,parseInt(this.nbDecimale)+1);
			var mille = multiple*this.nombreNormalise;
			var entier = Math.floor(mille);
			var reste = entier%10;
		  var signe = (this.positif)?1:-1;
			if (((reste<(parseFloat(this.seuilArrondi)*10*signe)) && this.typeArrondi == "+")
					|| ((reste<=(parseFloat(this.seuilArrondi)*10*signe)) && this.typeArrondi == "-"))
				entier = (entier-reste)/10;
			else
				entier = ((entier-reste)/10)+1;
			this.nombreNormalise = ""+(entier/(multiple/10));
		}
	}
	
	/**
	* La mthode formaterAffichage() applique l'opration demande par l'option du 
	* format d'affichage scientifique dans la chaine de formatage.
	* @private
	* @param {} Aucun.
	* @return {void}
	* @version 2.4
	* @date 14/11/2006
	*/
	this.formaterAffichage = function() {
		this.puissancesE = "";
		if (this.formatAffichage=="S") {
			// Affichage scientifique
			var entier = Math.floor(this.nombreNormalise)+"";
			var nbMaxEntier = ((this.estNombrePositif())?1:2);
			if ((nbMaxEntier==1&&entier=="0") || (nbMaxEntier==2&&entier=="-0")) {
				// Puissance ngative
				while (entier == "0" || entier == "-0") {
					this.nombreNormalise = this.nombreNormalise*10;
					entier = Math.floor(this.nombreNormalise)+"";
					this.puissancesE--;										
				}
			}	else {
				// Puissance positive
				while (entier.length!=nbMaxEntier) {
					this.nombreNormalise = this.nombreNormalise/10;
					entier = Math.floor(this.nombreNormalise)+"";
					this.puissancesE++;
				}
			}
		}
		
		if (this.puissancesE < 0)
			this.puissancesE = this.puissancesE + "";
		else
			this.puissancesE = "+" + this.puissancesE;
	}
}


// Fonction globale pour appliquer un format de restitution  un nombre

/**
* formaterNombre(nombre, expressionFormatage) permet de vrifier si nombre est un nombre et le retourne
* dans un autre format spcifi dans le paramtre "expressionFormat".
* -- explication du format de l'expression --
* <br><br>
* @public
* @param {String_Obligatoire} nombre : Chane de caractres contenant le nombre.
* @param {String_Obligatoire} expressionFormatage : Chane de caractres contenant le format cible.
* @return {String} Nombre converti si les paramtres sont corrects, null sinon.
* @version 2.4
* @date 14/11/2006
*/
function formaterNombre(nombre, expressionFormatage)
{
	var monNombre = new NombreFormate(nombre, expressionFormatage);
	if (!monNombre.estExpressionCorrecte())
		return null;
	return monNombre.donneNombreFormate();
}


/**
* deformaterNombre(nombreFormate, expressionFormatage) retourne le nombreFormate dans son format
* d'origine.
* <br><br>
* @public
* @param {String_Obligatoire} nombreFormate : Chane de caractres contenant le nombre format.
* @param {String_Obligatoire} expressionFormatage : Chane de caractres contenant le format cible.
* @return {String} Nombre converti si les paramtres sont corrects, null sinon.
* @version 2.4
* @date 14/11/2006
*/
function deformaterNombre(nombreFormate, expressionFormatage)
{
	var monNombre = new NombreFormate(null, expressionFormatage);
	if (!monNombre.estExpressionCorrecte())
		return null;
	return monNombre.donneOrigineNombreFormate(nombreFormate);
}


// Objet NumTelFormate

/**
* Cre une nouvelle instance NumTelFormate.<br> 
* @class La classe <b>NumTelFormate</b> est la classe permettant de manipuler un numro
* de tlphone dans le but de lui donner diffrentes formes possibles via une chaine
* de formatage.
* Cette chaine de formatage doit tre constitue comme suit :<br>
* [prefixe+|prefixe-][motif_partie_entiere+|motif_partie_entiere-]
* [motif_partie_decimale+|motif_partie_decimale-][postfixe+|postfixe-]
* [options]<br>
* <ul><li>prefixe+/- : prfixe  afficher avant le nombre positif ou ngatif. Dans le cas o un seul
* prefixe est prcis ([prefixe]), il sera utilis indifferement pour un nombre ngatif ou positif.</li>
* <li>motif_partie_entiere+/- : motif priodique  respecter pour l'affichage de la partie entire
* du nombre. Le caractre 0 reprsente un chiffre. Ex.: 0 000 pour un motif avec un espace comme 
* sparateur de milliers. Dans le cas o un seul motif est prcis ([motif]), il sera utilis
* indifferement pour un nombre ngatif ou positif.</li>
* <li>motif_partie_decimale+/- : motif priodique  respecter pour l'affichage de la partie dcimale
* du nombre. Le caractre 0 reprsente un chiffre. Ex.: 0 000 pour un motif avec un espace comme 
* sparateur de milliers. Dans le cas o un seul motif est prcis ([motif]), il sera utilis
* indifferement pour un nombre ngatif ou positif.</li>
* <li>postfixe+/- : postfixe  afficher aprs le nombre positif ou ngatif. Dans le cas o un seul
* postfixe est prcis ([postfixe]), il sera utilis indifferement pour un nombre ngatif ou positif.</li>
* <li>options : liste des options  utiliser lors du formatage [{arrondi}{+/-}|{nb_decimales}|
* {separateur}|{symbol}|{position_symbol:0|1|2|3|4}|{facteur_multiplicateur}|{format_affichage : N|S}]
*	<ul> <li>arrondi : Nombre prcisant  quelle valeur doit tre effectu l'arrondi,
* suivi de (+) pour l'arrondi  la valeur suprieur ou (-) pour l'arrondi  la valeur infrieur.
* Ces paramtres sont optionnels. Valeur par dfault : 0.5+</li>
* </ul>
* </ul>
* @constructor
* @param {String_Obligatoire} unNumero : numro de tlphone a manipul dans la classe
* @param {String_Facultatif} uneExpressionFormatage : Chaine de formatage prcisant
* le format de conversion souhait
* @version 2.5
* @date 14/02/2007
*/
function NumTelFormate(unNumero, uneExpressionFormatage) {

	// Constantes
	
	/**
	* Constante dsignant l'expression rgulire utilise pour vrifier le format de la
	* chaine de formatage.
	* @private
	* @type {string}
	* @final
	* @version 2.5
* @date 14/02/2007
	*/
	this.EXPREG = /^\[[^||]*\]\[[^||]*\]\[[^||]*\]\[[^||]*\]$/;

	/**
	* Constante dsignant la chaine de formatage par dfaut.
	* @private
	* @type {string}
	* @final
	* @version 2.5
* @date 14/02/2007
	*/
	this.FORMATDEF = "[][0.00][][]";
		
	// Proprits
	
	/**
	* Proprit dsignant le numro courant dans son format d'origine (format de saisie).
	* @private
	* @type string
	* @version 2.5
* @date 14/02/2007
	*/
	this.numero = unNumero;

	/**
	* Proprit dsignant le numro courant dans un format normalis (format numrique).
	* @private
	* @type String
	* @version 2.5
* @date 14/02/2007
	*/
	this.numeroNormalise = "";

	/**
	* Proprit dsignant le numro courant dans son tat format, c'est--dire
	* l'tat du numro aprs lui avoir appliqu la chaine de formatage.
	* @private
	* @type string
	* @version 2.5
* @date 14/02/2007
	*/
	this.numeroFormate = "";

	/**
	* Proprit dsignant l'expression de formatage  utiliser lors du formatage du numro.
	* @private
	* @type string
	* @version 2.4
	* @date 14/11/2006
	*/	
	this.expressionFormatage = ((uneExpressionFormatage=="")?this.FORMATDEF:uneExpressionFormatage);


	// Mthodes

	/**
	* La mthode setNumero(expression) dfinit le numro  formater.
	* @public
	* @param {String_Obligatoire} num : numro  formater.
	* @return {void}
	* @version 2.5
* @date 14/02/2007 
	*/
	this.setNumero = function(num) {
		this.numero = num;
		this.numeroNormalise = "";
	}

	/**
	* La mthode getNumero() retourne le numro utilise par la classe.
	* @public
	* @param {} Aucun.
	* @return {String}
	* @version 2.5
* @date 14/02/2007 
	*/
	this.getNumero = function() {
		return this.numero;
	}	

	/**
	* La mthode getNumeroFormate() retourne le numro format par la classe.
	* @public
	* @param {} Aucun.
	* @return {String}
	* @version 2.5
* @date 14/02/2007 
	*/
	this.getNumeroFormate = function() {
		return this.numeroFormate;
	}
		
	/**
	* La mthode setExpressionFormatage(expression) dfinit la chane de formatage  utiliser.
	* @public
	* @param {String_Obligatoire} expression : expression de formatage  utiliser.
	* @return {void}
	* @version 2.5
* @date 14/02/2007 
	*/
	this.setExpressionFormatage = function(expression) {
		this.expressionFormatage = expression;
		this.numeroFormate = "";
	}

	/**
	* La mthode getExpressionFormatage() retourne la chane de formatage utilise
	* par la classe.
	* @public
	* @param {} Aucun.
	* @return {String}
	* @version 2.5
* @date 14/02/2007 
	*/
	this.getExpressionFormatage = function() {
		return this.expressionFormatage;
	}	
	
	/**
	* La mthode estExpressionCorrecte() renvoie true si la chaine l'expression de formatage
	* passe en paramtre du constructeur est valide, false sinon.
	* @public
	* @param {} Aucun.
	* @return {boolean}
	* @version 2.5
* @date 14/02/2007
	*/
	this.estExpressionCorrecte = function() {
		return this.EXPREG.test(this.expressionFormatage);
	}

	/**
	* La mthode formaterNumero() applique la chaine de formatage au numro courant.
	* La chane de formatage  appliquer peut-tre passe en paramtre optionnel.
	* Retourne la valeur si tout s'est bien pass, null sinon.
	* @public
	* @param {String_Optionnel} expressionFormatage : Expression de formatage  appliquer.
	* @return {String}
	* @version 2.5
* @date 14/02/2007
	*/
	this.formaterNumero = function() {	
		// Initialisation des attributs
		this.numeroFormate = "";
		
		// Rcupration du paramtre optionnel expressionFormatage
		if (arguments.length == 1)
			this.expressionFormatage = arguments[0];

		// Vrification des parametres
		if (this.numero == "" || this.numero == null || this.expressionFormatage == ""
				 || this.expressionFormatage == null || this.estExpressionCorrecte()!=true)
			return null;		
			
		return (this.calculNumeroFormate());
	}
	
	/**
	* La mthode calculNumeroFormate() renseigne la proprit de l'objet contenant
	* le numro convertit au format spcifi par l'expression de formatage.
	* Retourne la valeur si tout s'est bien pass, null sinon.
	* @private
	* @param {} Aucun.
	* @return {String}
	* @version 2.5
* @date 14/02/2007
	*/
	this.calculNumeroFormate = function () {
		// Normalisation du numro
		var j = 0; 
		for (var i = 0; i < this.numero.length; i++) {
			if (!isNaN(this.numero.charAt(i)) && this.numero.charAt(i) != " "
					&& this.numero.charAt(i) != "-" && this.numero.charAt(i) != "E"
					&& this.numero.charAt(i) != "+") {
				this.numeroNormalise += this.numero.charAt(i);
				j++;
			}
		}
		if (this.numeroNormalise == "" || isNaN(this.numeroNormalise))
			return null;
					
		// Prise en compte du prefixe
		this.numeroFormate += this.donnePrefixe();

		// Prise en compte de l'option nbCarOmis 
		var nbCar = this.donneNbCarOmis();
		var numeroNormAvecOption = this.numeroNormalise.slice(nbCar,this.numeroNormalise.length);
		
		// Prise en compte du motif		
		this.numeroFormate += this.appliquerMotif(numeroNormAvecOption);

		// Prise en compte du postfixe
		this.numeroFormate += this.donnePostfixe();
		
		return this.numeroFormate; 
	}

	/**
	* La mthode deformaterNumero(resultatFormate) retourne une chaine de caractre contenant
	* le numro qui tait  l'origine du formatage obtenu dans resultatFormate.
	* Retourne la valeur si tout s'est bien pass, null sinon.
	* @public
	* @param {String_Optionnel} resultatFormate : formatage du nombre recherch.
	* @param {String_Optionnel} expressionFormatage : Expression du formatage d'origine.
	* @return {String}
	* @version 2.5
* @date 14/02/2007
	*/
	this.deformaterNumero = function () {	
		// Cas d'un dformater sur les donnes internes de la classe
		if (arguments.length == 0 && this.numero != "" && this.numero != null
				&& this.expressionFormatage == "" && this.expressionFormatage == null)
			return this.numero;
		else
			this.numero = "";
			
		// Rcupration du ou des paramtre(s) optionnel(s)
		if (arguments.length == 1)
			this.numeroFormate = arguments[0];			
		if (arguments.length == 2)
			this.expressionFormatage = arguments[1];
						
		// Vrification des parametres
		if (this.numeroFormate == "" || this.numeroFormate == null ||
				this.expressionFormatage == "" || this.expressionFormatage == null || this.estExpressionCorrecte()!=true)
			return null;
		
		return (this.calculerNumeroOrigine());
	}
	
	/**
	* La mthode calculerNumeroOrigine() retourne une chaine de caractre contenant
	* le numro qui tait  l'origine du formatage obtenu dans numeroFormate.
	* Retourne la valeur si tout s'est bien pass, null sinon.
	* @private
	* @param {} Aucun.
	* @return {String}
	* @version 2.5
* @date 14/02/2007
	*/
	this.calculerNumeroOrigine = function () {		
		// Suppression des prefixe et postfixe
		var postFixe = this.donnePostfixe();
		var preFixe = this.donnePrefixe();
		var numeroOrigine = this.numeroFormate;
		
		if (this.numeroFormate.indexOf(preFixe, 0) == 0)
			numeroOrigine = this.numeroFormate.slice(this.donnePrefixe().length,this.numeroFormate.length);
		if (this.numeroFormate.indexOf(postFixe, 0) != -1)
			numeroOrigine = numeroOrigine.slice(0,numeroOrigine.length-postFixe.length);
					
		// Suppression du motif
		numeroOrigine = numeroOrigine.replace("/^[[:alpha:]]$/","");
		
		if (numeroOrigine=="")
			return null;
		this.numeroNormalise = numeroOrigine;
		this.numero = numeroOrigine;
		
		return (numeroOrigine);
	}
	
	/**
	* La mthode donnePrefixe() retourne le prfixe  utiliser lors du formatage du numro.
	* Si aucun prefixe n'a t paramtr, retourne une chaine vide.
	* @private
	* @param {} Aucun.
	* @return {string}
	* @version 2.5
* @date 14/02/2007
	*/	
	this.donnePrefixe = function() {
		// Rcupration des valeurs de l'expression sous forme de tableau
		var tableauExpReg = this.expressionFormatage.split("][");
	
		// Initialisation des attributs relatifs au(x) prfixe(s)
		if (tableauExpReg[0].length-1!=0) {
			// Il existe un prfixe
			return tableauExpReg[0].slice(1,tableauExpReg[0].length);
		} else
			return "";				
	}

	/**
	* La mthode donnePostfixe() retourne le postfixe  utiliser lors du formatage du numro.
	* Si aucun postfixe n'a t paramtr, retourne une chaine vide.
	* @private
	* @param {} Aucun.
	* @return {string}
	* @version 2.5
* @date 14/02/2007
	*/	
	this.donnePostfixe = function() {
		// Rcupration des valeurs de l'expression sous forme de tableau
		var tableauExpReg = this.expressionFormatage.split("][");
	
		// Initialisation des attributs relatifs au(x) prfixe(s)
		if (tableauExpReg[2].length!=0) {
			// Il existe un postfixe
			return tableauExpReg[2].slice(0,tableauExpReg[2].length);
		} else
			return "";				
	}

	/**
	* La mthode donneNbCarOmis() retourne le nombre de caractre  ommettre.
	* Si cette option n'a pas t prcis, retourne 0.
	* @private
	* @param {} Aucun.
	* @return {int}
	* @version 2.5
* @date 14/02/2007
	*/	
	this.donneNbCarOmis = function() {
		// Rcupration des valeurs de l'expression sous forme de tableau
		var tableauExpReg = this.expressionFormatage.split("][");
	
		// Initialisation des attributs relatifs au(x) prfixe(s)
		if (tableauExpReg[3].length-1!=0) {
			// Il existe des options
			return parseInt(tableauExpReg[3]);
		} else
			return 0;
	}

	/**
	* La mthode appliquerMotif() retourne la chaine contenant le numro pass en 
	* paramtre respectant le motif dcrit dans les paramtres.
	* Si ce paramtre n'a pas t prcis, retourne une chane vide.
	* @private
	* @param {String_Obligatoire} num : numro sur lequel appliquer le motif.
	* @return {String}
	* @version 2.5
* @date 14/02/2007
	*/
	this.appliquerMotif = function(num) {
		// Rcupration du motif
		var tableauExpReg = this.expressionFormatage.split("][");
		var motifEnCours = tableauExpReg[1]; 
		
		// Si aucun formatage
		if (motifEnCours == "")
			return "";
					
		// Formatage
		var indexNumero = 0;
		var lgNumero = num.length;
		var indexMotif = 0;
		var lgMotif = motifEnCours.length;
		var sortie = "";
		while (indexNumero<lgNumero) {
			if (motifEnCours.charAt(lgMotif-1-indexMotif)!="0")
				// Insrer le motif dans la chaine de sortie
				sortie = motifEnCours.charAt(lgMotif-1-indexMotif) + sortie;
			else {
				// Insrer le caractre courant du nombre dans la chaine de sortie
				sortie = num.charAt(lgNumero-1-indexNumero) + sortie;
				indexNumero++;
			}
			indexMotif++;
			
			// RAZ de l'index motif
			if (indexMotif == lgMotif-1)
				indexMotif = 0;
		}
		
		return (sortie);
	}
}

/**
* formaterNumTel(numero, expressionFormatage) retourne "numero" dans le format spcifi
* dans le paramtre "expressionFormat" (cf. classe NumTelFormate).
* <br><br>
* @public
* @param {String_Obligatoire} numero : Chane de caractres contenant le numro de tlphone.
* @param {String_Obligatoire} expressionFormatage : Chane de caractres contenant le format cible.
* @return {String} Retourne le numero converti si les paramtres sont corrects, false sinon.
* @version 2.5
* @date 14/02/2007
*/
function formaterNumTel(numero, expressionFormatage)
{
	var monNumero = new NumTelFormate(numero, expressionFormatage);
	return monNumero.formaterNumero();
}

/**
* deformaterNumTel(numeroFormate, expressionFormatage) retourne "numeroFormate" dans
* son format d'origine aprs avoir t convertis avec le paramtre "expressionFormat"
* (cf. classe NumTelFormate). Attention, les caractres omis (champ options de l'expression
* de formatage) ne pourront pas tre retrouvs.
* <br><br>
* @public
* @param {String_Obligatoire} numeroFormate : Chane de caractres contenant le numro de tlphone format.
* @param {String_Obligatoire} expressionFormatage : Chane de caractres contenant le format du numro.
* @return {String} Retourne le numero d'origine si les paramtres sont corrects, false sinon.
* @version 2.5
* @date 14/02/2007
*/
function deformaterNumTel(numeroFormate, expressionFormatage)
{
	var monNumero = new NumTelFormate(null, expressionFormatage);
	return monNumero.deformaterNumero(numeroFormate);
}