/** 
* @fileoverview Ce fichier Javascript correspond au framework de gestion des
* requetes HTTP.
* <br>
* Ce framework client propose les classes utilitaires suivantes :
* <ul>
* <li><b>{@link XMLObject RequeteGet}</b> pour grer une requte HTTP de type GET (et nottament ses paramtres).
* </li>
* </ul>
* @author Ministre des Affaires Etrangres, Aubay SA, Steve Pguet
* @version 2.5
* @date 14/02/2007
*/

/*
Copyright ou  ou Copr. 
Ministre des Affaires Etrangres,
Aubay SA,
Steve Pguet, (06/04/2004)

steve.peguet@diplomatie.gouv.fr

Ce logiciel est un programme informatique servant de framework JavaScript 
bas sur les normes W3C (XHTML/CSS/DOM/XML). Il offre la possibilit de 
mettre en uvre facilement les principes ergonomiques et techniques propres 
 un client riche (cumul des avantages du client lger et du client lourd).
Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
respectant les principes de diffusion des logiciels libres. Vous pouvez
utiliser, modifier et/ou redistribuer ce programme sous les conditions
de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
sur le site "http://www.cecill.info".

En contrepartie de l'accessibilit au code source et des droits de copie,
de modification et de redistribution accords par cette licence, il n'est
offert aux utilisateurs qu'une garantie limite.  Pour les mmes raisons,
seule une responsabilit restreinte pse sur l'auteur du programme,  le
titulaire des droits patrimoniaux et les concdants successifs.

A cet gard  l'attention de l'utilisateur est attire sur les risques
associs au chargement,   l'utilisation,   la modification et/ou au
dveloppement et  la reproduction du logiciel par l'utilisateur tant 
donn sa spcificit de logiciel libre, qui peut le rendre complexe  
manipuler et qui le rserve donc  des dveloppeurs et des professionnels
avertis possdant  des  connaissances  informatiques approfondies.  Les
utilisateurs sont donc invits  charger  et  tester  l'adquation  du
logiciel  leurs besoins dans des conditions permettant d'assurer la
scurit de leurs systmes et ou de leurs donnes et, plus gnralement, 
 l'utiliser et l'exploiter dans les mmes conditions de scurit. 

Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
pris connaissance de la licence CeCILL, et que vous en avez accept les
termes.*/


// Accesseur de la proprit urlRequete

/**
* <b>Propre  la classe RequeteGet</b> - La mthode publique getUrl() retourne la valeur
* de l'URL manipule par l'objet RequeteGet courant.
* @public
* @param {} Aucun
* @return {string} valeur de l'URL de la requte GET courante
* @version 2.5
* @date 14/02/2007
*/
function RequeteGet_getUrl () {
	return this.urlRequete;
}

/**
* <b>Propre  la classe RequeteGet</b> - La mthode publique setUrl(url) permet de dfinir la valeur
* de l'URL manipule par l'objet RequeteGet courant. Elle met  jour la proprit tabParams
* @public
* @param {String_Obligatoire} url : nouvelle URL correspondant  la requete GET
* @return {void}
* @version 2.5
* @date 14/02/2007
*/
function RequeteGet_setUrl(url) {
	
	var tabUrlParams; // Variable temporaire pour dpartager URL / PARAMETRES
	var lesParams; // Variable tableau temporaire pour extraire les paramtres
	var unParams; // Variable tableau temporaire pour dpartager NOM / VALEUR d'un paramtre
	var cptParams; // Compteur de paramtre
	
	// Initialisation des attributs
	this.urlRequete = url;
	this.tabParams = new Array();

	// Renseignement du tableau des paramtres
	if (this.urlRequete == null)
		return;

  tabUrlParams = this.urlRequete.split(/\?/);
  if (tabUrlParams.length == 2 && (tabUrlParams[1] != "" || tabUrlParams[1] != "")) {
  		// Il existe des paramtres
  		lesParams = tabUrlParams[1].split(/&/);
  		for (cptParams = 0; cptParams < lesParams.length; cptParams++) {
  				// Extraire NOM et VALEUR du paramtre 
  				unParams = lesParams[cptParams].split(/=/);
  				// Ajouter le paramtre au tableau
  				if (unParams[1] != null)
  					this.tabParams[unParams[0]] = unescape(unParams[1]);
  		}
  }
}


// Accesseurs de la proprit tabParams

/**
* <b>Propre  la classe RequeteGet</b> - La mthode publique setTabParams(tabParametres)
* permet de dfinir l'ensemble des paramtres de la requte GET courante, sous la forme
* d'un tableau du type params={VAR1="xxxx",VAR2="ffff"}.
* @public
* @param {Array_string} tabParametres : tableau dsignant les paramtres de la requte du type
* params={VAR1="xxxx",VAR2="ffff"}
* @return {void}
* @version 2.5
* @date 14/02/2007
*/
function RequeteGet_setTabParams(tabParametres) {
	
	var tabUrlParams; // Variable temporaire pour dpartager URL / PARAMETRES
	var valeur; // Valeur du parametre courant 
	var nom; // libelle du parametre courant
	var premierParametre = true; // Indicateur de la position du parametre

	// Mise  jour du tableau de paramtre
	this.tabParams = tabParametres;
	
	// Mise  jour de l'url
	if (this.urlRequete == null)
		this.urlRequete = "";
	tabUrlParams = this.urlRequete.split(/\?/);
	this.urlRequete = tabUrlParams[0];
  for (nom in this.tabParams)
  { 	
    // Rcupration du nom du parametre
    valeur = this.tabParams[nom];
		
		// Ajout des sparateurs
		if (!premierParametre)
			this.urlRequete += '&';
		else {
			this.urlRequete += '?';
  		premierParametre = false;
		}
		this.urlRequete += nom + '=' + escape(valeur);
  }
}

/**
* <b>Propre  la classe RequeteGet</b> - La mthode publique getTabParams() retourne
* le tableau des paramtres du type params={VAR1="xxxx",VAR2="ffff"}, manipule par l'objet
* RequeteGet courant.
* @public
* @param {aucun}
* @return {Array_string}
* @version 2.5
* @date 14/02/2007
*/
function RequeteGet_getTabParams() {
	return this.tabParams;
}


// Mthode utilitaire pour tester la prsence d'un paramtre

/**
* <b>Propre  la classe RequeteGet</b> - La mthode publique estParam(parametre) retourne
* VRAI si le parametre est prsent dans l'url de l'objet RequeteGet courant. FAUX sinon.
* @public
* @param {String_Obligatoire} parametre : Nom du paramtre recherch
* @return {Booleen} VRAI si le parametre existe, faux sinon
* @version 2.5
* @date 14/02/2007
*/
function RequeteGet_estParam(parametre) {
	var nom; // libelle du parametre courant
	
	// Parcours du tableau de paramtre
	for (nom in this.tabParams)
  {
  	if (nom == parametre)
  		return true; // Le paramtre a t trouv
  }
  return false;
}


// Accesseurs pour un paramtre

/**
* <b>Propre  la classe RequeteGet</b> - La mthode publique getParam(parametre) retourne
* la valeur du parametre demand, manipule par l'objet RequeteGet courant. Retourne null
* si le paramtre n'existe pas.
* @public
* @param {String_Obligatoire} parametre : nom du parametre
* @return {String} valeur du paramtre
* @version 2.5
* @date 14/02/2007
*/
function RequeteGet_getParam(parametre) {
	var nom; // libelle du parametre courant
	
	// Parcours du tableau de paramtre
	for (nom in this.tabParams)
  {
  	if (nom == parametre)
  		return this.tabParams[nom]; // Le paramtre a t trouv
  }
  return null;
}

/**
* <b>Propre  la classe RequeteGet</b> - La mthode publique setParam(parametre, valeur)
* permet de dfinir un paramtre de la requte GET courante.
* @public
* @param {String_Obligatoire} parametre : nom du parametre
* @param {String_Obligatoire} valeur : valeur du parametre
* @return {void}
* @version 2.5
* @date 14/02/2007
*/
function RequeteGet_setParam(parametre, valeur) {
	// Ajout du paramtre
	this.tabParams[parametre] = valeur;
  
	// Mise  jour de l'objet
	this.setTabParams(this.tabParams);
}

/**
* <b>Propre  la classe RequeteGet</b> - La mthode publique supprimerParam(parametre)
* permet de supprimer un paramtre de la requte GET courante.
* @public
* @param {String_Obligatoire} parametre : nom du parametre
* @return {void}
* @version 2.5
* @date 14/02/2007
*/
function RequeteGet_supprimerParam(parametre) {
	// Suppression du paramtre
	var nouvTabParams = new Array(); // Tableau temporaire des paramtres
	for (nom in this.tabParams)
  		if (nom != parametre)
  				nouvTabParams[nom] = this.tabParams[nom];
	this.tabParams = nouvTabParams;

	// Mise  jour de l'objet
	this.setTabParams(this.tabParams);
}

/**
* <b>Propre  la classe RequeteGet</b> - La mthode publique viderParams()
* permet de supprimer tous les paramtres de la requte GET courante.
* @public
* @param {} Aucun
* @return {void}
* @version 2.5
* @date 14/02/2007
*/
function RequeteGet_viderParams() {
	// Suppression des paramtres
	this.tabParams[parametre] = new Array();

	// Mise  jour de l'objet
	this.setTabParams(this.tabParams);
}

// Constructeur

/**
* <b>Propre  la classe RequeteGet</b> - Constructeur de le classe RequeteGet.
* @public
* @param {String_Obligatoire} url : url de la requete GET
* @return {void}
* @version 2.5
* @date 14/02/2007
*/
function RequeteGet_constructor(url) {
	// Mise  jour de l'objet
	this.setUrl(url);
}


// Objet pour la gestion des requtes HTTP de type GET

/**
* Cre une instance de la classe RequeteGet.<br>
* @class
* La classe <b>RequeteGet</b> est la classe permettant de manipuler l'url d'une requte HTTP de type GET.
* <br><br><br><img src="Image.RequeteGetUML.png"/><br><br><br>
* <a href="javascript:ouvrirPopupExemple('./exemples/requeteget1.html','Zoom')">Exemple d'utilisation de l'objet RequeteGet.</a><br>
* @constructor
* @public
* @param {String_Obligatoire} url : chaine indiquant l'url de la requte GET.
* @version 2.5
* @date 14/02/2007
*/
function RequeteGet(url)
{

  // Attributs de la classe 
  
	/**
	* L'attribut urlRequete contient l'url de la requete HTTP de type GET.
	* <br><br>
	* @private
	* @type String
	* @version 2.5
	* @date 14/02/2007	
	*/  
	this.urlRequete;
	
	/**
	* L'attribut tabParams est un tableau du type params={VAR1="xxxx",VAR2="ffff"} contenant
	* les paramtres de la requte.
	* <br><br>
	* @private
	* @type Array_String
	* @version 2.5
	* @date 14/02/2007
	*/  
	this.tabParams = new Array();


	// Mthodes de la classe
  
	this.getUrl = RequeteGet_getUrl;
	this.setUrl = RequeteGet_setUrl;
	this.setTabParams = RequeteGet_setTabParams;
	this.getTabParams = RequeteGet_getTabParams;
	this.estParam = RequeteGet_estParam;
	this.getParam = RequeteGet_getParam;
	this.setParam = RequeteGet_setParam;
	this.supprimerParam = RequeteGet_supprimerParam;
	this.viderParams = RequeteGet_viderParams;
	this.constructor = RequeteGet_constructor;
	
	this.constructor(url);
}
 